%clear all variables from workspace, clear command window
%and close all open figures. 

clear all;
      clc;
close all;
   


%initalize some global variables now.  these variables will be constant
%throughout the rootscan analysis.

global AllImageSpecs; %structure containing all image specifications.
global         f_fig; %figure handle.



%define the current directory.

currentDir = cd;  


%define the screensize.  this will be used to construct the main gui window.

screenSize = get(0, 'ScreenSize');  




%----------------------initalize the gui figure window---------------------%



%retrieve the GUI display color set by user or set the default color.
%our default color will be light blue.

directory = which('Rootscan_session.m');
directory(end-17:end)            = [];

cd(directory);

switch numel(dir('BgColor.mat'))

    %the file containing the GUI background color specs exists.
    
    case 1 
        
        GUIDispColor = load([directory 'BgColor.mat']);
 
        
    %the file containing the GUI background color specs does not exist.

    case 0 
        
        GUIDispColor = [.8 .9 .9];
        
        
end;
        
  


%initialize main GUI figure.

f_fig = figure('Name', 'SELECTA AERENCHYMA 1.0 BETA', 'Position', ...
    [0, 0, screenSize(3), screenSize(4)], 'MenuBar', 'none', ...
    'Color', GUIDispColor.BgColor, 'NumberTitle', 'off');



%define a gui handle.  this handle will be used to store axex, button and 
%other handles in it.

f_fig_handle = guihandles(f_fig); 

                 
              
                                  
%MENU----MENU----MENU----MENU----MENU----MENU----MENU----MENU----MENU%
%MENU----MENU----MENU----MENU----MENU----MENU----MENU----MENU----MENU%
%MENU----MENU----MENU----MENU----MENU----MENU----MENU----MENU----MENU%


    %'about menu' parent.  when the user selects this option a window will given 
    %some general information about the software.
    
    uimenu('Label', 'About Root Scan', 'Callback', 'aboutRootScan');  

    
    %'file' menu parent.

    fileMenuBar = uimenu(f_fig, 'Label', 'File'); 
    
    
        %file menu child #1.  user selects this option to open a single file
        %for analysis.
    
        uimenu(fileMenuBar, 'Label', 'Open Image', 'Callback', 'Rootscan_session(-1);');  
               
        
        %file menu child #2.  user selects this option to close the entire program.
        
        uimenu(fileMenuBar, 'Label', 'End Session', 'Callback', 'exit', 'enable', 'off');   
        
        
    %data options parent.
   
    dataOptionsMenuBar = uimenu(f_fig, 'Label', 'Data Options'); 
    
    
        imageInversion = uimenu(dataOptionsMenuBar, 'Label', ...
            'Image Negative', 'Callback', 'invertImage;');
    
    
        %data options child #2.  user selects this option to enter camera
        %calibration and data precision settings.

        Measure_calib = uimenu(dataOptionsMenuBar, 'Label', ...
            'Measurement Calibration', 'Callback', 'set_calibration;');  
        
       
                
        
        %data options child #3. user selects this option to check which
        %steps are automated.
        
        auto_steps = uimenu(dataOptionsMenuBar, 'Label', ...
            'Analysis automation options', 'Callback', 'automated_options;'); 
        
        
        
        %data options child #4.  user selects this option to define their
        %own derived variables
        
        cortex_options = uimenu(dataOptionsMenuBar, 'Label', 'Select Cortex Intervals');  
        
        
        %advanded measuremnents child #1.  user selects this option to define
        %the intervals for cortex cell size measurements.
        
        Cortex_int = uimenu(cortex_options, 'Label', 'Cortex Region Interval Selection', ...
            'Callback', 'set_cortex_bands;');  
        
        
        %advanded measuremnents child #2.  user selects this option to define
        %custom intervals for cortex cells size measurements.
        
        Cortex_measure_custom = uimenu(cortex_options, 'Label', 'Custom Interval Selection', ...
            'Callback', 'set_custom_cortex_bands;');  
        
       
    %batch analysis parent.
        
    BatchMenuBar = uimenu(f_fig, 'Label', 'Batch Analysis');  
    
        
        %batch analysis child #1.  user selects a directory for batch analysis.
        
         selectDir = uimenu(BatchMenuBar, 'Label', ...
             'Select Directory', 'Callback', 'Rootscan_session(-2);', ...
             'Interruptible', 'off');  
         
         
         %batch analysis child #2.  user selects a finished directory for fast
         %data output.
         
         DataOut = uimenu(BatchMenuBar, 'Label', ...
             'Data Output', 'Callback', 'DATAOUT(2,0,0);', 'Interruptible', 'off');
         
         
         %reanalyze batch (cortex cells only). user selects a finished
         %directory for re-analysis.
         
         Cortex_analysis = uimenu(BatchMenuBar', 'Label', ...
             'Reanalyze Cortex Cells', 'Callback', 'cortex_RE_analysis;', 'Interruptible', 'off');
         

         
         %batch analysis child #4. user can delete all the matlab files and
         %sub-directories in current image directory.  they can do this if
         %they want to start over.
         
         delSession = uimenu(BatchMenuBar, 'Label', 'Delete Directory', ...
             'Callback', 'deleteSession;', 'Interruptible', 'off'); 
         
         
         %batch analysis child #5. user can view any runtime statistics
         %after they complete an directory.
         
         runtimeStats = uimenu(BatchMenuBar, 'Label', 'Runtime Statistics', ...
             'Callback', 'runtimeSTATS;', 'Interruptible', 'off');
         
         
    %threshold options.
    
    global pix;
    
    thresholdOptionsMenuBar = uimenu(f_fig, 'Label', 'Threshold Options');
    
    pix = [0 0 0];  %initialize the values of the menu bar.  All options are
    %unchecked at this time.
    
        %threshold options - user selects this option when they want to change the threshold settings. 
        
        uimenu(thresholdOptionsMenuBar, 'Label', 'Change Threshold Methods', ...
            'Callback', 'threshold_options;');
        

        uimenu(thresholdOptionsMenuBar, 'Label', 'Redo Thresholding', ...
            'Callback', 'Redo_Thresholding;');
             
         
    %image output options parent.     
         
    DisplayMenuBar = uimenu(f_fig, 'Label', 'Display and Image Output Options');
    
    
            %displaymenubar options child #1. this is a prototype.  user should 
            %not select this option at this time.
    
         GUIColorMenuBar = uimenu(DisplayMenuBar, 'Label', 'Main Display Color', ...
             'Callback', 'mainDisplayColor;', 'Interruptible', 'off');  
         
         

         %user selects this option to change the rgb color key for
         %highlighted  image output. 
         
         Highlight_image_color_options = uimenu(DisplayMenuBar, 'Label', ...
             'Select Image Output Colors', 'Callback', 'ImageColors;');
         
         
         change_format = uimenu(DisplayMenuBar, 'Label', ...
             'Covert to tif', 'Callback', 'cvrt2tif;');
         
        
        
    %help menu parent.     
        
    helpMenuBar = uimenu(f_fig, 'Label', 'Help Menu');  

    
        %HELP MENU CHILD #1.  USER SELECTS THIS OPTION TO GET THE MATLAB HELP WINDOW.

        uimenu(helpMenuBar, 'Label', 'MATLAB help menu', 'Callback', 'helpwin');  
        
        
        %HELP MENU CHILD #2.  NOT DEVELOPED YET.
        
        uimenu(helpMenuBar, 'Label', 'ROOT SCAN HELP');  

        

        %at this time verify which operating system the user is using.
        %this will determine if the directory separators are forward or
        %backward slash symbols.
        
        
        verifyDir = which('select_directory.m');
        
        verifyDirBack = verifyDir(uint8(verifyDir) == 92); %find forward slashes
        verifyDirFor  = verifyDir(uint8(verifyDir) == 47); %find back slashes
        
        
        if (length(verifyDirBack) > length(verifyDirFor))
        
            AllImageSpecs.fileSeparator = '\';
            
        else
            
            AllImageSpecs.fileSeparator = '/';
 
            
            
        end;
        
        

%define the current checkbox checked position.        

find_last_break = find(verifyDir == AllImageSpecs.fileSeparator, 1, 'last'); 
verifyDir                                    = verifyDir(1:find_last_break); 
        


%go to the main programs directory.

cd(verifyDir); 
                


%return to currect directory.        
        
cd(currentDir);  
        
 
        