function COMsCalc

%this function will calculate the center of mass for all segmented (and
%dimensionally normalized) x-sections so the user does not have to wait
%longer during their interaction with the program.

global AllImageSpecs;
global        h_wait;

%--------check to see if the coms file exists in the temp directory.------%


%define current directory.

currentDir = cd;


%go to the tempoary image directory (directory name = temp).

cd([currentDir AllImageSpecs.fileSeparator 'temp']);


%check to see if the file exist.

checkCom = dir('XScom');


%if the file does not exist. then calculate the center of masses for all
%x-sections and save the file in the current image directory.

if isempty(checkCom)


    %access the directory named X_section_segments and find image directory
    %containing only solid cross-section images.

    cd([currentDir AllImageSpecs.fileSeparator 'X_section_segments']);


    %find the subdirectory containing the solid cross-section images.

    solidDir = dir('SOLID_XS*');


    %define the number of solid cross-section images.  This number should be
    %equal to the number of images in the parent image directory.

    numImages = numel(solidDir);


    %create a matrix that will hold the values for the x and y cross-section
    %center of masss.

    Coms = zeros(numImages,2);




    for i = 1:numImages

        %read in the current solid x-section image.
    
        solidImage = imread(solidDir(i).name);
    
    
        %calculate the center of mass for the cross-sections.
    
        [row, col] = find(solidImage ~= 0);

        
        %calculate the column and row coordinates for the cross section
        %center of mass.
        
        Coms(i,1) = mean(col);
        Coms(i,2) = mean(row);
    
    
        %update the waitbar.

        percent_done = i/numImages;

        waitbar(percent_done, h_wait, [num2str(floor(percent_done*100), 3) ' % Complete']);           

    end;


    %save the data to the current parent image directory.

    save([currentDir AllImageSpecs.fileSeparator 'temp' AllImageSpecs.fileSeparator 'XScoms'], 'Coms');


end;




%return to parent image directory.

cd(currentDir);



waitbar(1, h_wait, 'Cross-section center of mass calculations complete');



end

