function CellSizeFilters

%this function creates an addition GUI that allows users to select
%different filters and detection methods used in Rootscan to segregate
%target objects from non-target objects.


%create the GUI figure window.

filter_window = figure('Name', 'Rootscan Data Filters', 'Units', 'normalized', ...
    'Position', [.375 .25 .25 .50], 'menubar', 'none');



%load in the current filter and detection methods settings from the main
%Rootscan programs directory.






%--------------------cortex cell size filter panel------------------------%

%create panel for cortex cell size filters.

cs_F_panel = uipanel('Parent', filter_window, 'Position', [0 0 .5 1], ...
    'BackgroundColor', [.5 .5 1]);


%define original and shift coordinates for the text box and button positioning.

xo             = 0;
xshift      = .025;
label_width  = .85;

yo           = .87;
yshift       = .08;
label_height = .05;



%create panel title.

uicontrol('Parent', cs_F_panel, 'Style', 'text', 'String', 'Cortex Cell Filters', ...
    'Units', 'normalized', 'Position', [.025 .94 1 .05], 'FontWeight', 'bold');


%create static text box to the hold the label for the cell size filter
%ediable text box (lower bound).

uicontrol('Parent', cs_F_panel, 'Style', 'text', 'String', ...
    'Smallest Cell Size (mm2)', 'Units', 'normalized', 'Position', ...
    [xo+xshift yo label_width label_height], 'FontUnits', 'normalized', ...
    'FontSize', .55, 'HorizontalAlignment', 'left');


%create editable text box used to display lower bound for cortex cell size.

cs_low_edit = uicontrol('Parent', cs_F_panel, 'Style', 'edit', 'String' , '', ...
    'Units', 'normalized', 'Position', [xo+xshift+label_width yo+(.4*label_height) .1 label_height]);



%create static text box to the hold the label for the cell size filter
%ediable text box (upper bound).

uicontrol('Parent', cs_F_panel, 'Style', 'text', 'String', ...
    'Largest Cell Size (mm2)', 'Units', 'normalized', 'Position', ...
    [xo+xshift (yo-yshift) label_width label_height], 'FontUnits', 'normalized', ...
    'FontSize', .55, 'HorizontalAlignment', 'left');


%create editable text box used to display upper bound for cortex cell size.

cs_low_edit = uicontrol('Parent', cs_F_panel, 'Style', 'edit', 'String' , '', ...
    'Units', 'normalized', 'Position', [xo+xshift+label_width (yo-yshift)+(.4*label_height) .1 label_height]);




%create static text box to the hold the label for the cell file range filter
%ediable text box (lower bound).

uicontrol('Parent', cs_F_panel, 'Style', 'text', 'String', ...
    'Minimum Cell Files', 'Units', 'normalized', 'Position', ...
    [xo+xshift (yo - (2*yshift)) label_width label_height], 'FontUnits', 'normalized', ...
    'FontSize', .55, 'HorizontalAlignment', 'left');


%create editable text box used to display lower bound for cell file range filter.

cf_low_edit = uicontrol('Parent', cs_F_panel, 'Style', 'edit', 'String' , '', ...
    'Units', 'normalized', 'Position', [xo+xshift+label_width (yo - (2*yshift))+(.4*label_height) .1 label_height]);



%create static text box to the hold the label for the cell range filter
%ediable text box (upper bound).

uicontrol('Parent', cs_F_panel, 'Style', 'text', 'String', ...
    'Maximum Cell Files', 'Units', 'normalized', 'Position', ...
    [xo+xshift (yo - (3*yshift)) label_width label_height], 'FontUnits', 'normalized', ...
    'FontSize', .55, 'HorizontalAlignment', 'left');


%create editable text box used to display upper bound for cell file range filter.

cf_high_edit = uicontrol('Parent', cs_F_panel, 'Style', 'edit', 'String' , '', ...
    'Units', 'normalized', 'Position', [xo+xshift+label_width (yo - (3*yshift))+(.4*label_height) .1 label_height]);




%create static text box to the hold the label for the cell count range 
%ediable text box (lower bound).

uicontrol('Parent', cs_F_panel, 'Style', 'text', 'String', ...
    'Minimum Cell Count', 'Units', 'normalized', 'Position', ...
    [xo+xshift (yo - (4*yshift)) label_width label_height], 'FontUnits', 'normalized', ...
    'FontSize', .55, 'HorizontalAlignment', 'left');


%create editable text box used to display lower bound for cell file range filter.

cc_low_edit = uicontrol('Parent', cs_F_panel, 'Style', 'edit', 'String' , '', ...
    'Units', 'normalized', 'Position', [xo+xshift+label_width (yo - (4*yshift))+(.4*label_height) .1 label_height]);



%create static text box to the hold the label for the cell cell count range
%ediable text box (upper bound).

uicontrol('Parent', cs_F_panel, 'Style', 'text', 'String', ...
    'Maximum Cell Count', 'Units', 'normalized', 'Position', ...
    [xo+xshift (yo - (5*yshift)) label_width label_height], 'FontUnits', 'normalized', ...
    'FontSize', .55, 'HorizontalAlignment', 'left');


%create editable text box used to display upper bound for cell file range filter.

cc_high_edit = uicontrol('Parent', cs_F_panel, 'Style', 'edit', 'String' , '', ...
    'Units', 'normalized', 'Position', [xo+xshift+label_width (yo - (5*yshift))+(.4*label_height) .1 label_height]);





%--------------------cortex cell size filter panel------------------------%





%create panel for Meta and proto xylem size filters.

xv_F_panel = uipanel('Parent', filter_window, 'Position', [.5 0 .5 .5], ...
    'BackgroundColor', [.9 .9 .9]);



%create panel for lacunae detection filters.

lac_F_panel = uipanel('Parent', filter_window, 'Position', [.5 .5 .5 .5], ...
    'BackgroundColor', [.5 .5 .5]);


%create panel for cell file count and other cell data filters.











end