function ImageColors

%this function will initiate a seperate GUI window that will allow the user
%to choose all the display effects for the main GUI images and reference
%image.

global AllImageSpecs;


%define the GUI figure window based on the current screensize.

screenSize = get(0, 'ScreenSize');  

colorFig = figure('Name', 'Image Colors and Display', 'Position', ...
    [.1*screenSize(3), .1*screenSize(4), .8*screenSize(3), .8*screenSize(4)], ...
    'MenuBar', 'none', 'NumberTitle', 'off');

set(colorFig, 'Color', [1 1 1]);


%define current directory.

currentDir = cd;

%retrieve the GUI display color set by user or set the default color.
%our default color will be light blue.

directory = which('Rootscan_session');
directory(end-17:end)            = [];




cd(directory);




%--------------define the initial color and dilation settings-------------%
%--------------define the initial color and dilation settings-------------%
%--------------define the initial color and dilation settings-------------%

%determine if the .mat file containg the color and dilation settings exist.

raw_colorcode = [100 190 127 125 0 25];



switch exist('REFhighColors.mat', 'file')

    case 2 %the file exists. 

        %open it.
        
        load('REFhighColors.mat');
        
        
    case 0 %the file does not exist. define arbitrary values for colors and dilation settings.

        
    %define initial colors for highlighted image.

    AllImageSpecs.high = [255 200 0; 255 0 0; 0 0 255; 0 255 0; 0 0 0; 0 0 222];


    %define initial reference image colors.

    AllImageSpecs.refColors = [255 200 0; 255 0 0; 0 0 255; 0 255 0; 120 100 0; 0 0 222];

    
    %define initial reference image thickness.
    
    AllImageSpecs.PerimThick = [1 1 1];

    
    
end;



%read in all images used to change the image output options.


%read in image for the highlighted xs image.  this image is the 1-d color
%coded image formulated throughout the analysis process but is not shown.
%it is recoded and printed to file.

highlight_image = imread([directory 'Highlight.190HighA.tif']);


%create image handle for the 3-d highlighted image.

im_High_handle = 0;


%create empty 3-d image for the highlighted image.

highlight3d_image = ones([size(highlight_image) 3], 'uint8')*255;



%read in all image associated with the reference image.


%original cross-section image.

grayscaleREF = imread([directory 'CROSS_SECTION.190HighA.tif']); 


%cross-section perimeter image.

XSperim                     = imread([directory 'xsPerim.tif']); 


%lateral perimeter image.

Latperim                   = imread([directory 'LatPerim.tif']); 


%stele perimeter image.

Steleperim               = imread([directory 'stelePerim.tif']); 




%define the dilated images (these will change with every slider move).  


%x-section dilation.

XSdilate       = imdilate(XSperim, strel('disk', AllImageSpecs.PerimThick(1))); 


%lateral dilation.

Latdilate     = imdilate(Latperim, strel('disk', AllImageSpecs.PerimThick(2))); 


%stele dilation.

Steledilate = imdilate(Steleperim, strel('disk', AllImageSpecs.PerimThick(3))); 




%define the original image.

ref3d_image = ones([size(highlight_image) 3], 'uint8')*255;



%create image handle for the 3-d reference image.

im_REF_handle = 0;



%make 3-d grayscale image.

for i = 1:3
    ref3d_image(:,:,i) = grayscaleREF;
end;


%assign all perimeter colors and dilations now.

perimvect         = cell(3,1);
perimvect{1,1}    = 'XSperim';
perimvect{2,1}   = 'Latperim';
perimvect{3,1} = 'Steleperim';


%define the number of pixels in the highlighted image.

numELM = numel(highlight_image);


%dilate each perimeter boundary using the initial dilation settings.

for i = 1:3
    
    %dilate each boundary now.
    
    dilatePerim = imdilate(eval(perimvect{i,1}), strel('disk', AllImageSpecs.PerimThick(i)));
    
    
    %find the index of the boundary.
    
    index = find(dilatePerim == 1);
    
    
    %color the initial 3-d reference image with the current perimeter color
    %settings.
    
    
    %red channel.
    
    ref3d_image(index)              = AllImageSpecs.refColors(i+3,1); 
    
    
    %green channel.
    
    ref3d_image(index + numELM)     = AllImageSpecs.refColors(i+3,2); 
    
    
    %blue channel.
    
    ref3d_image(index + (2*numELM)) = AllImageSpecs.refColors(i+3,3); 

    
end;



%assign all colors to the aerenchyma, meta and proto xv areas.

for i = 1:3
    
    
    %find the index of each region.
    
    index = find(highlight_image == raw_colorcode(i));
    
    
    %color initial 3-d reference with the current region color settings.
    
    
    %red channel.
    
    ref3d_image(index)              = AllImageSpecs.refColors(i,1); 
    
    
    %green channel.
    
    ref3d_image(index + numELM)     = AllImageSpecs.refColors(i,2); 
    
    
    %blue channel.
    
    ref3d_image(index + (2*numELM)) = AllImageSpecs.refColors(i,3); 
    
    
end;
  



%-------------------------------------------------------------------------%    
%-------------------------------------------------------------------------%   
%-------------------------set up GUI components---------------------------%
%-------------------------------------------------------------------------%
%-------------------------------------------------------------------------%




%define image axis to display image.

imageAxes = axes('Parent', colorFig, 'Units', 'normalized', ...
    'Position', [.025 .025 .55 .95], 'visible', 'off');



%set up a series of panels for the placement of uicontrol objects.


%define the master panel.

masterPanel = uipanel('Parent', colorFig, 'Units', 'Normalized', 'Position', [.6 0 .4 1]);


%define top subpanel.  the top subpanel will contain all buttons and tabs
%related to the user interaction options for changing any image display
%effects in the reference image.

referenceImagePanel = uipanel('Parent', masterPanel, 'Units', 'Normalized', ...
    'Position', [0 .6 1 .4]);


%define middle subpanel. the middle subpanel will contain all buttons and
%tabs related to the user interaction options for changing any image
%display effects in the color coded image called XsectionCode.format.

highlightXSPanel = uipanel('Parent', masterPanel, 'Units', 'Normalized', ...
    'Position', [0 .20 1 .4], 'BackgroundColor', [.7 .7 .7]);


%define buttom subpanel. the button subpanel will contain all buttons and
%tabs related to the user interaction options for changing any image
%display effects in the cortical cell file images.

%highlightcellFilePanel = uipanel('Parent', masterPanel, 'Units', 'Normalized', ...
  %  'Position', [0 .1 1 .1], 'BackgroundColor', [.5 .9 .5]);



%define finished button.

uicontrol('Parent', masterPanel, 'Units', 'normalized', ...
    'Position', [.75 .02 .25 .05], 'FontUnits', 'normalized', 'FontSize', .7, ...
    'String', 'Finished', 'Callback', @finishedcallback);






%place the GUI components into the GUI figure now according to their
%subpanel parent.





%make label for perimeter type label.

uicontrol('Parent', referenceImagePanel, 'Units', 'normalized', ...
    'Position', [.025, .88, .95 .1], 'FontUnits', ...
    'Normalized', 'FontSize', .7, 'String', 'Reference Image Color Options', ...
    'HorizontalAlignment', 'left', 'Callback', @refImagebuttoncallback);





%make three more subpanel to hold the perimeter thickness modification
%keys.


%label = red channel.

uicontrol('Parent', referenceImagePanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.35 .63 .15 .075], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'FontSize', .6, 'String', 'Red');


%label = green channel.

uicontrol('Parent', referenceImagePanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.35 .48 .15 .075], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'FontSize', .6, 'String', 'Green');


%label = blue channel.

uicontrol('Parent', referenceImagePanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.35 .33 .15 .075], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'FontSize', .6, 'String', 'Blue');




%define the GUI color sliders and accompanying text boxes for the reference image
%subpanel.  the users will click on the slider to adjust the color settings
%for the red, green and blue channels in the 3-d color map.  the value of
%the slider will be applied to the current image and the integer value of
%the slider will be displayed in the accompanying text box to the right of
%the slider.


%allocate memory for the vector containing the color slider handles.  since
%there are 3 color channels there will be 3 slider handles.

referenceColor.slider = zeros(3,1);


%define slider for red color channel.

referenceColor.slider(1) = uicontrol('Parent', referenceImagePanel, 'Style', 'slider', 'Units', 'Normalized', ...
    'Position', [.45 .65 .4 .1], 'BackgroundColor', [1 0 0]);


%define slider for green color channel.

referenceColor.slider(2) = uicontrol('Parent', referenceImagePanel, 'Style', 'slider', 'Units', 'Normalized', ...
    'Position', [.45 .50 .4 .1], 'BackgroundColor', [0 1 0]);


%define slider for the blue color channel.

referenceColor.slider(3) = uicontrol('Parent', referenceImagePanel, 'Style', 'slider', 'Units', 'Normalized', ...
    'Position', [.45 .35 .4 .1], 'BackgroundColor', [0 0 1]);


%set additional slider properties now.


%set the minumum slider value.

set(referenceColor.slider, 'Min', 0);


%set the maximum slider value.

set(referenceColor.slider, 'Max', 255);


%set the slider step.

set(referenceColor.slider, 'sliderstep', [1/255 10/255]);


%set the slider callback function

set(referenceColor.slider, 'Callback', @referenceSliderCallback);


%define vector of initial slider values.

initialVal_ref = zeros(3,1);



%allocate memory for the vector containing the text boxes accompanying each
%slider bar.  sincd there are 3 color channels there will be 3 text box
%handles.

referenceColor.text   = zeros(3,1);


%define text box for red channel.

referenceColor.text(1) = uicontrol('Parent', referenceImagePanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.87 .65 .12 .1], 'BackgroundColor', [1 1 1]);


%define text box for green channel.

referenceColor.text(2) = uicontrol('Parent', referenceImagePanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.87 .50 .12 .1], 'BackgroundColor', [1 1 1]);


%define text box for blue.

referenceColor.text(3) = uicontrol('Parent', referenceImagePanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.87 .35 .12 .1], 'BackgroundColor', [1 1 1]);



%set additional text box properties.

%set font units to normalized

set(referenceColor.text, 'FontUnits', 'Normalized');


%set font size to .9.

set(referenceColor.text, 'FontSize', .9);





%PERIMETER THICKNESS.............





%make title label for thickness options section.

uicontrol('Parent', referenceImagePanel, 'Style', 'text', ...
    'Units', 'normalized', 'Position', [.45, .14, .5 .1], 'FontUnits', ...
    'Normalized', 'FontSize', .6, 'String', 'Perimeter Dilation', ...
    'HorizontalAlignment', 'left');



%define slider for perimeter thickness adjustments.

slider_thick = uicontrol('Parent', referenceImagePanel, 'Style', 'slider', 'Units', 'Normalized', ...
    'Position', [.45 .04 .4 .1], 'BackgroundColor', [1 1 1]);


%set the maximum slide value.

set(slider_thick, 'Max', 26);


%set the slider step value.

set(slider_thick, 'sliderstep', [1/25 2/25]);


%set slider callback function.

set(slider_thick, 'Callback', @perimthickcallback);



%define initial slider value.

initSliderVal = 1;



%define text box accompanying perimeter thickness slider.

text_thick = uicontrol('Parent', referenceImagePanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.87 .04 .12 .1], 'BackgroundColor', [1 1 1], 'FontUnits', ...
    'Normalized', 'FontSize', .9, 'Min', 1);


%set the default string value to 1.

set(text_thick, 'String', 1);






%define radiobuttons for all regions to be colored by Rootscan.  when the
%user clicks on a radiobutton the region associated with label will be
%activated for color and or perimeter adjustments.


%allocate memory for radiobutton handles.

REF.radio = zeros(6,1);


%define radiobutton for aerenchyma color selection.

REF.radio(1) = uicontrol('Parent', referenceImagePanel, 'Style', 'radiobutton', ...
    'Units', 'normalized', 'Position', [.025, .74, .30 .1], ...
    'String', 'Aerenchyma', 'FontUnits', 'Normalized');


%define radiobutton for Meta xylem vessel color selection.

REF.radio(2) = uicontrol('Parent', referenceImagePanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .61, .30 .1], 'String', 'Meta XV', ...
    'FontUnits', 'Normalized');


%define radiobutton for Proto xylem vessel color selection.

REF.radio(3) = uicontrol('Parent', referenceImagePanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .47, .30 .1], 'FontUnits', 'Normalized', ...
    'String', 'Proto XV');



%make label for the different perimeters.  these labels will run down the
%left hand side of the panel.


%define radio button for x-section perimeter color and thickness selection.

REF.radio(4) = uicontrol('Parent', referenceImagePanel, 'Style', 'radiobutton', ...
    'Units', 'normalized', 'Position', [.025, .34, .30 .1], 'FontUnits', ...
    'Normalized', 'String', 'X-Section', ...
    'HorizontalAlignment', 'left');


%define radiobutton for lateral perimeter color and  thickness selection.

REF.radio(5) = uicontrol('Parent', referenceImagePanel, 'Style', 'radiobutton', ...
    'Units', 'normalized', 'Position', [.025, .21, .30 .1], 'FontUnits', ...
    'Normalized', 'String', 'Lateral', ...
    'HorizontalAlignment', 'left');


%define radiobutton for stele perimeter color and thickness selection.

REF.radio(6) = uicontrol('Parent', referenceImagePanel, 'Style', 'radiobutton', ...
    'Units', 'normalized', 'Position', [.025, .08, .30 .1], 'FontUnits', ...
    'Normalized', 'String', 'Stele', ...
    'HorizontalAlignment', 'left');


%set the radiobutton callback function.

set(REF.radio, 'Callback', @REFradiocallback);


%set the font size of the radiobutton labels.

set(REF.radio, 'FontSize', .5);


%define initial values for radiobuttons.

REFinitVal = zeros(6,1);








%set up buttons and sliders in the middle panel.






%define pushbutton for the highlighted image options panel (i.e. middle
%panel.

highlightBUTTON = uicontrol('Parent', highlightXSPanel, 'Units', 'Normalized', ...
    'Position', [.025 .87 .95 .12], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'FontSize', .5, 'String', 'Highlighted Cross-section Color Options');


%set the callback function for pushbutton.

set(highlightBUTTON, 'Callback', @highlightIMAGE);





%define text box height.

highslideHt = .1;


%define initial y-coordinate of text boxes.

highslideYo = [.70 .55 .40];


%define inital x-coordinate of text boxes.

highslideXo = .45;


%label = red channel.

uicontrol('Parent', highlightXSPanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.35 highslideYo(1)-.02 .15 highslideHt], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'FontSize', .5, 'String', 'Red');


%label = green channel.

uicontrol('Parent', highlightXSPanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.35 highslideYo(2)-.02 .15 highslideHt], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'FontSize', .5, 'String', 'Green');


%label = blue channel.

uicontrol('Parent', highlightXSPanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [.35 highslideYo(3)-.02 .15 highslideHt], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'FontSize', .5, 'String', 'Blue');



%define radiobuttons for all regions to be colored by Rootscan.  when the
%user clicks on a radiobutton the region associated with label will be
%activated for color adjustments.  these radio buttons are located in the
%middle panel.  mouse clicks on these buttons will allow user to make
%adjustments to the highlighted coded image settings.


%allocate memory for radiobutton handles.

highlight.radio = zeros(6,1);


%define radio button for aerenchyma color selection.

highlight.radio(1) = uicontrol('Parent', highlightXSPanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .70, .3 .1], 'FontUnits', 'Normalized', ...
    'String', 'Aerenchyma');


%define radio button for meta xylem vessel color selection.

highlight.radio(2) = uicontrol('Parent', highlightXSPanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .58, .3 .1], 'FontUnits', 'Normalized', ...
    'String', 'Meta XV');


%define radio button for proto xylem vessel color selection.

highlight.radio(3) = uicontrol('Parent', highlightXSPanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .46, .3 .1], 'FontUnits', 'Normalized', ...
    'String', 'Proto XV');


%define radio button for stele cell structure color selection.

highlight.radio(4) = uicontrol('Parent', highlightXSPanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .34, .3 .1], 'FontUnits', 'Normalized', ...
    'String', 'Stele Structure');


%define radio button for cortex structure color selection.

highlight.radio(5) = uicontrol('Parent', highlightXSPanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .22, .3 .1], 'FontUnits', 'Normalized', ...
    'String', 'Cortex Structure');


%define radio button for lateral color selection.

highlight.radio(6) = uicontrol('Parent', highlightXSPanel, 'Units', 'normalized', ...
    'Style', 'radiobutton', 'Position', [.025, .10, .3 .1], 'FontUnits', 'Normalized', ...
    'String', 'Lateral');


%set the font size for the radiobuttons.

set(highlight.radio, 'FontSize', .5);


%set the callback for the radiobuttons.

set(highlight.radio, 'Callback', @whichbuttoncallback);


%set the initial value of the radiobuttons.

init_highlight_radioVal = zeros(6,1);




%define the GUI color sliders and accompanying text boxes for the reference image
%subpanel.  the users will click on the slider to adjust the color settings
%for the red, green and blue channels in the 3-d color map.  the value of
%the slider will be applied to the current image and the integer value of
%the slider will be displayed in the accompanying text box to the right of
%the slider.


%allocate memory for the vector containing the color slider handles.  since
%there are 3 color channels there will be 3 slider handles.

highlight.slider = zeros(3,1);


%define slider for red color channel.

highlight.slider(1) = uicontrol('Parent', highlightXSPanel, 'Style', 'slider', 'Units', 'Normalized', ...
    'Position', [highslideXo highslideYo(1) .4 highslideHt], 'BackgroundColor', [1 0 0]);


%define slider for green color channel.

highlight.slider(2) = uicontrol('Parent', highlightXSPanel, 'Style', 'slider', 'Units', 'Normalized', ...
    'Position', [highslideXo highslideYo(2) .4 highslideHt], 'BackgroundColor', [0 1 0]);


%define slider for blue color channel.

highlight.slider(3) = uicontrol('Parent', highlightXSPanel, 'Style', 'slider', 'Units', 'Normalized', ...
    'Position', [highslideXo highslideYo(3) .4 highslideHt], 'BackgroundColor', [0 0 1]);


%set the minimum slider value.

set(highlight.slider, 'Min', 0);


%set the maximum slider value.

set(highlight.slider, 'Max', 255);


%set the slider step size.

set(highlight.slider, 'sliderstep', [1/255 10/255]);


%set the callback function for the slider.

set(highlight.slider, 'Callback', @highlightSliderCallback);


%define the initial slider values.

initialVal_highlight = cell2mat(get(highlight.slider, 'Value'));




%allocate memory for the vector containing the text boxes accompanying each
%slider bar.  sincd there are 3 color channels there will be 3 text box
%handles.

highlightText = zeros(3,1);


%define text box for red channel.

highlightText(1) = uicontrol('Parent', highlightXSPanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [(highslideXo + .42) highslideYo(1) .12 highslideHt], 'BackgroundColor', [1 1 1]);


%define text box for green channel.

highlightText(2) = uicontrol('Parent', highlightXSPanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [(highslideXo + .42) highslideYo(2) .12 highslideHt], 'BackgroundColor', [1 1 1]);


%define text box for blue channel.

highlightText(3) = uicontrol('Parent', highlightXSPanel, 'Style', 'text', 'Units', 'Normalized', ...
    'Position', [(highslideXo + .42)  highslideYo(3) .12 highslideHt], 'BackgroundColor', [1 1 1]);


%set the font units for text boxes.

set(highlightText, 'FontUnits', 'normalized');


%set the font size for text boxes.

set(highlightText, 'FontSize', .9);















%--------------CALLBACK FUNCTIONS FOR REFERENCE IMAGE OPTIONS-------------%
%--------------CALLBACK FUNCTIONS FOR REFERENCE IMAGE OPTIONS-------------%
%--------------CALLBACK FUNCTIONS FOR REFERENCE IMAGE OPTIONS-------------%















%callbacks for the reference image options.


    function refImagebuttoncallback(varargin)
        
        %clear axes now.
        
        cla;
        
        
        %show the image now.
        
        im_REF_handle = imshow(ref3d_image);
       

        
    end





%define callback for reference image radio button selection.

    function REFradiocallback(varargin)
        
                 
        %check to see which button has been selected.
        
        getREFradioVal = cell2mat(get(REF.radio, 'Value'));
        
        diffREFradio = getREFradioVal - REFinitVal;
        
        
        %set the previous button with value 1 to 0.
        
        set(REF.radio(diffREFradio < 1), 'Value', 0);
        diffREFradio(diffREFradio < 1)           = 0;
        getREFradioVal(diffREFradio < 1)         = 0;
  
        
        %reset the REFinitVal.
        
        REFinitVal = getREFradioVal;
        
        
        %set the initial conditions for the slider and static text box.
        
        set(referenceColor.slider(1), 'Value', AllImageSpecs.refColors(diffREFradio == 1,1)); %red channel.
        set(referenceColor.slider(2), 'Value', AllImageSpecs.refColors(diffREFradio == 1,2)); %green channel.
        set(referenceColor.slider(3), 'Value', AllImageSpecs.refColors(diffREFradio == 1,3)); %blue channel.

        
        set(referenceColor.text(1), 'String', AllImageSpecs.refColors(diffREFradio == 1,1)); %red channel.
        set(referenceColor.text(2), 'String', AllImageSpecs.refColors(diffREFradio == 1,2)); %green channel.
        set(referenceColor.text(3), 'String', AllImageSpecs.refColors(diffREFradio == 1,3)); %blue channel.
                    
        initialVal_ref = AllImageSpecs.refColors(diffREFradio == 1,:)';

        
    end








%define callback for perimeter dilation slider.  this function will adjust
%the dilation settings for the either the x-section, lateral or stele
%depending on which radiobutton is on.

    function perimthickcallback(varargin)
        
        
        %check to see which radio button is selected.
        
        radioIndex = cell2mat(get(REF.radio, 'Value'));
        
        radioIndex = find(radioIndex == 1);
        
        
        switch radioIndex >=4
            
            case 1
        
        
        %get the current slider value. this value will be the dilation
        %radius for imdilate using disk method.
        
        getPerimsliderVal = floor(get(slider_thick, 'Value'));
        

        %set the current dilation back to the original pixel values.
        
        dilatePerim = imdilate(eval(perimvect{radioIndex-3,1}), strel('disk', AllImageSpecs.PerimThick(radioIndex-3)));

        
        %find the indices of the old dilation.
        
        index = find(dilatePerim == 1);
        
        
        %reset the pixels now.  the dilation will disapear.
        
        ref3d_image(index)              = grayscaleREF(index); %red channel.
        ref3d_image(index + numELM)     = grayscaleREF(index); %green channel.
        ref3d_image(index + (2*numELM)) = grayscaleREF(index); %blue channel.
        
        
        
        %set the new dilation.
        
        AllImageSpecs.PerimThick(radioIndex-3) = getPerimsliderVal;
        
        
        %set slider text box to new value.
        
        set(text_thick, 'String', getPerimsliderVal);

        
        
        
        %define new dilation.
        
        dilatePerim = imdilate(eval(perimvect{radioIndex-3,1}), strel('disk', AllImageSpecs.PerimThick(radioIndex-3)));

        
        %find indices for new dilation.
        
        index = find(dilatePerim == 1);
        
        
        %apply the new dilation to image.
        
        ref3d_image(index)              = AllImageSpecs.refColors(radioIndex,1); %red channel.
        ref3d_image(index + numELM)     = AllImageSpecs.refColors(radioIndex,2); %green channel.
        ref3d_image(index + (2*numELM)) = AllImageSpecs.refColors(radioIndex,3); %blue channel.
        
        
        
        %set the Cdata for image handle. the new setting will be displayed
        %now.
        
        set(im_REF_handle, 'Cdata', ref3d_image);
        
        

        %set the new dilation image.
        
        switch radioIndex
            
            case 4 %assign current dilation to cross-section dilation image.
                
                XSdilate    = dilatePerim;
                
            case 5 %assign current dilation to lateral dilation image.
                
                Latdilate   = dilatePerim;
                
            case 6 %assign current dilation to stele dilation image.
                
                Steledilate = dilatePerim;
                
                
        end;
        
        
        
        
        
        
        end;
        
        
    end







%define function for the reference image color options.






%set the callback for the reference image slider step (color options).

    function referenceSliderCallback(varargin)
        
        %check to see which radio button is selected.
                
        radioIndex = cell2mat(get(REF.radio, 'Value'));
        
        radioIndex = find(radioIndex == 1);
       
        
        
        
        %define the color slider values.
                        
        sliderval = floor(cell2mat(get(referenceColor.slider, 'Value')));
        
        diffval = abs(sliderval - initialVal_ref);
        
        
        set(referenceColor.text(diffval ~= 0), 'String', sliderval(diffval ~= 0));
        
        initialVal_ref = sliderval;
        

        %change the initial setting.
        
        AllImageSpecs.refColors(radioIndex, find(diffval ~= 0)) = sliderval(diffval ~= 0);
        
        
        %there are two color modes for this panel.
        
        %mode 1: we are coloring aerenchyma, meta and proto xv.
        %mode 2: we are coloring x-section, lateral and stele perimeters.
        

        
        switch radioIndex < 4
            
            case 1 %mode 1
                
                
                %find the indices for the object.
                
                index = find(highlight_image == raw_colorcode(radioIndex));
                
                
                %assign new colors to object. 
                
                ref3d_image(index)              = AllImageSpecs.refColors(radioIndex,1); %red channel.
                ref3d_image(index+numELM)       = AllImageSpecs.refColors(radioIndex,2); %green channel.
                ref3d_image(index + (2*numELM)) = AllImageSpecs.refColors(radioIndex,3); %blue channel.

        
                set(im_REF_handle, 'Cdata', ref3d_image);
                
                
            case 0 %mode 2
                
                
                %select the image associated with radiobutton that is in
                %focus.
                
                switch radioIndex
                    
                    case 4 %select cross-section dilation image.
                        
                        imdilate = XSdilate;
                        
                    case 5 %select lateral dilation image.
                        
                        imdilate = Latdilate;
                        
                    case 6 %select stele dilation image.
                        
                        imdilate = Steledilate;
                        
                        
                end;
                
            
                %find the indices for the dilated image in focus.
                
                index = find(imdilate == 1);
                
                
                %assign new colors to the dilated perimeter.
                
                ref3d_image(index)              = AllImageSpecs.refColors(radioIndex,1); %red channel.
                ref3d_image(index+numELM)       = AllImageSpecs.refColors(radioIndex,2); %green channel.
                ref3d_image(index + (2*numELM)) = AllImageSpecs.refColors(radioIndex,3); %blue channel.

        
                %set cdata in the current image handle display the image 
                %in the image axes.
                
                set(im_REF_handle, 'Cdata', ref3d_image);
                
                
                
                
        end;
        
        

        
        
        
        
        
    end










%place all button callbacks for the middle panel here.



%set the callback for the highlighted image slider step and associated functions.  this function
%will update the static text boxes showing the integer values for the rgb
%image options and will change the output image colors on the screen.


    function highlightIMAGE(varargin)
        
        %clear axes.
        
        cla;
        
        
        %take the coded image in 1-d and code it in 3-d.
                
        totdims = numel(highlight_image);

        
        for I = 1:6
            
            %highlight each region.
            
            index = find(highlight_image == raw_colorcode(I));
            
            highlight3d_image(index)               = AllImageSpecs.high(I,1);
            highlight3d_image(index+totdims)       = AllImageSpecs.high(I,2);
            highlight3d_image(index + (2*totdims)) = AllImageSpecs.high(I,3);


            im_High_handle = imshow(highlight3d_image);
        
        
        
        end;
        

    end




%define a function that will reset the values of all other radio buttons
%other than the one currently selected.

    function whichbuttoncallback(varargin)
        
       
        %get the values of the current radio buttons.
        
        currentVal = cell2mat(get(highlight.radio, 'Value'));
        
        
        %calculate the difference between the current values and previous
        %values.  this will determine which button is in focus.
        
        diffVal = currentVal - init_highlight_radioVal;
        
       
        %set the previous button with value 1 to 0.
        
        set(highlight.radio(diffVal < 1), 'Value', 0);
        diffVal(diffVal < 1)                      = 0;
        currentVal(diffVal < 1)                   = 0;
         
        %set the current button values to the initial conditions.
                
        init_highlight_radioVal = currentVal;
        
        
        
        %set the initial conditions for the slider and static text box.
        
        set(highlight.slider(1), 'Value', AllImageSpecs.high(diffVal == 1,1)); %red channel.
        set(highlight.slider(2), 'Value', AllImageSpecs.high(diffVal == 1,2)); %green channel.
        set(highlight.slider(3), 'Value', AllImageSpecs.high(diffVal == 1,3)); %blue channel.

        
        set(highlightText(1), 'String', AllImageSpecs.high(diffVal == 1,1)); %red channel.
        set(highlightText(2), 'String', AllImageSpecs.high(diffVal == 1,2)); %green channel.
        set(highlightText(3), 'String', AllImageSpecs.high(diffVal == 1,3)); %blue channel.
        
        initialVal_highlight = AllImageSpecs.high(diffVal == 1,:)';
        
    end





%define the callback for the slider windows associated with the highlighted
%cross-section image.  when the slider is moved forward or backward in the
%slider window the color settings are changed in the slider text window and
%the cross-section image object changes colors also.


    function highlightSliderCallback(varargin)
        
        
        %get the current value of the highlight color slider field.
        
        sliderval = floor(cell2mat(get(highlight.slider, 'Value')));
        
        
        %calculate the difference between the current slider values and
        %previous slider values.
        
        diffval = abs(sliderval - initialVal_highlight);
        
        
        %change the text box associated with the action in the current
        %slider window.
        
        set(highlightText(diffval ~= 0), 'String', sliderval(diffval ~= 0));
        
        
        %redefine new initial slider values for all color slider windows.
        
        initialVal_highlight = sliderval;
                
        
        
        %check to see which radio button is selected.
        
        currentVal = cell2mat(get(highlight.radio, 'Value'));

        currentValIndex = find(currentVal == 1);
        
        
        %change the initial setting.
        
        AllImageSpecs.high(currentValIndex, find(diffval ~= 0)) = sliderval(diffval ~= 0);
        
        
        %define the index for the current object.
      
        index = find(highlight_image == raw_colorcode(currentValIndex));
           
        
        %apply the new colors to the object.
        
        highlight3d_image(index)              = AllImageSpecs.high(currentValIndex,1);
        highlight3d_image(index+numELM)       = AllImageSpecs.high(currentValIndex,2);
        highlight3d_image(index + (2*numELM)) = AllImageSpecs.high(currentValIndex,3);

        
        %display the image with the new settings.
        
        set(im_High_handle, 'Cdata', highlight3d_image);
                
                
        
        
    end





    function finishedcallback(varargin)
        
        %save the data to file.
        
        save('REFhighColors', 'AllImageSpecs');

        cd(currentDir);
        
        %delete current figure.
        
        delete(colorFig);
        
    end









end