function Redo_Thresholding(varargin)

%this function will perform a redo of the image thresholding assuming the
%user selected another statistical measure to binarize the grayscale image.

global   AllImageSpecs; %structure containing all image specifications.
global        DirSpecs; %structure containing all directory specifications.
global     data_matrix; %data matrix.
global time_efficiency; %time efficiency matrix.

%ask the user to select the image directory for their batch thresholding
%redo.

directory = uigetdir;


%go to directory selected by user.

cd(directory);


%load the pixel calibration parameters.

calib_vals = load([directory  AllImageSpecs.fileSeparator' 'CALIB_MAT.mat']);

calib_area            = calib_vals.calibprecis(1).*calib_vals.calibprecis(2);

calib_length       = (calib_vals.calibprecis(1)+calib_vals.calibprecis(2))/2; 

precision                                        = calib_vals.calibprecis(3); 


AllImageSpecs.calib_area                                        = calib_area;



%define a log file used to track the progress of the redo process.  if the
%file exists in the current directory then load that file and resume the
%batch processing from the current iteration.

%determine if the log file exists.


%define the current rootscan directory.

programs_dir                   = which('manual_lacunae_selection.m');
index = find(programs_dir == AllImageSpecs.fileSeparator, 1, 'last');
programs_dir((index+1):end)                                     = [];



log_exist = exist([directory AllImageSpecs.fileSeparator 'thresholding_log.mat'], 'file');



switch log_exist == 0
    
    case 0
        
        %the file exists. load the file now.
        
        %before resuming the batch thresholding ask user if they would like
        %to resume their analysis or start over.
        
        user_choice = questdlg('Would you like to resume batch thresholding', ...
            'Resume Progress', 'Yes', 'No', 'Yes');


        switch isempty(user_choice)

            case 1

                user_choice = 'Yes';

        end;    
        
        
        switch user_choice
            
            case 'Yes'
        
                %resume batch thresholding.
                
                
                %allocate memory for the log file based on the number of images in
                %the current image directory.
                
                
                %load in the data matrix.
                
                data_matrix = load([directory AllImageSpecs.fileSeparator 'DATA_MAT.mat']);
                data_matrix                                     = struct2cell(data_matrix);
                data_matrix                                             = data_matrix{1,1};                      
                
        
                thresh_log_f = load([directory AllImageSpecs.fileSeparator 'thresholding_log.mat']);
                thresh_log                                                = thresh_log_f.thresh_log;

                
                %load the threshold neighborhood settings in the current
                %image directory.
                
                loadthreshMethod  = load([directory AllImageSpecs.fileSeparator 'threshMethod.mat']);
                thresh_method                                       = loadthreshMethod.thresh_method;
                AllImageSpecs.thresh_method                              = thresh_method.window_size;    

                
            case 'No'
                
                %start over.
                
                %allocate memory for the log file based on the number of images in
                %the current image directory.

                
                %load in the data matrix.
                
                data_matrix = load([directory AllImageSpecs.fileSeparator 'DATA_MAT.mat']);
                data_matrix                                     = struct2cell(data_matrix);
                data_matrix                                             = data_matrix{1,1};        


                %set the current thresh_log value to 1. start at the beginning.

                thresh_log = 1;
                
                
                %define the current threshold setting defined in the rootscan
                %GUI.
                
                loadthreshMethod = load([programs_dir AllImageSpecs.fileSeparator 'threshMethod.mat']);
                thresh_method                                         = loadthreshMethod.thresh_method;
                AllImageSpecs.thresh_method                                = thresh_method.window_size;    
                
                
                %save the current method in the current image directory.
                
                save([directory AllImageSpecs.fileSeparator 'threshMethod'], 'thresh_method');

                
                
        end;
        

    case 1
        
        %the file does not exist. make a log file now.
        
        %allocate memory for the log file based on the number of images in
        %the current image directory.
        
        data_matrix = load([directory AllImageSpecs.fileSeparator 'DATA_MAT.mat']);
        data_matrix                                     = struct2cell(data_matrix);
        data_matrix                                             = data_matrix{1,1};        

              
        %set the current thresh_log value to 1. start at the beginning.
        
        thresh_log = 1;
                      
        
        %define the current threshold setting defined in the rootscan
        %GUI.

        loadthreshMethod = load([programs_dir AllImageSpecs.fileSeparator 'threshMethod.mat']);
        thresh_method                                         = loadthreshMethod.thresh_method;
        AllImageSpecs.thresh_method                                = thresh_method.window_size;           

        
        
end;


%save the threshold log data.

save([directory AllImageSpecs.fileSeparator 'thresholding_log'], 'thresh_log');


DirSpecs.thresh_log = thresh_log;


%determine the current iteration.

current_iteration = thresh_log;


%determine the total number of images.

total_images = size(data_matrix,1);



%load the time efficiency matrix.

time_efficiency = load([directory AllImageSpecs.fileSeparator 'time_efficiency.mat']);
time_efficiency                                        = struct2cell(time_efficiency);
time_efficiency                                                = time_efficiency{1,1};




%define the current analysis mode.

DirSpecs.batch_mode  = 2;
DirSpecs.programMode = 0;

%run the automated x-section binary conversion code function here:  
    
binary_xs_driver(current_iteration, total_images);  





end