function Rootscan_session(program_mode)

%this function will handle the main workflow of the Rootscan software
%package.  user accesses this function by selecting an image file or image
%directory in the Rootscan main menu bar at the top of the main GUI window
%initiated the in script called A_ROOTSCAN_1BETA.m.  This function will set
%up the GUI layout, load in all applicable data matrices and data
%specifications and perform the major task of RootScan, which is the
%complete analysis of an image or directory of images.


%There are many global variables Rootscan is going to utilized since these
%variables are either constant or their class and usage will remain static.
%all other variables that do not meet this criteria are deemed local
%variables in their respective functions.





%set up the data display text, cortex interval (region) matrix and figure
%handles as globals.
   
global f_fig_handle; %this is a structure that holds all the GUI handles for
                     %panels, buttons, etc....


%set up the main GUI display images and their axes as global.

global          get_ref_cdata; %this is the cdata used to display the reference image.
global           ref_axes_obj; %this is the reference axes object for reference image.
global          main_axes_obj; %this is the main axes object for main GUI image.
global get_ref_cdata_standard; %standard reference image for xv selection process.
global                 h_wait; %waitbar handle used to track the progress of different processes.


%define the action images that are used over again in RootScan to save
%memory.  These images have a constant size and class.  There is no
%changing of classes for these images.  If it is initialized as a double
%precision it will remain a double precision and so on.


global  X_section_gray; %this is the truncated grayscale image.
global X_section_solid; %this is the solid image of the cross section.
global        X_binary; %this is the binary equivalent.

    
global Coms; %matrix of all x-section center of mass coordinates.   
    


%set up the cortex interval handles, mode, dataspecs, color specifactions, 
%automated options, image output specs, image specs directory partition,
%image AllImageSpecs.format and threshold method type as global structure.  Also place
%the color values and tags for the aerenchyma and xv selection display.

global AllImageSpecs; %image specifications.

AllImageSpecs.image_name  = 0; %current image name.
AllImageSpecs.format      = 0; %current image format.



%define the color codes and tags for the aerenchyma and xv highlighted images.

defAerenXVColors;
 


%define the image name, batch iteration, current directory name and pathway as global.
   
global DirSpecs; %structure containing all directory specifications.

DirSpecs.programMode = program_mode; %current processing mode
DirSpecs.dir_name               = 0; %current image directory.
DirSpecs.directory_name         = 0; %define current image directory path. 
DirSpecs.iteration              = 0; %current batch iteration.



%define all data matrices for a particular directory as global.
    
global     data_matrix; %data cell matrix
global     approx_data; %approximation cell matrix
global   ccw_thickness; %cortex cell wall thickness matrix
global time_efficiency; %time efficiency matrix.

    
    
ref_axes_obj = 0;
        

%define image analysis specifications.
    
    
%(1) find the path to the root scan main programs directory. (2) find 
%the last file break in the directory path. (3) truncate directory path
%beyond the last file break.
    
pathway                                     = which('Rootscan_session.m'); %(1) 
    
find_last_break = find(pathway == AllImageSpecs.fileSeparator, 1, 'last'); %(2)
    
DirSpecs.pathway                             = pathway(1:find_last_break); %(3) 

        
    
%determine the identity of file or directory and load in (or define new) 
%cell arrays for data storage.

[data_matrix, ccw_thickness, total_images, time_efficiency, approx_data]  = declare_arrays;    
    
    
%define all gui panels, buttons and graphical display handles.

define_gui_components;


%set GUI callback for redo button options.  These
%buttons were define in the above function called : 'define_gui_components'
    
set(f_fig_handle.redobuttondropdown, 'callback', @redobuttoncallback); 



%disable all image evaluation controls now.

set(f_fig_handle.checkGroup1(1,:), 'Enable', 'off');
set(f_fig_handle.checkGroup2(1,:), 'Enable', 'off');
set(f_fig_handle.checkGroup3(1,:), 'Enable', 'off');

set(f_fig_handle.editGroup2, 'Enable', 'off');
set(f_fig_handle.editGroup3, 'Enable', 'off');

set(f_fig_handle.editLabel, 'Enable', 'off');





%set callback functions for skip image button.
    
set(f_fig_handle.skipImageButton, 'callback', @skipImageCallback);    
  

   

%---------------------------start the analysis----------------------------%
%---------------------------start the analysis----------------------------%
%---------------------------start the analysis----------------------------%


%start the analysis. this loop contains the meat of the program.

%---------------------------start the analysis----------------------------%
%---------------------------start the analysis----------------------------%
%---------------------------start the analysis----------------------------%

        


%this program has been altered to include a batch processing option for the 
%x-section thresholding algorithm.  this will allow the user to step away from 
%the program and do other things until all images have been converted from 
%256-grayscale to their binary equivalents.  


%define the starting batch iteration based on the current incomplete data
%matrix (if in batch mode).
    
switch program_mode
        
    case -2 %directory mode. current starting batch iteration depends on incomplete data matrix.
    
        
        current_iteration = length(find(cell2mat(data_matrix(:,4)) ~= 0))+1;

        
    case -1 %single file mode.  starting batch iteration = 1.
            
        current_iteration = 1;
        total_images   = 1;
            
end;

  

%---------begin--------RGB to grayscale conversion----------begin---------%

%initialize waitbar for the image normalization.

h_wait = waitbar(0, 'RGB to Grayscale Conversion Process Initialization....');


%batch convert all rgb images to grayscale and fill in some data columns.

rgbconvertDIR(current_iteration, total_images);
   

%delete the current waitbar.

close(h_wait);


%----------end---------RGB to grayscale conversion-----------end----------%



%update tooltipstring for phase i: currently in progress.
    
set(f_fig_handle.status(1), 'TooltipString', 'In Progress');


%disable all done radiobuttons except the one associated with x-section segmentation.
    
set(f_fig_handle.done_buttons([1:3 5:6]), 'Enable', 'off'); 








%phase 1: cross-section segmentation.
        
segment_xs(current_iteration, total_images, program_mode);


%update tooltipstring for phase i: Completed.
    
set(f_fig_handle.status(1), 'TooltipString', 'Completed');

    
%set the value of the x-section done button to 1 (i.e. are finished with
%this step for the entire directory).

set(f_fig_handle.done_buttons(4), 'Value', 1);
    
  

%--------begin--------image normalization alogorithm--------begin---------%

%initialize waitbar for the image normalization.

h_wait = waitbar(0, 'Initializing Image Normalization Process....');



switch program_mode
        
	case -2
    
        %define image dimension normalization function here.

        imageDIMnorm;
        
end;
  

%close  the current waitbar.

close(h_wait);

%---------end---------image normalization alogorithm---------end----------%






%-------begin-------cross-section-center of mass calcs-------begin--------%

%initialize waitbar for cross-section center of mass calculations.

h_wait = waitbar(0, 'Initializing Cross-section center of mass calculations....');


%place the automatic center mass calculation function here.
    
COMsCalc;
    

%delete the current waitbar.

close(h_wait);

%--------end--------cross-section-center of mass calcs--------end---------%
    

    
%you should place more functions like this here too to increase the
%runtime efficiency when the user is actively interacting with the
%program.
    


%%------------------------------------------------------------------------%
%%------------------------------------------------------------------------%
%%------------------------------------------------------------------------%
%%------------------------------------------------------------------------%


%determine the number of images are currently in the sub-directory: 'x_section_binary'
    
switch program_mode
        
    case -2 %directory mode. batch iteration depends on cell arrays.
        
        %determine the number of image binary files in sub-directory.

        current_iteration     = numel(dir([DirSpecs.directory_name ...
            '/X_section_binary/XS_binary.*'])) + 1;
 
        
    case -1 %single file mode. batch iteration = 1.
            
        current_iteration = 1;
            
end;
    



clc;
  


%disable all done radiobuttons now.
    
set(f_fig_handle.done_buttons, 'Enable', 'off'); 
    

%update tooltipstring for phase II: currently in progress.
    
set(f_fig_handle.status(2), 'TooltipString', 'In Progress');


%define the current analysis mode.

DirSpecs.batch_mode = 1;


%run the automated x-section binary conversion code function here:  
    
binary_xs_driver(current_iteration, total_images);  
  

%update tooltipstring for phase II: currently in progress.
    
set(f_fig_handle.status(2), 'TooltipString', 'Completed');



%--------begin-------check binary images for accuracy--------begin--------%

%initialize waitbar for the image normalization.

h_wait = waitbar(0, 'Initializing Binay Image Validation Process....');


   
%check the binary files to determine if they were converted to binary
%AllImageSpecs.format correctly.

switch program_mode

    
    case  -2

        checkBinary;
  
end;
 

%delete the current waitbar.

close(h_wait);

%---------end--------check binary images for accuracy---------end---------%  





%proceed to the rest of the analysis.  there are 4 remaining steps for the
%successful x-section analsyis.  they are as follows:
 
%1. lateral segmentation if applicable.
 
%2. automatic and manual stele/cortex segmentation.
 
%3. automatic and manual aerenchyma selection process.
 
%4. automatic and manual xylem vessel selection process (both meta and
%proto xylem vessels are differentiated).





%%------------------------------------------------------------------------%
%%------------------------------------------------------------------------%
%%------------------------------------------------------------------------%
%%------------------------------------------------------------------------%






%find the indices for the images that need to be analyzed.

switch program_mode

    
    case -2 %directory mode.  find all incompleted images.
    
        [iteration, indvect] = findindices;


    case -1 %single file mode. iteration  = 1.
        
        indvect   = 1;
        iteration = 1;

end;







%-------------------------------------------------------------------------%
%-------------------------------------------------------------------------%




%pre-load blank images as image axes object.  this image will completely
%white. later the cdata will be set to the respective pixel values as the
%user interacts with the program. this should be faster than clearing hte
%image axes and displaying another image using the function: imshow.

clc;  



%allocate memory for global image variables that are used in the phase 3
%batch process.

ImageAllocate;



%define the x and y center of mass matrix here.
     
COM = load([cd AllImageSpecs.fileSeparator 'temp' ...
    AllImageSpecs.fileSeparator 'XScoms']);

COM                             = COM.Coms;



%highlight the current phase.

%update tooltipstring for phase III: currently in progress.
    
set(f_fig_handle.status(3), 'TooltipString', 'In Progress');


%get the current background color of phase II.

phaseIII_color  = get(f_fig_handle.status(3), 'BackgroundColor');
set(f_fig_handle.status(1:3), 'BackgroundColor', phaseIII_color);
        set(f_fig_handle.status(3), 'BackgroundColor', [0 1 .3]);


% disable the x-section done button and lateral isolation done buttons.

set(f_fig_handle.done_buttons(4:5), 'Enable', 'off');





%start the batch processing for phase 3


for i = 1:size(indvect,1)

    
    %define current batch iteration.
    
    DirSpecs.iteration = indvect(i,1);
    
    
    %display the number of images remaining.
        
    num_remain =  size(indvect,1) - i + 1;
        
    set(f_fig_handle.status(4), 'String', [num2str(num_remain) ' Images Remaining' ]);
    
    
    %display the percent completed.
    
    set(f_fig_handle.status(5), 'String', [num2str(100*(DirSpecs.iteration-1)/max(indvect), '%3.0f') ' % Complete']);
    
    
    
    %reset rate image drop down menu. and user comments text box to initial
    %string.
    
    
    set(f_fig_handle.comments, 'String', '');

    

    %display image name and variable headers for the radial cell file count
    %and cortical cell count.

    image_name  = data_matrix{DirSpecs.iteration,1};
    
    
    image_name2 = image_name;
    index = find(image_name2 == '.', 1, 'last');
    image_name2 = [image_name2(1:index) 'tif'];
    
    
    set(f_fig_handle.image_vars(1), 'String', image_name); 

            set(f_fig_handle.image_vars(7), 'String', '');
    
            set(f_fig_handle.image_vars(8), 'String', '');    
    
    
    
    %turn all buttons to off position.

    
    
    %read in all the images used for the rest of the steps for each sample.
    
    X_section_gray        = imread(['X_section_segments' ...
        AllImageSpecs.fileSeparator 'XS.' image_name]);
    
    X_section_solid = imread(['X_section_segments' ...
        AllImageSpecs.fileSeparator 'SOLID_XS.' image_name]);
    
    X_binary         = imread(['X_section_binary' ...
        AllImageSpecs.fileSeparator 'XS_binary.' image_name2]);
    
    
    %define the center of mass for the current cross-section image.
    
    Coms = COM(DirSpecs.iteration,:);
    
    
    %reset reference image.
    
    get_ref_cdata(:,:) = 0;

    
    %disable all done radiobuttons now.
    
    set(f_fig_handle.done_buttons, 'Enable', 'off'); 

    
    
    
    
    
    
%-------------------execute lateral segmentation step---------------------%      
%-------------------execute lateral segmentation step---------------------%
%-------------------execute lateral segmentation step---------------------%








    %execute manual lateral segmentation step if the automated settings
    %are turned off or if the skip image button has not been pushed by
    %user.
    
    %check for skipped image.   
    
    skippedImage = strcmp(data_matrix{DirSpecs.iteration,end}, 'skipped'); 

    switch ((AllImageSpecs.automated_settings(2)*AllImageSpecs.automated_settings(end) == 0) ...
            & (skippedImage ~= 1)) 
        
    	case 1
        
            %set the foreground color of the lateral step label to green.
            
            set(f_fig_handle.step_label(5), 'ForegroundColor', [0 .7 0]); 
        
            
            %start the clock    
            
            tic; 
        
        
            %execute the lateral isolation step.
        
            lateral_segmentation;  
        
        
            %record the execution time.
                                                            
            time_efficiency{DirSpecs.iteration, 3}                = toc; 
                                 
                                 
            %set the foreground color of the lateral step label to black.    
        
            set(f_fig_handle.step_label(5), 'ForegroundColor', [0 0 0]); 

            
            
            
     end;
        
    
     
     
     
     
     

%----------------execute automatic stele/cortex segmentation--------------%     
%----------------execute automatic stele/cortex segmentation--------------%
%----------------execute automatic stele/cortex segmentation--------------%









    %auto-segmentation: stele/cortex segmentation.
    
    %this function will automatically segment the stele region from the cortex
    %region using simple statistics and mathematical manipulation.  this
    %function will not execute if the skipped image button has been pushed
    %for image.
    

    %check for skipped image.
    
    skippedImage = strcmp(data_matrix{DirSpecs.iteration,end}, 'skipped'); 
    
    
    switch skippedImage
        
        case 0 %execute automatic stele/cortex segmentation step
    
            %set the foreground color of the stele step label to green. 
            
            set(f_fig_handle.step_label(4), 'ForegroundColor', [0 .7 0]);            
             
            
            %start the clock. 
            
            tic; 
            
            
            %perform automatic stele segmentation.  
            
            automatic_stele_segmentation;  
            
            
            %record the execution time.
            
            time_efficiency{DirSpecs.iteration, 4} = toc; 
        
            
            %execute manual stele/cortex segmentation step if the automated
            %settings are turned off.   
    
            switch (AllImageSpecs.automated_settings(3)*AllImageSpecs.automated_settings(end) == 0) 
    
                case 1
    
                    %manual-segmentation: stele/cortex segmentation.  
        
                    [cortexData, xv_data] = manual_stele_segmentation;  
    
            end;
    
            
            %set the foreground color of the stele step label to black. 
            
            set(f_fig_handle.step_label(4), 'ForegroundColor', [0 0 0]);      
            
    end;
    
    
    
    
    

    
%--------------------execute manual aerenchyma selection------------------%    
%--------------------execute manual aerenchyma selection------------------%    
%--------------------execute manual aerenchyma selection------------------%    
        







    %execute manual aerenchyma  selection step if the automated settings
    %are turned ofF.  this function will not execute if the skipped image
    %button has been pushed for image.
        
    skippedImage = strcmp(data_matrix{DirSpecs.iteration,end}, 'skipped');

    switch ((AllImageSpecs.automated_settings(4)*AllImageSpecs.automated_settings(end) == 0) ...
            & (skippedImage ~= 1)) 
    
        case 1
        
            %set the foreground color of the lacunae step label to green. 
            
            set(f_fig_handle.step_label(3), 'ForegroundColor', [0 .7 0]); 
            
            
            %start the clock  
            
            tic; 
            
            
            %execute manual aerenchyma detection function.
            
            [cortexData, lacunae_data] = manual_lacunae_selection(cortexData);
    
            
            %record the time required for execution of function.
            
            time_efficiency{DirSpecs.iteration, 8} = toc; 
            
            
            %set the foreground color of the lacunae step label to black.
            
            set(f_fig_handle.step_label(3), 'ForegroundColor', [0 0 0]); 
            
    end;
        

    
    
  
    
    
    
    
%-----------------execute manual xylem vessel selection-------------------%    
%-----------------execute manual xylem vessel selection-------------------%    
%-----------------execute manual xylem vessel selection-------------------%








    
    %execute manual xylem vessel selection step if the automated settings
    %are turned off. this function will not execute if the skipped image
    %button has been pushed for image.
         
    skippedImage = strcmp(data_matrix{DirSpecs.iteration,end}, 'skipped');
        
    switch ((AllImageSpecs.automated_settings(5)*AllImageSpecs.automated_settings(end) == 0) ...
            & (skippedImage ~= 1)) 
    
        case 1
         
            %place the xylem vessel selection code here.

            
            %initialize skip_proto variable.
            
            skip_proto                                    = 0; 
                   
            
            %start clock
            
            tic;                                               
            
                                                                  
            %define standard image for xylem vessel step.
            
            get_ref_cdata_standard            = get_ref_cdata;

            
            %execute the manual xylem vessel selection function.
            
            xv_data   = manual_xv_selection(xv_data, skip_proto);
    
            
            %stop clock and record time required for manual xylem vessel selection.
            
            time_efficiency{DirSpecs.iteration, 9}            = toc; 
            
            
            %set the foreground color of the proto xv step label to green. 
            
            set(f_fig_handle.step_label(1), 'ForegroundColor', [0 0 0]); 
            
            
    end;

    
    
 
    
%------------------finished with the initial run-through------------------%    
%------------------finished with the initial run-through------------------%    
%------------------finished with the initial run-through------------------% 




%we are finished with the first pass. enable all the buttons now so the user
%can select (if any) steps to redo. if they are finished then they can hit the
%finished button.


%enable all the redo buttons now.  these are the push buttons located in
%the top left panel beside the progress panel.

                                                 
     set(f_fig_handle.reference_axes, 'enable', 'on');

     
     %enable finished button.
     
     set(f_fig_handle.image_done_button, 'enable', 'on');

        
        %display the final reference image if the skipped button has not be
        %pressed.  if the skipped button has been pressed then set the
        %finished radio button value to 1.  this will initiate the exit analysis
        %sequence for this image.

        switch skippedImage
            
            case 0 %display the image.
        
            %get_ref_cdata = get(ref_axes_obj, 'Cdata');
                  
            XsectionCode = imread([cd AllImageSpecs.fileSeparator 'temp' ...
                AllImageSpecs.fileSeparator 'XsectionCode.tif']);
            

            
            set(main_axes_obj, 'Cdata', XsectionCode);
            
            case 1 %do not display iamge
                
             
             %set the finished radio button value to 1.   
                
            set(f_fig_handle.image_done_button, 'Value', 1);  

        
        end;
        
        
        %enable all image evaluation controls now.

        set(f_fig_handle.checkGroup1(1,:), 'Enable', 'on');
        set(f_fig_handle.checkGroup2(1,:), 'Enable', 'on');
        set(f_fig_handle.checkGroup3(1,:), 'Enable', 'on');

        set(f_fig_handle.editGroup2, 'Enable', 'on');
        set(f_fig_handle.editGroup3, 'Enable', 'on');        
        
        set(f_fig_handle.editLabel, 'Enable', 'on');
        

        
        %wait for the user to hit the finished button.  they can make changes
        %up until they hit the the finished button.  if the user hit the
        %skip image button the user will exit the analysis mode for this
        %iamge and move on to the next image.

        waitfor(f_fig_handle.image_done_button, 'Value', 1);  
       
        
        %set the foreground color for all labels to black.
        
        set(f_fig_handle.step_label, 'ForegroundColor', [0 0 0]);         
        
        
        %disable all image evaluation controls now.

        set(f_fig_handle.checkGroup1(1,:), 'Enable', 'off');
        set(f_fig_handle.checkGroup2(1,:), 'Enable', 'off');
        set(f_fig_handle.checkGroup3(1,:), 'Enable', 'off');

        set(f_fig_handle.editGroup2, 'Enable', 'off');
        set(f_fig_handle.editGroup3, 'Enable', 'off'); 
        
        set(f_fig_handle.editLabel, 'Enable', 'off');
        

            
        %set the finished button value to zero.  this will reset the done 
        %button to off before next image loads.
        
        set(f_fig_handle.image_done_button, 'Value', 0); 
        set(f_fig_handle.image_done_button, 'enable', 'off');

     
        %disable and reset the done buttons to zero.
        
        set(f_fig_handle.done_buttons, 'enable', 'off');
        set(f_fig_handle.done_buttons, 'Value', 0);
         
        
        %disable reference axes now.
        
        set(f_fig_handle.reference_axes, 'enable', 'off'); 
    
        
        %reset cell file uicontrol slider value to 1/12.
        
        set(f_fig_handle.image_vars(4), 'Value', (1/12));
        
        
        %set left axes to the current axes.clear the axis objects.

        set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));  
                                                     cla;  
        
        
        %set right axes to the current axes and clear ases objects
        
        set(gcf, 'CurrentAxes', f_fig_handle.im_axes(2));  
                                                     cla; 
                                              
                                              
                                              
        
    switch skippedImage
                    
    	case 0
                      

            %define output directory for image output.  
                
            Image_output_directory = ['Image_Output' AllImageSpecs.fileSeparator image_name];  
               
            
            %truncate image name by deleting the image format from the
            %image_name string.
            
            index = find(image_name == '.', 1, 'last');
            image_name(index:end)                 = [];
            
            
            %define filename for highlighted cross-section image and print it to file.
                
            filename = [cd AllImageSpecs.fileSeparator Image_output_directory ...
                AllImageSpecs.fileSeparator 'Highlight_RGB.' image_name '.tif'];  

            
            %write the image to file with the previously defined file name.
            
            imwrite(get_ref_cdata, filename, 'tif');  
            
            
            
            filename = [cd AllImageSpecs.fileSeparator Image_output_directory ...
                AllImageSpecs.fileSeparator 'Highlight_RGB_region.' image_name '.tif'];  

           
            
            imwrite(XsectionCode, filename, 'tif');                             
                
            
            %place user cell file adjustment in data matrix column 23.
            
            cf_user = str2double(get(f_fig_handle.image_vars(6), 'String'));

            
            switch (isnumeric(cf_user) == 0) | (isempty(cf_user))
                
                case 1
                    
                    cf_user = 0;
                    
            end;
            
            
            %place cf value (user) into data matrix.
            
            data_matrix{DirSpecs.iteration, 23} = cf_user;
            
            
            %set the cell file adjustment string to blank space.
            
            set(f_fig_handle.image_vars(6), 'String', '');
            
            
           
            %place user comments into matrix.
            
            %comments (string) 
            
            user_comment = get(f_fig_handle.comments, 'String'); 
            
            
            switch isempty(user_comment)
                
                case 1
                    
                    user_comment = 'No Comments';
            
                    
            end;
            

            data_matrix{DirSpecs.iteration, 50 + DirSpecs.cortBins} = user_comment;               
                
            
            %check the image evaluation checkboxes to determine what
            %variables are not fit for analysis.
            
            badVal;
            
            
            
            %update the lucunae, meta xv and proto xv approximation data
            %matrix.
            
            
            approx_data{DirSpecs.iteration, 1} = data_matrix{DirSpecs.iteration, 1}; 
            
                      
            approx_lac_mxv_pxv(lacunae_data, xv_data);
            
            
            
            
            

        case 1
            
            
            %if the image was skipped then code the data matrix with a
            %dummy variable.
            
            for i = 3:(size(data_matrix,2) - 1)
            
                data_matrix{DirSpecs.iteration, i} = -999;
 
            end;
                
    end;
                
    

        %reset the checkboxes to checked (i.e.value = 1)
    
        set(f_fig_handle.checkGroup1(1,:), 'Value', 1);
        set(f_fig_handle.checkGroup2(1,:), 'Value', 1);
        set(f_fig_handle.checkGroup3(1,:), 'Value', 1);
        
        
        %reset the edit box strings to 0.
        
        set(f_fig_handle.editGroup2, 'String', '0');
        set(f_fig_handle.editGroup3, 'String', '0');   
        
        
        %reset the reference values for the checkboxes.
    
        f_fig_handle.checkGroup1(2,:) = 1;
        f_fig_handle.checkGroup2(2,:) = 1;
        f_fig_handle.checkGroup3(2,:) = 1;



        %we are in batch analysis program_mode. record last image iteration.
        
        switch program_mode
            
            case -2 
            
            %save the current updated data matrix.
            
            save('DATA_MAT', 'data_matrix');  
            
            
            %save the current updated approximated data matrix.
            
            save('APPROX_DAT', 'approx_data');
            
            
            %save the current updated time efficiency matrix.
            
            save('time_efficiency', 'time_efficiency');
            
        
        end;

          
        
end;


     


    
    
%output data to text file. access function 'dataout'.

%this value tells the data output function data is being directly exported 
%from the batch analysis.

analysis_mode = 1;  


%execute the dataout function.  this function will output all data for all 
%currently activated settings.


switch program_mode
    
    case -2 %directory mode: print data to file.

        
        %check all the data matrices for NaN's and empty cell cells.
        
        checkdataentries;
        
        
        %print data to file.
        
        data_output(analysis_mode, total_images, DirSpecs.directory_name);  


    case -1 %individual file mode: allow user to see results in separate GUI.
        

        switch skippedImage
            
            case 0
        
            viewQuickResults;
            
                
        end;
                

end;








%------------------end of main rootscan analysis steps---------------------%
%------------------end of main rootscan analysis steps---------------------%        
%------------------end of main rootscan analysis steps---------------------%             
%------------------end of main rootscan analysis steps---------------------% 
%------------------end of main rootscan analysis steps---------------------%








%------------------------place gui callbacks here.------------------------%
%------------------------place gui callbacks here.------------------------%
%------------------------place gui callbacks here.------------------------%
%------------------------place gui callbacks here.------------------------%
 




%define callback for all redo buttons.  this callback will perform the
%applicable operations when any of the dropdown menu options in the top
%right hand panel are selected.  The operations are toggle on or off
%depending on the result from the switch conditional statement.


function redobuttoncallback(varargin)  

    %determine which tab option was selected.
    
    button = get(f_fig_handle.redobuttondropdown, 'Value') - 1;
    
    
    %disable all buttons and dropdown menus now.
    
    set(f_fig_handle.reference_axes, 'enable', 'off'); 
    set(f_fig_handle.image_done_button, 'enable', 'off');      
    set(f_fig_handle.done_buttons, 'enable', 'off');
    set(f_fig_handle.done_buttons, 'value', 0);
    

    %redo lateral isolation.
    
    switch button
        
        case 1
        
        set(gcf, 'CurrentAxes', f_fig_handle.im_axes(2));  
        cla  
    
        	       lateral_segementation;
            automatic_stele_segmentation;   

        
    end;
    
    
    switch (button <= 2)
        
        case 1
        
        %manual-segmentation: stele/cortex segmentation.
        
        [cortexData, xv_data] = manual_stele_segmentation;
    
        
    end;
    
    
    switch ((button <=2) | (button == 3))

        case 1
            
        %redo lacunae selection.      
    
        [cortexData, lacunae_data] = manual_lacunae_selection(cortexData);
   
        
    end;
    
    
    switch ((button <=2) | (button == 4))
        
        case 1
    

        %redo xlyem vessel selection.

        skip_proto = 0;
   
        xv_data = manual_xv_selection(xv_data, skip_proto);


    end;
        
    
    %place the updated reference image in the main image axes.
    
    set(main_axes_obj, 'cdata', get_ref_cdata);
    
        
    %enable all buttons now.
    
    set(f_fig_handle.reference_axes, 'enable', 'on'); 
    set(f_fig_handle.image_done_button, 'enable', 'on');                                          
    set(f_fig_handle.image_done_button, 'Value', 0);
    

   %reset the redo dropdown button.
 
   set(f_fig_handle.redobuttondropdown, 'Value', 1);
          
          
          
end





    %skip image callback function is placed here.  this function will execute
    %when the user pushes the image skip button on the main display.


    function skipImageCallback(varargin)
        
        
        %update comments section of data matrix to indicate which image has
        %been skipped.
        
        data_matrix{DirSpecs.iteration, end} = 'skipped';
        
        set(f_fig_handle.done_buttons, 'Value', 1);
        
        
    end






 
    
    
end