function smoothStele = SealLatGap(smoothStele, x_sect_reg)

%this function will seal the gap between the stele region and lateral
%region at the proximity of the stele and lateral regions adjacency site.


%define and verify the intersection of the stele perimeter and dilated
%lateral perimeter.  these points of intersection will be used as points of
%interpolation between the current stele perimeter and current
%lateral perimeter. 

[CodeStele, BrokenStele] = steleLatINT(smoothStele, x_sect_reg);


%define the lateral perimeter closest to the current stele perimeter.
%reject the rest.

CodeStele = closeLat(CodeStele);



%place the broken stele perimeter coordinates and broken lateral
%coordinates on the same.


CodeStele = CodeStele + BrokenStele;
CodeStele(CodeStele == 2)       = 1;



%interpolate the  current binary image containing the stele and lateral
%segments.  we are essentially filling in the dots.


%find the coordinates

[row, col] = find(CodeStele ~= 0);


%define the approximate center of mass coordinates.

rowO = mean(row);
colO = mean(col);


%shift the coordinates now.

row = row - rowO;
col = col - colO;



%convert to polar coordinates.

[theta, rho] = cart2pol(col, row);


%convert theta coordinates from -pi:pi to 0:2pi.

theta(theta < 0) = theta(theta < 0) + 2*pi;


%place these coordinates in a N X 2 matrix.

thetaMat = [theta rho];
thetaMat = sortrows(thetaMat, 1);


INT = floor(.25*size(thetaMat,1));


%create lower and upper buffers in data matrix.

lowerbuff    = thetaMat((end - INT),:);
lowerbuff(:,1) = lowerbuff(:,1) - 2*pi;

upperbuff          = thetaMat(1:INT,:);
upperbuff(:,1) = upperbuff(:,1) + 2*pi;


thetaMat = vertcat(lowerbuff, thetaMat, upperbuff);


%interpolate the map.

xi    = thetaMat(1,1):(pi/360):thetaMat(end,1);

yi = interp1(thetaMat(:,1), thetaMat(:,2), xi);





%convert to cartesian coordinates.

[xi, yi] = pol2cart(xi, yi);

xi = xi + colO;
yi = yi + rowO;


%convert the interpolated coordinates to a 1-dim image indice vector.

index = size(smoothStele,1)*floor(xi) + floor(yi);


smoothStele = smoothStele*0;
smoothStele(index) = 1;
smoothStele(CodeStele == 1) = 1;


approxArea = pi*(length(smoothStele(smoothStele == 1))/pi)^2;

status = 0;
disksize = 4;


while status == 0
    
    disksize = disksize + 1;

    smoothStele1 = imdilate(smoothStele, strel('disk', disksize));

    fillStele = imfill(smoothStele1, 'holes');

    fillArea = length(fillStele(fillStele == 1));

    %test to see if current dilation is enough to fill in stele.

    if fillArea >= .25*approxArea
    
        status = 1;
        
        smoothStele = fillStele;
        smoothStele = imerode(smoothStele, strel('disk', disksize));
        
    end;
    





end;





end