function XsStelepoly(varargin)

%this function will create a draggable polygon with initial vertice
%positions for 25-30 approximate vertice positions.  


global f_fig_handle; %structure containing all figure children and properties.
global solidSegment; %solid region image.


%define the integer that is assigned to the radio button to be enabled.

radBut = varargin{2};  
ComX   = varargin{3};
ComY   = varargin{4};


%set the finished (done) radiobuttons to off.

set(f_fig_handle.done_buttons(radBut), 'Value', 0);



%check the second argument to see if we have a position vector with x and y
%co-coordinates in their respective columns.

posVect = varargin{1};

if size(posVect,2) ~= 2
    
    posVect = PosVect';
    
end;




%these coordinates need to be placed in angular order now.

%convert from cartesian to polar.

[theta, rho] = cart2pol(posVect(:,2), posVect(:,1));

theta(theta < 0) = theta(theta < 0) + 2*pi;

thetarho = [theta rho];


thetarho = sortrows(thetarho, 1);


%we need to select 25-30 equidistant points for the stele perimeter
%boundary for the creation of our initial interactive polygon.


%for now we will create 30.  we can scale down this number later on if
%there is a significant relationship between image size and minimun number
%of initial vertices.  this would only be introduced if there would be a
%significant reduction in time wasted on the other (useless) vertices.


%take 40 equidistant coordinates about the stele perimeter.

div40 = floor(size(posVect,1)/40);

vector40 = 1:div40:size(posVect,1);


%truncate the vector containing the stele perimeter coordinates using the
%40-equidistant vertice method above.

thetarho = thetarho(vector40,:);



switch radBut
    
    case 4
        
        initialRAD = 35;
        
        thetarho(:,2) = thetarho(:,2) + initialRAD;
        
end;


%convert back to cartesian coordinates.

[col, row] = pol2cart(thetarho(:,1), thetarho(:,2));

col = col + ComX;
row = row + ComY;


%display the initial interactive polygon.

g = impoly(gca, [col row]);


%set the key press function now.

set(gcf, 'KeyPressFcn', @deleteverts);


%set the finished (done) radiobutton associated with the x-section
%segmentation step to on so the user can select it when finished.

set(f_fig_handle.done_buttons(radBut), 'enable', 'on');


        
waitfor(f_fig_handle.done_buttons(radBut), 'Value', 1);




%if the user made adjustments to the x-section segmentation then assign the
%mask associated with the image polygon tool to the solidSegment result.

if isempty(g) == 0
     
        solidSegment = createMask(g);

end;




%define function for when users delete or create a new interactive polygon.

    function deleteverts(src, evnt)
        
        
        %if the user presses the delete (backspace) button, space bar or
        %return we are going to delete the current polygon. 
        
        
        if max(strncmp(char(evnt.Key), {'backspace' 'return' 'space'}, 1)) == 1
            
            delete(g); %delete the current image polygon.
            g = [];
            
        elseif max(strncmp(char(evnt.Character), {'n' 'N'}, 1)) == 1           
        
        %initialize a roipoly just incase the user made a mistake by pressing any of the
        %three buttons listed above.
        
            g = impoly; %initialize region of interest polygon.
        
            
        elseif max(strncmp(char(evnt.Character), {'x' 'X' 'C' 'c'}, 1)) == 1
            
            
            %retrieve the current position of the interactive polygon.
            
            getPos         = getPosition(g);
            
            
            %normalize these coordinates by the x-section center of mass.
            
            getPos(:,1) = getPos(:,1) - ComX;
            getPos(:,2) = getPos(:,2) - ComY;
            
            
            %convert these coordinates to polar coordinates.
            
            [theta,rho] = cart2pol(getPos(:,1), getPos(:,2));
            
            
            %concatenate these coordinates.
            
            thetarho = [theta rho];
            
            
            %sort this matrix according to increasing angle about the
            %x-section center of mass.
            
            thetarho = sortrows(thetarho, 1);
            
            
            %define script for the radial expansion or collapse of the interactive polygon.

            if max(strncmp(char(evnt.Character), {'x' 'X'}, 1)) == 1
            
                thetarho(:,2) = thetarho(:,2) + 10;

            
            elseif max(strncmp(char(evnt.Character), {'C' 'c'}, 1)) == 1
                
                thetarho(:,2) = thetarho(:,2) - 10;

                
            end
            


            %convert back to cartesian coordinates.

            [col, row] = pol2cart(thetarho(:,1), thetarho(:,2));

            col = col + ComX;
            row = row + ComY;


            %delete the old polygon.
            
            delete(g);
            g    = [];
            
            %display the initial interactive polygon.
            
            g = impoly(gca, [col row]);
            
            
        
        end;
        
    end



end