function approx_lac_mxv_pxv(varargin)

%this function approximates data for any missing lacunae, metaxylem vessels
%and protoxylem vessels.  this function will only evaluate if the user
%confirms the existence of any missing objects.  If there are no missing
%objects then the data values for tha row will remain zero.



%access all global variables.

global   approx_data; %data approximation cell matrix.
global  f_fig_handle; %gui figure handles.
global      DirSpecs; %currect directory specifications.
global AllImageSpecs; %image specifications.


%read in primary data variables.


%data matrix containing lacunae data

lacunae_data = varargin{1};


%data matrix containing xylem vessel data.

xv_data      = varargin{2};


%get the value of the missing lacunae edit box.  this should be an integer.

lac_missing = get(f_fig_handle.editGroup2, 'String');

lac_missing         = floor(str2double(lac_missing));            


%get the value of the missing metaxylem vessel edit box. this should be an
%integer.

mxv_missing = get(f_fig_handle.editGroup3(1), 'String');

mxv_missing            = floor(str2double(mxv_missing));            


%get the value of the missing protoxylem vessel edit box. this should be an
%integer.

pxv_missing = get(f_fig_handle.editGroup3(2), 'String');

pxv_missing            = floor(str2double(pxv_missing));  




%get the value of the lacunae checkbox (i.e. is it checked or not).

lac_check = get(f_fig_handle.checkGroup2(1,1), 'Value');



%get the value of the metaxylem checkbox (i.e. is it checked or not).

mxv_check = get(f_fig_handle.checkGroup3(1,1), 'Value');



%get the value of the protoxylem checkbox (i.e. is it checked or not).

pxv_check = get(f_fig_handle.checkGroup3(1,2), 'Value');




%approximate the lacunae measurements if there are any missing lacunae as
%designated by the lacunae edit box values define above.


switch ((lac_check == 1) & (lac_missing > 0))
    
    case 1 %lacunae check box is checked and there is at least 1 lacunae missing.
        
        
        %the lacunae approximations will be based on the median lacunae
        %size.
        
        lac_objs = median(lacunae_data)*ones(lac_missing,1);
        
        lacunae_data = [lacunae_data; lac_objs];
        
        
        %calculate the approximated lacuane measurements now.
        
        
        %number of lacunae missing.
        
        approx_data{DirSpecs.iteration, 2} ...
        	                                 = lac_missing; 
        
        
        %number of lacunae.
        
        approx_data{DirSpecs.iteration, 3} ...
                                    = length(lacunae_data); 
        
        
        %median lacunae area.
        
        approx_data{DirSpecs.iteration, 4} ...
            = median(lacunae_data)/AllImageSpecs.calib_area;
        
        
        %std lacunae area.

        approx_data{DirSpecs.iteration, 5} ...
               = std(lacunae_data)/AllImageSpecs.calib_area; 
           
           
        %lacunae area (low).   

        approx_data{DirSpecs.iteration, 6} ...
               = min(lacunae_data)/AllImageSpecs.calib_area; 
           
           
        %lacunae area (high).   

        approx_data{DirSpecs.iteration, 7} ...
               = max(lacunae_data)/AllImageSpecs.calib_area; 

           
        %total aerencyhma area.     
           
        approx_data{DirSpecs.iteration, 8} ...
               = sum(lacunae_data)/AllImageSpecs.calib_area;       
        
        
        
        
        
        
        
        
        
        
end;







%approximate the metaxylem vessel measurements if there are any metaxylem
%vessels designated by the mxv edit box values define above.

switch ((mxv_check == 1) & (mxv_missing > 0))
    
    case 1 %there is at least one metaxylem vessel missing.
        
        %the metaxylem vessel approximations will be based on the median
        %metaxylem vessel size.
        
        all_metaxv = xv_data(xv_data(:,end) == 2,:);
        
        metaxv_objs                 = median(all_metaxv,1);
        metaxv_objs = repmat(metaxv_objs, [mxv_missing 1]);        
        
        
        all_metaxv = [all_metaxv; metaxv_objs];
        
        %adjust the values based on the missing data.
        
        calc_missing(all_metaxv);
        
        
        
        
        %place the meta xv data in global data matrix.
        
        
        %number of missing metaxylem vessels.
        
        approx_data{DirSpecs.iteration, 9}         = mxv_missing; 
       
        
        %# of meta-xv.
        
        approx_data{DirSpecs.iteration, 10} = size(all_metaxv,1); 
        
        
        %median meta-xv area.
        
        approx_data{DirSpecs.iteration, 11}             = med_xv; 
        
        
        %std meta-xv area.
        
        approx_data{DirSpecs.iteration, 12}             = std_xv; 
        
        
        %low meta-xv area.
        
        approx_data{DirSpecs.iteration, 13}             = low_xv; 
        
        
        %high meta-xv area.
        
        approx_data{DirSpecs.iteration, 14}            = high_xv; 
        
        
        %median meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 15}        = med_xv_diam; 
        
        
        %std meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 16}        = std_xv_diam; 
        
        
        %low meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 17}        = low_xv_diam; 
        
        
        %high meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 18}       = high_xv_diam; 
        
        
        %meta-xv area.
        
        approx_data{DirSpecs.iteration, 19}           = tot_area; 
        
        
        %r^4 h2o conductance.  

        approx_data{DirSpecs.iteration, 20}   = total_xv_r4power;       
        
        
end;











%approximate the protoxylem vessel measurements if there are any protoxylem
%vessels designated by the pxv edit box values define above.

switch ((pxv_check == 1) & (pxv_missing > 0))
    
    case 1 %there is at least one metaxylem vessel missing.
        
        %the protoxylem vessel approximations will be based on the median
        %protoxylem vessel size.
        
        all_protoxv = xv_data(xv_data(:,end) == 3,:);
        
        protoxv_objs                = median(all_protoxv,1);
        protoxv_objs = repmat(protoxv_objs, [pxv_missing 1]);           
        
        
        all_protoxv = [all_protoxv; protoxv_objs];
        
        
        %adjust the values based on the missing data.
        
        calc_missing(all_protoxv);
        
        
        
        
        %place the meta xv data in global data matrix.
        
        
        %number of missing metaxylem vessels.
        
        approx_data{DirSpecs.iteration, 21}         = pxv_missing; 
       
        
        %# of meta-xv.
        
        approx_data{DirSpecs.iteration, 22} = size(all_protoxv,1); 
        
        
        %median meta-xv area.
        
        approx_data{DirSpecs.iteration, 23}              = med_xv; 
        
        
        %std meta-xv area.
        
        approx_data{DirSpecs.iteration, 24}              = std_xv; 
        
        
        %low meta-xv area.
        
        approx_data{DirSpecs.iteration, 25}              = low_xv; 
        
        
        %high meta-xv area.
        
        approx_data{DirSpecs.iteration, 26}             = high_xv; 
        
        
        %median meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 27}         = med_xv_diam; 
        
        
        %std meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 28}         = std_xv_diam; 
        
        
        %low meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 29}         = low_xv_diam; 
        
        
        %high meta-xv diameter.
        
        approx_data{DirSpecs.iteration, 30}        = high_xv_diam; 
        
        
        %meta-xv area.
        
        approx_data{DirSpecs.iteration, 31}            = tot_area; 
        
        
        %r^4 h2o conductance.  

        approx_data{DirSpecs.iteration, 32}    = total_xv_r4power;          
        

        
        
end;









    function calc_missing(varargin)
        
    %this function calculates values for the metaxylem and protoxylem
    %vessel data with the approximated missing values.
    
        %define the xylem vessel data matrix.
        
        xvDAT = varargin{1};
    
        
        %calculate the mean diameter of each xylem vessel object.

        mean_major_minor_AL = mean([xvDAT(:,4), xvDAT(:,5)], 2);        
    
        
        
        %calculate the mean, std, low and high xylem vessel diameters.
        
        med_xv_diam = median(mean_major_minor_AL)/(AllImageSpecs.calib_length);
        std_xv_diam    = std(mean_major_minor_AL)/(AllImageSpecs.calib_length);
        low_xv_diam    = min(mean_major_minor_AL)/(AllImageSpecs.calib_length);
        high_xv_diam   = max(mean_major_minor_AL)/(AllImageSpecs.calib_length);

                                
               
        %calculate the mean, std, low and high xylem vessel areas values.
                
        med_xv = median(xvDAT(:,2))/AllImageSpecs.calib_area;
        std_xv    = std(xvDAT(:,2))/AllImageSpecs.calib_area;
        low_xv    = min(xvDAT(:,2))/AllImageSpecs.calib_area;
        high_xv   = max(xvDAT(:,2))/AllImageSpecs.calib_area;
                


        %--------------------------------------------------------------------------                
        %CALCULATE THE 'r^4' TERM IN THE TOTAL WATER FLUX CALCULATION USING Poiseuille's EQUATION.
        %--------------------------------------------------------------------------
                
        %calculate radius of each xylem vessel object (i.e. the mean of the major and
        %minor axis lengths).
                
        xylem_vessel_radii = (1/1000)*(mean_major_minor_AL/2)/AllImageSpecs.calib_length;
                
                
        %sum these r^4 terms up.
                
        total_xv_r4power = sum(xylem_vessel_radii.^4);
                
       
        %calculate the total area.
        
        tot_area = sum(xvDAT(:,2))/AllImageSpecs.calib_area;
        
        
        
	end







end