function midpoint = auto_meta_detect(steleObjs)

%determine the midpoint between the two bi-modal groups using a inter-class
%variance optimization.

%this function is similar to otsu's method for global pixel binarization.

%find the optimal cut-off point between meta xylem vessels and all other
%stele objects (i.e. proto-xylem, pith and other objects).

 
%sort the stele objects according to increasing object size.

steleObjs = sortrows(steleObjs,1);


%calculate the number of stele objects.

totObjs = length(steleObjs);


%start the iterations now.


%allocate memory for the the stele object areas and midpoints.

midpt_mat = zeros(length(steleObjs),2);
midpt_mat(:,1) = steleObjs;


for I = 1:length(steleObjs)
    
    
    %define the smaller object group, its weight and variance.
    
    smallgroup = steleObjs(steleObjs < steleObjs(I));
    
    smallgroupweight = length(smallgroup)/totObjs;
    
    smallgroupvariance = var(smallgroup);
    
    
    %define the larger object group, its weight and variance.
    
    largegroup = steleObjs(steleObjs >= steleObjs(I));    
    
    largegroupweight = length(largegroup)/totObjs;
    
    largegroupvariance = var(largegroup);
    
    
    
    %calculate the interclass weighted variance for the two groups and
    %assign the value to 'midpt_mat'.
    
    midpt_mat(I,2) = (smallgroupweight*smallgroupvariance) + ...
        (largegroupweight*largegroupvariance);
    
    
    
end;


%sort the matrix: midpt_mat and find the cutoff point associated with the
%smallest variance.

midpt_mat = sortrows(midpt_mat, 2);



%define the cutoff midpoint for the stele object sizes.

midpoint = midpt_mat(1,1);



end