function automated_options

%this function was constructed on january 28, 2011 to allow the user to
%automate particular steps in the root-scan program.  for example, if the
%user wanted to forgo interaction with the xylem vessel detection and just
%use the result from the automated xylem vessel function then they can
%select that associated box.


%read in the current automated options set by the user during the previous
%session.

DIRECTORY        = which('AUTOMATED_OPTIONS');
find_paren = find(DIRECTORY == 47, 1, 'last');
DIRECTORY           = DIRECTORY(1:find_paren);


%go to the main program directory.

cd(DIRECTORY);

dir_settings = dir('AUTOMATED_SETTINGS.mat');


%check to see if file exists

if (isempty(dir_settings) == 0) %yes, it does. load previous settings.

    AUTOMATED_OPTIONS_SETTINGS = struct2cell(load('AUTOMATED_SETTINGS.mat'));
    AUTOMATED_OPTIONS_SETTINGS             = AUTOMATED_OPTIONS_SETTINGS{1,1};

    switch AUTOMATED_OPTIONS_SETTINGS(end)
        
        case 0 %it is currently de-activated.
            
            active = 'Program automation deactivated';
            
        case 1 %it is currently activated.
            
            active = 'Program automation activated';
            
    end;
    
else %no, it does not.  set all boxes to uncheck.
    
    AUTOMATED_OPTIONS_SETTINGS = (1:6)*0;  

    active = 'Program automation deactivated';
    

end;

%display check gui for user interaction.

automateFig = figure('Name', 'Automated Root-Scan Settings', 'Units', 'Normalized', ...
    'Position', [.3, .3 .4 .6], 'menubar', 'none');


%set up a static text uicontrol to place a simple instruction for the user.

uicontrol('Parent', automateFig, 'Style', 'text', 'Units', 'normalized', ...
    'Position', [.025 .9 .9 .075], 'FontUnits', 'normalized', 'String', ...
    'Select Steps For Automation', 'FontWeight', 'bold', 'FontSize', .8, ...
    'HorizontalAlignment', 'Left', 'BackgroundColor', [.8 .8 .8]);



%set up pushbutton for activation purposes and set its callback function.

ACTIVATE = uicontrol('Parent', automateFig, 'Style', 'pushbutton', 'Units', 'normalized', ...
    'Position', [.025 .025 .55 .075], 'FontUnits', 'normalized', 'String', ...
    active, 'FontWeight', 'bold', 'FontSize', .4, ...
    'HorizontalAlignment', 'left', 'BackgroundColor', [.8 .8 .8]);

set(ACTIVATE, 'Callback', @ACTIVATE_CALLBACK);


%---------------SET UP THE AUTOMATED OPTIONS CHECKBOXES NOW---------------%




%set up panel for checkboxes.

checkpanel = uipanel('Parent', automateFig, 'Units', 'normalized', ...
    'Position', [.025 .25 .95 .6], 'BackgroundColor', [.8 .8 .8]);


%define the automated optoins checkbox for x-section segmentation, set it's
%initial check box value and callback function.

AUTO_X_SECTION = uicontrol('Parent', checkpanel, 'Style', 'checkbox', 'Units', 'normalized', ...
    'Position', [.025 .812 .95 .153], 'FontUnits', 'normalized', 'String', ...
    'Automate cross-section segmentation', 'FontWeight', 'bold', 'FontSize', .5, ...
    'HorizontalAlignment', 'left', 'BackgroundColor', [.8 .8 .8]);
   

set(AUTO_X_SECTION, 'Value', AUTOMATED_OPTIONS_SETTINGS(1));

set(AUTO_X_SECTION, 'Callback', @CHECK_BOX_CALLBACK);


%define the automated optoins checkbox for lateral segmentation set it's
%initial check box value and callback function.

AUTO_LATERAL = uicontrol('Parent', checkpanel, 'Style', 'checkbox', 'Units', 'normalized', ...
    'Position', [.025 .619 .95 .153], 'FontUnits', 'normalized', 'String', ...
    'Automate lateral segmentation', 'FontWeight', 'bold', 'FontSize', .5, ...
    'HorizontalAlignment', 'left', 'BackgroundColor', [.8 .8 .8], 'Enable', 'off');

set(AUTO_LATERAL, 'Value', AUTOMATED_OPTIONS_SETTINGS(2));

set(AUTO_LATERAL, 'Callback', @CHECK_BOX_CALLBACK);


%define the automated optoins checkbox for stele/cortex segmentation set it's
%initial check box value and callback function.

AUTO_STELE_CORTEX = uicontrol('Parent', checkpanel, 'Style', 'checkbox', 'Units', 'normalized', ...
    'Position', [.025 .426 .95 .153], 'FontUnits', 'normalized', 'String', ...
    'Automate stele segmentation', 'FontWeight', 'bold', 'FontSize', .5, ...
    'HorizontalAlignment', 'left', 'BackgroundColor', [.8 .8 .8]);

set(AUTO_STELE_CORTEX, 'Value', AUTOMATED_OPTIONS_SETTINGS(3));

set(AUTO_STELE_CORTEX, 'Callback', @CHECK_BOX_CALLBACK);



%define the automated optoins checkbox for x-section segmentation set it's
%initial check box value and callback function.

AUTO_AEREN = uicontrol('Parent', checkpanel, 'Style', 'checkbox', 'Units', 'normalized', ...
    'Position', [.025 .233 .95 .153], 'FontUnits', 'normalized', 'String', ...
    'Automate aerenchyma detection', 'FontWeight', 'bold', 'FontSize', .5, ...
    'HorizontalAlignment', 'left', 'BackgroundColor', [.8 .8 .8], 'Enable', 'off');



set(AUTO_AEREN, 'Value', AUTOMATED_OPTIONS_SETTINGS(4));

set(AUTO_AEREN, 'Callback', @CHECK_BOX_CALLBACK);


%define the automated optoins checkbox for x-section segmentation set it's
%initial check box value and callback function.

AUTO_XYLEM_VESSEL = uicontrol('Parent', checkpanel, 'Style', 'checkbox', 'Units', 'normalized', ...
    'Position', [.025 .04 .95 .153], 'FontUnits', 'normalized', 'String', ...
    'Automate xylem vessel detection', 'FontWeight', 'bold', 'FontSize', .5, ...
    'HorizontalAlignment', 'left', 'BackgroundColor', [.8 .8 .8]);

set(AUTO_XYLEM_VESSEL, 'Value', AUTOMATED_OPTIONS_SETTINGS(5));

set(AUTO_XYLEM_VESSEL, 'Callback', @CHECK_BOX_CALLBACK);


BOXES = [AUTO_X_SECTION AUTO_LATERAL AUTO_STELE_CORTEX AUTO_AEREN AUTO_XYLEM_VESSEL];

previous_settings = cell2mat(get(BOXES, 'Value'));



%define the 'done' and 'cancel' user interactive controls.  they will be
%push-buttons


DONE = uicontrol('Parent', automateFig, 'Style', 'pushbutton', 'units', 'normalized', ...
    'Position', [.6 .025 .2 .07], 'FontUnits', 'normalized', 'String', 'Done', ...
    'FontSize', .6, 'FontWeight', 'bold');

CANCEL = uicontrol('Parent', automateFig, 'Style', 'pushbutton', 'units', 'normalized', ...
    'Position', [.8 .025 .2 .07], 'FontUnits', 'normalized', 'String', 'Cancel', ...
    'FontSize', .6, 'FontWeight', 'bold');


%set the callback functions for the 'done' and 'cancel' pushbuttons.

set(DONE, 'Callback', @DONE_CALLBACK);
set(CANCEL, 'Callback', @CANCEL_CALLBACK);



%define callback when a checkbox is selected by user.

    function CHECK_BOX_CALLBACK(varargin)
        
        current_settings = cell2mat(get(BOXES, 'Value'));
        
        %take the calculate the difference between the current settings and
        %previous settings.
        
        diff_settings = current_settings - previous_settings;
        
        
        %determine which box was just ckecked or unchecked.
        
        current_box = find(diff_settings ~= 0);

        
        %determine if the box was checked or unchecked
        
        checked = (diff_settings(current_box) == 1);
        
        
        switch checked
            
            case 0 %the box was just unchecked take no action
                
                
            case 1 %the box was just check, display a warning message to 
                   %for each checkbox.
                   
                   which_box = current_box;
                   
                   
                   switch which_box
                       
                       case 1 %display warning message for automated x-section 
                              %segmentation option.
                              
         message = ['Selecting this option will prohibit you from interacting ' ...
             'with the manual cross-section segmentation step in Root Scan'];
                              
                              warndlg(message);
                              
                       case 2 %display warning message for automated lateral 
                              %option.
                              
         message = ['Selecting this option will prohibit you from interacting ' ...
             'with the manual lateral segmentation step in Root Scan'];                     
                              
                              warndlg(message);
                             
                       case 3 %display warning message for automated stele/cortex 
                              %segmentation option.
                              
         message = ['Selecting this option will prohibit you from interacting ' ...
             'with the manual stele/cortex segmentation step in Root Scan'];                        
                              
                              warndlg(message);
                              
                       case 4 %display warning message for automated aerenchyma
                              %detection option.
                              
         message = ['Selecting this option will prohibit you from interacting ' ...
             'with the manual aerenchyma selection step in Root Scan'];   
                              
                              warndlg(message);
                              
                       case 5 %display warning message for automated xylem vessel
                              %detection option.
                
         message = ['Selecting this option will prohibit you from interacting ' ...
             'with the manual xylem vessel step in Root Scan.  Warning, this option is not ' ...
             'recommended']; 
         
                              warndlg(message);
                
                              
                   end;
                
                
                
        end;
                
                
       
        %set the previous settings to the current settings.
        
        previous_settings = current_settings;
        
        
        
    end


%place 'ACTIVATE' pushbutton callback function here.  when use selects this
%button.  the activation state will toggle between on and off states.

    function ACTIVATE_CALLBACK(varargin)
        
        a = get(ACTIVATE, 'String');
        
        switch (length(a) == length('Program automation deactivated'))
            
            case 1 %activate the automation now
                
                set(ACTIVATE, 'String', 'Program automation activated');
                
            case 0 %deactivate the automation now
                
                set(ACTIVATE, 'String', 'Program automation deactivated');

                
                
        end;
        
        
        
        
        
    end



%place the 'DONE' pushbutton callback function here


    function DONE_CALLBACK(varargin)
        
        %save the current settings and delete the GUI figure.
        
        a = get(ACTIVATE, 'String');

        switch (length(a) == length('Program automation activated'))
            
            case 1
                
                activate = 1;
                
            case 0
                
                activate = 0;
                
        end;
            
            
        
        current_settings = [cell2mat(get(BOXES, 'Value')); activate];

        save('AUTOMATED_SETTINGS', 'current_settings');
        
        delete(automateFig);
        
    end
    
    
    
%place the 'CANCEL' pushbutton callback function here


    function CANCEL_CALLBACK(varargin)
        
        
        %revert to previous settings and delete the GUI figure.
        
        delete(automateFig);
        
           
        
    end


end