function stele_objs = automatic_protoXV_detection(stele_objs)

%this function will perform a automatic proto-xylem detection after the
%meta-xylem have been positively identified automatically and verifed by
%the user during the meta xylem vessel selection process.  

%this function was initialized on February 23, 2011 and updated on May 3,
%2011.




   

    %detect the proto-xylem vessel objects.



    %subset all non-meta-xylem vessel objects.

    nonMetaXV = stele_objs(stele_objs(:,end) ~= 2,:);


    %determine were the object size cutoff is for the proto-xylem
    %vessel objects using a simple median statistic.

    indexProto = nonMetaXV(:,2) >= median(nonMetaXV(:,2));


    %update proto-xylem vessel data matrix after 1st test.

    nonMetaXV(:,end) = 1;


    %eliminate all objects inside the meta-xylem vessel object coordinates.           

    %define all meta-xylem vessel object matrix.

    metaXV = stele_objs(stele_objs(:,end) == 2, :);

    
    switch isempty(metaXV) == 0
        
        %some metaxylem vessels have been selected.  find the protoxylem
        %vessels now.
        
        case 1

            %sort the meta-xylem vessel object matrix from lowest theta to highest
            %theta coordinate.

            metaXV               = sortrows(metaXV, 6);



            %calculate the radii of all meta xv object around the stele.  these values
            %will be used to eliminate all objects within the radii boundary as
            %possible proto xv.

            for I = 1:(size(metaXV,1) - 1)


            %define the lower and upper bounds for the meta xylem vessel theta coordinates.

            lower_bound   = metaXV(I,6);
            upper_bound = metaXV(I+1,6);


                %define the sampling index for the all non-meta-xylem objects in stele region.

                non_index = find((nonMetaXV(:,6) >= lower_bound) & ...
                    (nonMetaXV(:,6) < upper_bound));


                %caculate the mean meta xylem position radii for each theta interval.

                mean_meta_rad = mean(metaXV(I:I+1,7)) + ...
                    .5*mean(metaXV(I:I+1,4));


                %assign all xylem vessel objects inside the meta xylem radial
                %positions to zero.  they are not proto xylem vessels under normal
                %growing conditions.        

                nonMetaXV(non_index(nonMetaXV(non_index,7) < mean_meta_rad),end) = 0;



            end;




            %assign the rest of the xylem vessel objects inside the meta xylem radial positions
            %to zeros. they are not proto xylem.

            non_index = find((nonMetaXV(:,6) >= metaXV(end,6)) | (nonMetaXV(:,6) < metaXV(1,6)));


            %caculate the mean meta xylem position radii for each theta interval.

            mean_meta_rad = mean(metaXV([1 end],7)) + ...
                .5*mean(metaXV([1 end],4));


            %assign all xylem vessel objects inside the meta xylem radial positions to zero.
            %they are not proto xylem vessels under normal growing conditions.        

            nonMetaXV(non_index(nonMetaXV(non_index,7) < mean_meta_rad),end) = 0;


            %eliminate all non-proto xylem objects from the matrix now. they have ~ a 
            %zero Prob. of being proto xylem because of their %relative position to the meta xylem.

            nonMetaXV(nonMetaXV(:,end) == 0,:)        = [];


            %now that all the objects in the center of stele are de-classified as proto-xylem,
            %we need to de-classify more stele objects by comparing their major axis lengths.

            nonMetaXV = nonMetaXV(nonMetaXV(:,end) == 1,:);


            %calculate the mean and standard deviation major axis length for the remaining objects.
            %this value is used to define the cutoff between proto xylem and non proto
            %xylem.

            mean_AL = mean(nonMetaXV(:,2)) + (2*std(nonMetaXV(:,2)));

            nonMetaXV(nonMetaXV(:,2) <= mean_AL,end)             = 0;

            nonMetaXV           = nonMetaXV(nonMetaXV(:,end) == 1,:);



            %determine if all objects were de-classified as proto-xylem.  if so
            %then we have to re-instate some now.

            clear_all_proto = isempty(nonMetaXV(nonMetaXV(:,end) == 1,1));




            switch clear_all_proto

                %all de-classified.  re-instate some now.   

                case 1 

                    nonMetaXV(indexProto == 1,end)             = 1;
                    nonMetaXV = nonMetaXV(nonMetaXV(:,end) == 1,:);               

            end;


            %determine which non-proto-xylem vessel indices correspond to the stele object
            %label matrix data matrix and assign those matching indices (i.e. they are
            %in union with each other) 1 since they are ~ likely proto-xylem objects.

            stele_objs(ismember(stele_objs(:,1), nonMetaXV(:,1)), end) = 3;

    end;



end