function binary_xs_driver(varargin)

%this function will handle all phase two procedures that are associated wit
%the binary conversation of cross-section images using localized
%thresholding methods.


    global    f_fig_handle; %structure containing all figure properties and children.
    global   AllImageSpecs; %structure containing all image specifications.
    global        DirSpecs; %structure containing all directory specifications.
    global     data_matrix; %data matrix.
    global time_efficiency; %time efficiency matrix.

    
    %define current iteration.
    
    current_iteration = varargin{1};
    
    
    %define the total number of images to be processed.
    
    total_images      = varargin{2};
    
    
    
    

    switch DirSpecs.batch_mode == 1
        
        case 1

            %clear the main axes and turn off the axes handle.

            set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));
                                                         cla;
              set(f_fig_handle.im_axes(1), 'visible', 'off');



            %place the automated batch thresholding algorithm here.

            %display a info box telling the user how much time is required for the
            %batch analysis for their directory.


            %highlight the current phase.

            %get the current background color of phase II.

            phaseII_color  = get(f_fig_handle.status(2), 'BackgroundColor');

            set(f_fig_handle.status(1:3), 'BackgroundColor', phaseII_color);
                   set(f_fig_handle.status(2), 'BackgroundColor', [0 1 .3]);
                   
                   
        case 0
            
            %display waitbar to show progress.
            
            h_wait = waitbar(0, 'Initializing Batch Thresholding');
            
            

    end;
    
    

    %convert all grayscale images to binary format.

    if ((current_iteration < total_images) || (total_images == 1))


        for iter_thresh = current_iteration:total_images

            %start the clock.

            tic;


            %read in grayscale image (extrapolated buffer image).

            x_section_grayscale = imread(['X_section_segments' AllImageSpecs.fileSeparator ...
            'XS_BUFFER.' data_matrix{iter_thresh,1}]);


            %read in solid x-section image.

            x_section_solid = imread(['X_section_segments' AllImageSpecs.fileSeparator ...
            'SOLID_XS.' data_matrix{iter_thresh,1}]);




            %define filename of image.

            file_name = data_matrix{iter_thresh,1};


            %convert the grayscale image using the function: 'X_THRESH'.

            local_threshold_method(x_section_grayscale, x_section_solid, iter_thresh);

            
            switch DirSpecs.batch_mode == 1
                
                case 1

                    %display name image that has been converted to binary format.

                    set(f_fig_handle.image_vars(1), 'String', file_name);



                    %display the number of images remaining.

                    num_remain =  total_images - iter_thresh;

                    set(f_fig_handle.status(4), 'String', [num2str(num_remain) ' Images Remaining']);


                    %display the percent completed.

                    set(f_fig_handle.status(5), 'String', [num2str(100*iter_thresh/total_images, '%3.0f\t') ' % Complete']);            

            
            
                case 0
                    

                    percent_done                                      = iter_thresh/total_images;

                    waitbar(percent_done, h_wait, [num2str(floor(percent_done*100), 3) ' % Complete']);                    
                    
                    
            end;
            
            pause(.1);

            %save the time efficiency statistics if the user is in directory mode.

            
            switch DirSpecs.batch_mode == 1
                
                case 1
                
                    switch DirSpecs.programMode

                        case -2

                            time_efficiency{iter_thresh,2} = toc;
                                   save('time_efficiency', 'time_efficiency');

                    end;


                case 0
                    
                	time_efficiency{iter_thresh,2}       = toc;
                	save('time_efficiency', 'time_efficiency');
                    
                    
            end;
            
            
            %define the new thresh log value. add 1 to the previous value.
            
%             DirSpecs.thresh_log = DirSpecs.thresh_log + 1;
%             
%             
%             thresh_log = DirSpecs.thresh_log;
%             
%             
%             %save the threshold log data.
% 
%             save('thresholding_log', 'thresh_log');            
            

        end;

    end;


   

end