function bandVect = calcBand(X_SECTION_REGIONS)

%since cross sections lack symmetry is some cases it would be good to
%calculate a bandwidth matrix (used in the spatial weight matrix calculations)
%to account for this asymmetry.  this normalized will reduce any
%directional bias in the spatial weight calculation.  we will see a spatial
%weights matrix that is normalized to the changing shape of the
%cross-section border region.


global Coms;



%define the perimeter image of the cross-section.

perimIM = bwperim(X_SECTION_REGIONS);


%find the row and column coordinates of the perimeter pixels.

[row, col] = find(perimIM ~= 0);


%normalize the row and column coordinates before converting them to polar
%coordinates by subtracting those row and column coordinates from the row
%and column center of mass coordinates.

row = row - Coms(2);
col = col - Coms(1);


%convert to polar coordinates.

[theta, rho] = cart2pol(col, row);


clear row col;


%translate theta from -pi:pi coordinates to 0:2pi coordinates.

theta(theta < 0) = theta(theta < 0) + 2*pi;



%now it is time to adjust the bandwidth for each theta interval.



%define the row and column coordinates for the image.

row = repmat((1:size(perimIM,1))', 1, size(perimIM,2));
col = repmat((1:size(perimIM,2)), size(perimIM,1), 1);


%normalized the row and column indexing matrix by the center of mass
%coordinates once again.

row = row - Coms(2);
col = col - Coms(1);

%convert to polar coordinates.

[theta2, rho2] = cart2pol(col, row);


%traslate any negative theta values to their equilavent positive
%values

theta2(theta2 < 0) = theta2(theta2 < 0) + 2*pi;


%define blank image for variable bandwidth calculation.

bandVect = zeros(size(perimIM));



%define the theta interval to loop through for the bandwidth calculations.

thetaInt = 0:(pi/24):2*pi;



for I = 1:(length(thetaInt) - 1)
    
    %define the lower and upper bounds.
    
    lowerB = thetaInt(I);
    
    upperB = thetaInt(I+1);
       
    
    %calculate the mean radius of perimeter from the center of mass and 
    %place this mean radius calculation into the bandVect matrix.
    
    bandVect((theta2 >= lowerB) & (theta2 < upperB)) = ...
        mean(rho((theta >= lowerB) & (theta < upperB)));
    
    
    
end;
    





end