function crossDens2 = calcDens(IMAGE)

%this function will calculate the cross section tissue density in an
%attempt to accurate isolate the stele region for a vast array of image
%containing varying levels of contrast, resolution and clarity.  at this
%time the sample bounding box (analogous to volume or area) is the same.
%So our density measurement is just a concentration of mass calculation.


global X_binary;

%remove any non-cell wall pixels from the image.  this is done because we
%are only interested in the relative different between the stele cell wall
%pixels and cortical cell wall pixels.

IMAGE(X_binary ~= 0) = 0;


%define the dimensions of the bounding box used for sampling.  you need to
%make sure your box does not extend beyond the image indices.

halfBox1Dim = 10;


%find the indices of the cross section tissue without region eliminated by
%the spatial weights matrix previously calculated.

[row, col] = find(IMAGE ~= 0);


%create blank density image for output.

crossDens = zeros(size(IMAGE));


%implement for loop for calculating the tissue density.

for i = 1:length(row)
    
    %define the indices for the current bounding box.
    
    boundRow = (row(i) - halfBox1Dim):(row(i) + halfBox1Dim);
    boundCol = (col(i) - halfBox1Dim):(col(i) + halfBox1Dim);
    

    %define the pixels in the bounding box and calculate the sum of the box.
    
    pixels = IMAGE(boundRow, boundCol);
    
    density = sum(sum(pixels));
    
    %calculate the image contrast in the bounding box.  this value will be
    %used for the normalization of the density measurement.
    
    crossDens(row(i), col(i)) = density;
    
    
    
end;


%select all pixels whos pixel density is not zero.

pxvalslice = crossDens(crossDens ~= 0);


%define the minimum pixel density value.

pxmin = 255;


%define the maximum pixel density value.

pxmax = max(max(crossDens)) - 255;


%iteration step for modified ostu function.

step = max(max(crossDens))/255;


%run the modified otsu method for the segmentation of the stele region.

result = modotsu(pxvalslice, pxmin, pxmax, step);


%define the final stele image using the modified otsu results.

crossDens2      = ones(size(IMAGE));
crossDens2(crossDens <= result) = 0;





end