function diskRad = calcdiskrad(solidSegment2)

%this function will calculate the optimal radius for the outer
%cross-section pixel grouping.  



global solidSegment;


%calculate the perimeter images for the auto cross-section binary image and
%manual cross-section binary image.

autoBINperim = bwperim(solidSegment2);

manBINperim   = bwperim(solidSegment);



%calculate the x-com and y-com coordinates for the manual x-section
%segmentation choice.

[manY, manX] = find(manBINperim ~= 0);


%use these coordinates to calculate the center of mass.

xbar = mean(manX);
ybar = mean(manY);



%define the x-com and y-com coordinates for the automatic x-section
%segmentation choice.

[autoY, autoX] = find(autoBINperim ~= 0);



%normalize x and y-coordinates for both coordinate sets.

manX = manX - xbar; %manual x-section perimeter (x coordinate).
manY = manY - ybar; %automatic x-section perimeter (y coordinates).


autoX = autoX - xbar; %automatic x-section perimeter (x coordinate).
autoY = autoY - ybar; %automatic x-section perimeter (y coordinate).



%convert these normalized coordinate sets to polar coordinates.

[manTheta, manRadius] = cart2pol(manX, manY);

[autoTheta, autoRadius] = cart2pol(autoX, autoY);


%adjust theta coordinates by +2pi.

manTheta(manTheta < 0) = manTheta(manTheta < 0) + 2*pi;

autoTheta(autoTheta < 0) = autoTheta(autoTheta < 0) + 2*pi;



%at this time we can calculate all the radii to be considered for the
%optimization.


thetaVect = 0:(pi/20):2*pi;


%allocate memory for radial distance vector.

radialDist = zeros(size(thetaVect


for I = 1:(length(thetaVect) - 1)
    
    %define all the perimeter coordinates with theta slice and calculate
    %their mean radii value.
    
    manRADmean = mean(manRadius((manTheta >= thetaVect(I)) & ...
        (manTheta < thetaVect(I+1)))); %manual x-section coordinates.
    
    
    autoRADmean = mean(autoRadius((autoTheta >= thetaVect(I)) & ...
        (autoTheta < thetaVect(I+1)))); %manual x-section coordinates.
    
    
    
    




























end