function [XsectionCode, TCApix] = cf_poly(varargin)

%this function will allow user to isolate any radial cortex slice for use
%in the cortex cell file calculation.


global X_section_solid; %solid x-section image.
global    solidSegment; %solid stele image.
global    f_fig_handle; %structure containing all figure children properties.
global   AllImageSpecs;
global     DATA_MATRIX;
global        DirSpecs;


%remove_junk2 = varargin{1};
%remove_junk2(remove_junk2(:,3) < 0,3) = remove_junk2(remove_junk2(:,3) < 0,3) + 2*pi;


%initalize polygon in current image axes.  This axes should contain the
%result from the aerenchyma selections previously made.


%we need to fine the coordinates of the inner and outer cortical
%boundaries.  This will allow us to anchor some of the polygon vertices at
%those locations.  We can code this image.  code 1 (value = 128) represents the inner
%boundary and code 2 (value = 255) represents  the outer boundary.  all other pixels are
%code 0.

%define the coded cortex perimeter image.

coded_cortex = zeros(size(solidSegment), 'uint8');


%define the perimeter of the inner cortex.  this is simply just the
%perimeter of the solid stele image.

stele_perim               = bwperim(solidSegment);


%define the perimeter of the outer cortex.  this is simply just the
%perimeter of the solid x-section image.

cortex_perim           = bwperim(X_section_solid);



%assign codes to the coded cortex image now.

coded_cortex(stele_perim ~= 0)  = 128;  %assign code for inner cortex boundary.

coded_cortex(cortex_perim ~= 0) = 255; %assign code for outer cortex boundary.



%isolate all the values for the coded cortex image.

coded_cort_vals = double(coded_cortex(coded_cortex ~= 0));


%calculate the x and y coordinates for the coded cortex image.

[y, x]       = find(coded_cortex ~= 0);


%normalize x and y about the x-section center of mass.

meanX = mean(x);
meanY = mean(y);

x  = x - meanX;
y  = y - meanY;


%convert to polar coordinates.

[theta, rho]              = cart2pol(x, y);

theta(theta < 0) = theta(theta < 0) + 2*pi;
rho(theta < 0)     = rho(theta < 0) + 2*pi;

theta_count = sum(theta < (pi/4));




%move the coordinates back to their correct image indices.



%concatenate x, y, theta and rho.

coord_vect = horzcat(x, y, theta, rho, coded_cort_vals);

coord_vect                    = sortrows(coord_vect, 3);


%expand the radius of the sampling window.

coord_vect(coord_vect(:,5) == 128, 4) = coord_vect(coord_vect(:,5) == 128, 4) - .07*max(coord_vect(:,4));
coord_vect(coord_vect(:,5) == 255, 4) = coord_vect(coord_vect(:,5) == 255, 4) + .07*max(coord_vect(:,4));


%convert the expanded polar coordinates to the cartesian coordinates.

[x,y] = pol2cart(coord_vect(:,3), coord_vect(:,4));

x = floor(x + meanX);
y = floor(y + meanY);

coord_vect(:,1:2) = [x y];

coord_vect  = vertcat(coord_vect(end-theta_count:end,:), ...
    coord_vect, coord_vect(1:theta_count,:));

coord_vect(1:theta_count,3)             = coord_vect(1:theta_count,3) - 2*pi;
coord_vect(end-theta_count:end,3) = coord_vect(end-theta_count:end,3) + 2*pi;

coord_vect = sortrows(coord_vect, 3);


%initialize the polygon and set the original position to the top of the
%cross-section.  set the angular bandwidth to about 30 degs (pi/6).
%therefore the window radius is pi/12.

%note: there will only be 4 vertices in this polygon.


%initialized polygon now.


%set the current axes.

set(gcf, 'CurrentAxes', f_fig_handle.AXES(1)); 


%isolate the inner and outer cortex perimeter pixels within the bandwidth.

halfBand      = pi/12;
thetaMouse = (3*pi/2);


lowerbound  = thetaMouse - halfBand;
upperbound  = thetaMouse + halfBand;


%get the current polygon position.  

polyposition;


%initialize the polygon now.

h = impoly(gca, [c1; c2; c3; c4; c5; c6; c7; c8]);


%set the mouse down function now.

set(gcf, 'WindowButtonDownFcn', @movePoly);


%set the slider movement callback function.

set(f_fig_handle.IMAGE_NAME(6), 'Callback', @spreadWindow);


waitfor(f_fig_handle.IMAGE_NAME(2), 'Value', 1);



%create the image mask for export.

XsectionCode = createMask(h);


%retain only the cortical region.

XsectionCode((X_section_solid == 0) | (solidSegment ~= 0)) = 0;




%calculate the cortex thickness now based.

cortex_thickness = sqrt((c3(1) - c7(1))^2 + (c3(2) - c7(2))^2) - 2*.07*max(coord_vect(:,4));

DATA_MATRIX{DirSpecs.BATCH_ITER, 8}            = cortex_thickness/AllImageSpecs.CALIBlength; 




%isolate the cortex objects within the sample window.


%reset lower boundary if lower boundary is less than 0.





% lowerbound2 = lowerbound;
% upperbound2 = upperbound;
% 
% switch lowerbound < 0
%     
%     case 1
%         
%         lowerbound2 = (2*pi) + lowerbound;
%         
% end;
% 
% 
% %reset the upper boundary if upper boundary is greater than 2pi.
% 
% switch upperbound > 2*pi
%     
%     case 1
%         
%         upperbound2 = (upperbound - (2*pi));
%         
% end;
% 
% testbound = [abs(lowerbound - lowerbound2) abs(upperbound - upperbound2)];
% 
% 
% 
% 
% %isolate the cortex cell matrix data now.
% 
% switch max(testbound) == 0
%     
%     case 1
% 
%         remove_junk2 = remove_junk2((remove_junk2(:,3) >= lowerbound) & ...
%           (remove_junk2(:,3) <= upperbound), :);
%    
%     
%     case 0
%         
%         remove_junk2((remove_junk2(:,3) < lowerbound2) & (remove_junk2(:,3) > upperbound2),:)  = [];
% 
% end;
    


%calculate the total cortex area (pixel units).

TCApix = sum(sum(X_section_solid)) - sum(sum(solidSegment));

      
%-------------------------------------end of main script.-----------------------------------------%





%place callback and mouse button down functions here.





    function polyposition
        
        %isolate all the coordinates in the cortex window.
        
        cortex_window = coord_vect((coord_vect(:,3) >= lowerbound) & ...
            (coord_vect(:,3) <= upperbound), :);
        

        %isolate the perimeter coordinates for the inner and outer cortex.
        
        inner_cort = cortex_window(cortex_window(:,end) == 128, (1:2));
        
        outer_cort = cortex_window(cortex_window(:,end) == 255, (1:2)); 
       
        
        
        %define the coordinates of the polygon now.
        
        c1   = outer_cort(1,:); %outer cortex boundary, lower window boundary.
                
        c2   = inner_cort(1,:); %inner cortex boundary, lower window boundary.
        
        
        %define midpoint for inner cortex boundary.
        
        c3 = inner_cort(floor(.5*length(inner_cort)),:);
        
        
                       
        c4 = inner_cort(end,:); %inner cortex boundary, upper window boundary.
        
        c5 = outer_cort(end,:); %outer cortex boundary, upper window boundary.
        
        
        %find 3 midpoints for the outer cortex.
        
        c6 = outer_cort(floor(.75*length(outer_cort)),:); %outer cortex boundary, midpoint 1
        
        c7 = outer_cort(floor(.5*length(outer_cort)),:); %outer cortex boundary, midpoint 2
        
        c8 = outer_cort(floor(.25*length(outer_cort)),:); %outer cortex boundary, midpoint 2

        
                
    end


    %this function will evaluate the current mouse position relative to the
    %cross section to determine where the interactive cell file selection
    %polygon will be migrate to.

    function movePoly(varargin)
        
        %get the current position of the interactive polygon.
        
        currentPos_poly = getPosition(h);
        
        
        %get the current position of the mouse pointer.
        
        currentPos_mouse = get(gca, 'CurrentPoint');
        
        
        
        mouseX = currentPos_mouse(1,1) - meanX;
        mouseY = currentPos_mouse(1,2) - meanY;
        
        [thetaMouse, rho] = cart2pol(mouseX, mouseY);
        
        
        switch thetaMouse < 0
            
            case 1
                
                thetaMouse = thetaMouse + 2*pi;
                
        end;
        
        lowerbound = thetaMouse - halfBand;
        upperbound = thetaMouse + halfBand;
        
        
        %calculate the vertices of the new polygon position.
        
        polyposition;
        
        
        %update polygon position;
        
        delete(h);
        
        h = impoly(gca, [c1; c2; c3; c4; c5; c6; c7; c8]);
        
        
    end




    function spreadWindow(varargin)
        
        %get the current slider position.
        
        halfBand = pi*get(f_fig_handle.IMAGE_NAME(6), 'Value');
        
        
        %define the lower and upper bound for the sampling window.
        
        lowerbound = thetaMouse - halfBand;
        upperbound = thetaMouse + halfBand;
        
        
        %determine the new polygon position.
        
        polyposition;
        
        
        %update the polygon position.
        
        delete(h);
        
        h = impoly(gca, [c1; c2; c3; c4; c5; c6; c7; c8]);
        

        
    end







end