function checkBinary

%this function will verify that all images were correctly converted to
%their binary equivalent using our defined methods.  If any image fails any
%test it must be converted again using the same methods. 

global AllImageSpecs;
global   data_matrix;
global        h_wait;

%define current directory.

currentDir = cd;


%access the sub-directory storing all binary files.

cd([currentDir AllImageSpecs.fileSeparator 'X_section_binary']);


%identify binary image directory.

BINdirectory = dir('XS_binary*');



%access the sub-directory storing x-section segmentation truncation image
%files.

cd([currentDir AllImageSpecs.fileSeparator 'X_section_segments']);


%identify one subset of images from each triplet for size comparisions.

XSdirectory = dir('XS.*');




%for each binary image run our two tests for image verification.

numIM = numel(BINdirectory);

for i = 1:numIM

    %go to the subdirectories containing the binary x-section images for
    %that directory.
    
    cd([currentDir AllImageSpecs.fileSeparator 'X_section_binary']);


    %define image.

    BINimage = imread(BINdirectory(i).name);
    
    
    %test 1: determine if cell area and cell structure are present.  Does the
    %image have both 1's and 0's.

    BINrange = max(max(BINimage)) - min(min(BINimage));


    %test 2: determine if the dimensions are consistant with results from the
    %cross-section segmentation truncation step.

    rawName = data_matrix{i,1};


    %go to the subdirectory containing the x-section image results from the
    %x-section segmentation step.
    
    cd([currentDir AllImageSpecs.fileSeparator 'X_section_segments']);


    %read in an image from the x-section segmentation step.
    
    SEGimage = imread(['XS.' rawName]);



    %compare the two images based on their dimensions.

    BINsize = size(BINimage) == size(SEGimage);

    BINsize = sum(BINsize);


    %if the images fail the test. convert them to binary images again.

    if (BINrange == 0) | (BINsize ~= 2)

        %read in the solid x-section image.

        SOLIDxs = imread(['SOLID_XS.' rawName]);


        %go to the current directory.

        cd(currentDir);


        %define the name of the image file.

        findPeriod = find(rawName == '.', 1, 'last');
        rawName(findPeriod:end) = [];


        %run the x-section binarization code now.

        local_threshold_method(SEGimage, SOLIDxs, i);

    end;


    %update the waitbar.
    
    percent_done = i/numIM;

    waitbar(percent_done, h_wait, [num2str(floor(percent_done*100), 3) ' % Complete']); 



end;


%once the user is finished checking the binary images GO to the current
%parent image directory.

cd(currentDir);


waitbar(1, h_wait, 'Binary Image Validation Process Complete');



end