function bound_coords = check_cort_count(varargin)

%this function checks the actual cortex cell count against the expected
%count to determine the validity of the value.


%define the cortex cell data.

non_aeren        = varargin{1};


%define the radius coordinates used in the calculations.

max_min_rad      = varargin{2};


%define the percent area allocated to aerenchyma.

total_lac_area   = varargin{3};


%define the median cortex thickness.

cortex_thickness = varargin{4};




%subset all cortex cell objects between .4 and .6 normalized distance.
%These cortex objects are chosen since they most likely represent the
%general cell size for the entire cortex barring any fluctuations due to
%boundary cells.  we are only looking for a general range with limited
%accuracy.

cc_subset = non_aeren((non_aeren(:,4) >= .4) & (non_aeren(:,4) <= .6),7);


%remove all values less than 3.

cc_subset(cc_subset <= 3) = [];


%remove all outliers from the data subset.  this will help fine tune the
%expect cell count range for our comparisions.

mean_cc     = mean(cc_subset);

std_cc = sqrt(std(cc_subset));


%remove the low and high end outliers.

cc_subset(cc_subset < (mean_cc - std_cc)) = [];
cc_subset(cc_subset > (mean_cc + std_cc)) = [];


mean_cc   = median(cc_subset);

std_cc = sqrt(std(cc_subset));


%remove the low and high end outliers.

%cc_subset(cc_subset < (mean_cc - (1.5*std_cc))) = [];
%cc_subset(cc_subset > (mean_cc + (1.5*std_cc))) = [];





%allocate memory for the boundary coordinates calculated for both loop
%runs.  the first iteration will calculate the lower boundary coordinates.  the
%second iteration will calculate the upper boundary coordinates. 

bound_coords = zeros(2,2);


%calculate the lower and upper cortex cell size boundaries.

for li = 1:2


    switch li

        case 1

            %calculate the upper cell size cutoff.  this will be used to
            %calculate the lower boundary coordinates.

            med_deltaS = mean(cc_subset) + sqrt(std(cc_subset));


        case 2

            %calculate the lower cell size cutoff.  this will be used to
            %calculate the upper boundary coordinates.

            med_deltaS = mean(cc_subset) - sqrt(std(cc_subset));
                        
                        
            %if the range is less than zero then reduce the
            %standard deviation term to .2 the original value.

            switch med_deltaS <= 0

                case 1

                med_deltaS = mean(cc_subset) - (.2*sqrt(std(cc_subset)));


            end;


    end;



    %calculate the direction range for this cell diameter (outer
    %cortex).  this value reflects how much angular space is allocated to a
    %typical cell plus its cell wall border.

    med_delta_th = 1.2*med_deltaS/max_min_rad(1);


    %calculate the total number of cells in the outer cell file
    %ring.

    total_outer              = 2*pi/med_delta_th;



    %calculate the direction range for this cell diameter (inner
    %cortex).  this value reflects how much angular space is allocated to a
    %typical cell plus its cell wall border.

    med_delta_th = 1.1*med_deltaS/max_min_rad(2);


    %calculate the total number of cells in the inner cell file
    %ring.

    total_inner              = 2*pi/med_delta_th;


    %calculate the approximate number of cell files.  This calculation
    %is based on the cell size and cortex thickness.add in the
    %cell wall boundary.  the boundary is roughly 5% of cell

    cells_in_slice = floor(cortex_thickness/(1.1*med_deltaS));


    %calculate the slope parameter for the number of cell file
    %rings between the inner and outer cortex rings.  This value is used to
    %interpolate the number of cells in each cell file ring.

    ring_slope = (total_outer - total_inner)/cells_in_slice;


    %calculate the total number of cells in cortex use the above slope parameter
    %assuming there is no aerenchyma present.

    cell_ring_vector = ((1:cells_in_slice)*ring_slope) + total_inner;


    %sum the entire cell file ring data.  this value is the total number of
    %cells assuming there is no aerenchyma present.
    
    bound_coords(li,1) = sum(cell_ring_vector);


    %calculate the total number of cells in cortex assuming the
    %actual aerenchyma is present.

    bound_coords(li,2) = (1-total_lac_area)*bound_coords(li,1);



end;
            
            
%round boundary coordinates to the nearest integer value.

bound_coords = floor(bound_coords);
            


end