function checkboxFcn(varargin)

%this function evaluates the current check box selection/de-selection to
%determine if any checkboxes associated with any dependent variables are to
%be select/de-selected.  The results from each check box are used to code
%the data matrix if a measure is deemed to be unfit for analysis.


%read in all global variables at this time.

global f_fig_handle; %contains all button handles


%------get the previous checkbox values------%


%get the previous checkbox values ---group 1

group1_prev = f_fig_handle.checkGroup1(2,:);



%get the previous checkbox values ---group 2

group2_prev = f_fig_handle.checkGroup2(2,:);



%get the previous checkbox values ---group 3

group3_prev = f_fig_handle.checkGroup3(2,:);





%------get the current checkbox values------%


%get the current checkbox values ---group 1

group1_current = get(f_fig_handle.checkGroup1(1,:), 'Value');
group1_current                   = cell2mat(group1_current)';


%get the current checkbox values ---group 2

group2_current = get(f_fig_handle.checkGroup2(1,:), 'Value');
group2_current                   = cell2mat(group2_current)';



%get the current checkbox values ---group 3

group3_current = get(f_fig_handle.checkGroup3(1,:), 'Value');
group3_current                   = cell2mat(group3_current)';







%------determine which checkbox was selected------%

group_test = zeros(3,1);

%test group 1. -- aggregate data.

group1_test = abs(group1_current - group1_prev);
group_test(1)                = max(group1_test);


%test group 2. -- Lacunae and cortex cell data.

group2_test = abs(group2_current - group2_prev);
group_test(2)                = max(group2_test);


%test grou 3. -- Meta- and Proto- Xylem Vessel data.

group3_test = abs(group3_current - group3_prev);
group_test(3)                = max(group3_test);



%find the indice of the current group whos checkbox was selected.

check_index = find(group_test == 1);



%insert a switch statement to determine which selection/de-selection
%function to run.

switch check_index
    
    
    case 1 %a checkbox from group 1 was selected
        
        
        %assign group 1 test data to target group.
        
        target_group = group1_test;
        group          = 'group 1';
        
    case 2 %a checkbox from group 2 was selected.
        
        
        %assign group 2 test data to target group.
        
        target_group = group2_test;
        group = 'group 2';
        
    case 3 %as checkbox from group 3 was selected.
        
        
        %assign group 3 test data to target group.
        
        target_group = group3_test;
        group = 'group 3';
        
        
        
        
end;


%define the initial checkbox values.

group1_new = group1_current;
group2_new = group2_current;
group3_new = group3_current;


%find the only non-zero index.
                
no_0_index = find(target_group == 1);
        
%define the sizes of the groups.
                
group1_s = size(group1_current);
group2_s = size(group2_current);
group3_s = size(group3_current);



        %run the test based on the group.
        
        switch group
            
            case 'group 1' %test group 1 checkboxes.
                
                
                     

                
                
                
                %determine which dependent checkboxes are unselected at
                %this time.
                
                
                switch no_0_index
                    
                    
                    case 1 %user selected/de-selected Root cross-section area.
                           %the entire cross-section is fit or unfit for
                           %analysis.
                           
                           
                        %determine the values for all check boxes now.
                        
                        group1_new = zeros(group1_s) + group1_current(no_0_index); %select/de-select all now.
                        
                        
                        group2_new = zeros(group2_s) + group1_current(no_0_index); %select/de-select all now.
                        
                        
                        group3_new = zeros(group3_s) + group1_current(no_0_index); %select/de-select all now.   
                
                        
                    case 2 %user selected/de-selected Total cortex area.
                           %The entire cortex is fit or unfit for analysis.
                           
                           
                        %determine the values for all checkboxes now.
                           
                        group1_new =                               group1_current; %set the new group to the current group.
                        group1_new(1:4)              = group1_current(no_0_index); %set total cross-section area and cortex data now.
                        
                        group2_new = zeros(group2_s) + group1_current(no_0_index); %select/de-select all now.
                        group2_new(1)                            = group2_prev(1); %keep lacunuae data.
                        
                        group3_new                               = group3_current; %keep all xylem data.                         
                        
                
                
                    case 5 %user selected/de-selected Total stele area.
                           %the entire stele is fit or unfit for analysis.
                           
                         %determine the values for all checkboxes now.
                           
                        group1_new                               = group1_current; %select/de-select all now.
                        group1_new(5:end)            = group1_current(no_0_index); %keep aggregate cortex data.
                        
                        group2_new                               = group2_current; %keep all cortex data.
                        
                        group3_new                               = group3_current; %keep all meta and proto xv data.                          

                        
                
                end;
                
                
               
                
            case 'group 2' %test group 2 checkboxes.
                
                
                switch no_0_index
                    
                    case 3  %user selected/de-selected cortex cell count. take
                            %action on cortex cell area also.
                            
                         %determine the values for all checkboxes now.
                        
                        group1_new                               = group1_current; %select/de-select all now.

                        group2_new                               = group2_current;
                        group2_new(3:4)              = group2_current(no_0_index); %set ccc and cca to zero.
                        
                        group3_new                               = group3_current; %keep all meta and proto xv data.                          
                        
                        
                        
                end;
                        
                        
                
                
                
                
                
            case 'group 3' %test group 3 checkboxes. there are no special options at this time.
                
              
                
                
                
                
        end;
        
        
     
        
        %set the values for group 1.
        
        for i = 1:size(group1_current,2)
            
            set(f_fig_handle.checkGroup1(1,i), 'Value', group1_new(i)); %check/uncheck the box.
            f_fig_handle.checkGroup1(2,i)              = group1_new(i); %update the previous value.

        end;
        
        
        
        %set the values for group 2.
        
        for i = 1:size(group2_current,2)
            
            set(f_fig_handle.checkGroup2(1,i), 'Value', group2_new(i)); %check/uncheck the box.
            f_fig_handle.checkGroup2(2,i)              = group2_new(i); %update the previous value.

        end;
        
        
        
        %set the values for group 3.
        
        for i = 1:size(group3_current,2)
            
            set(f_fig_handle.checkGroup3(1,i), 'Value', group3_new(i)); %check uncheck the box.
            f_fig_handle.checkGroup3(2,i)              = group3_new(i); %update the previous value.

        end;        
        
        

        
        
    






end