function CodeStele = closeLat(CodeStele)

%this function will isolate the lateral region closet to the stele region.
%we need this region for closing the gap between the stele and lateral.


%create label matrix for lateral region and 2 intersecting nodes.

[labelCode, maxNode] = bwlabel(CodeStele);



%define the center mass coordinates and area values for the label matrix.

RegProps = regionprops(labelCode, 'Centroid', 'Area');


%place these variables into matrix with size N X 4.  c1=index, c2=x-coord,
%c3=y-coord and c4=area.

catProps = horzcat((1:maxNode)', cat(1, RegProps.Centroid), cat(1, RegProps.Area));
    

%sort these rows from largest to smallest.

catProps = sortrows(catProps, -4);


%define the largest object in the label matrix.

largestObj = catProps(1,1);


%modify the center of mass coordinates for the intersection nodes so that
%the pixel furtherest from the lateral center of mass becomes the new
%center of mass.

%catProps = shiftNodes(catProps, labelCode);



%retain only the two points of intersection.

catProps(1,:) = [];


%find all the row and column indices for the largest object.

[row, col] = find(labelCode == largestObj);



%find the closest lateral perimeter coordinate to each node of
%intersection.

for i = 1:2
    
    xo = catProps(i,2);
    yo = catProps(i,3);
    
    dist = sqrt((row - yo).^2 + (col - xo).^2);
    

    %find the min distance.
    
    minDistRow = row(dist == min(dist));
    minDistCol = col(dist == min(dist));
    
    
    %cut the lateral using a 4 X 4 pixel buffer.
    
    buffer = 2;
    
    CodeStele((minDistRow - buffer):(minDistRow + buffer), ...
        (minDistCol - buffer):(minDistCol + buffer))     = 0;
        
    
    %remove each nodes of intersection.

    CodeStele(labelCode == catProps(i,1)) = 0;
    
end;




%remove the largest object from the broken lateral region.

labelObjs            = bwlabel(CodeStele);

modeObj = mode(labelObjs(labelObjs ~= 0));

CodeStele(labelObjs == modeObj)       = 0;




%if a piece of any node still exists in the image then remove it now.

if max(max(labelObjs)) >= 3

    labelObjs(labelObjs == modeObj) = 0;

    modeObj = mode(labelObjs(labelObjs ~= 0));

    CodeStele(labelObjs ~= modeObj)       = 0;


end;


end