function cortexData = cort_obj_norm(cortexData)

%this function with covert the cortex object radii measurements to
%normalized radii coordinates relative to its position between the inner
%cortical boundary and outer cortical boundary.

%this function function was originally found in the function called:
%AUTO_AERENCHYMA.m


    global          Coms; %x-section center of mass coordinates.
    global      X_binary; %x-section binary image.
    global  solidSegment; %solid x-section image.
    global   data_matrix; %rootscan data matrix.
    global      DirSpecs; %directory specifications.
    global AllImageSpecs; %image specifications.


    %radius measurements are indexed by inner cortex cell wall rather than 
    %the inner most cell file (this change was made novemeber 19, 2010).


    %create dummy binary X-section image so we do not overwrite the real binary
    %x-section image. call the image X_binary2.  when we are done with
    %image manipulation we will have a cortex binary with stele area and
    %back ground being white

    X_binary2                  = X_binary;


    %whiten out stele area.  all you should have left is a binary cortical region.

    X_binary2(solidSegment ~= 0)          = 1;
    X_binary2(bwperim(solidSegment) == 1) = 0;    



    %define the row and column indices of the cortical cell wall.    

    [row_cortex_binary, col_cortex_binary] = find(X_binary2 == 0);


    %normalized these coordinates with respect to the x-section center of mass.

    col_cortex_binary = col_cortex_binary - Coms(1);
    row_cortex_binary = row_cortex_binary - Coms(2);


    %convert these values to polar coordinates.

    [theta_cortex_binary, rho_cortex_binary] = cart2pol(col_cortex_binary, row_cortex_binary);

    theta_cortex_binary(theta_cortex_binary < 0) = theta_cortex_binary(theta_cortex_binary < 0) + 2*pi;




    %define theta interval for the normalization procedure.

    theta = 0:(pi/45):2*pi;
    
    
    %allocate memory for cortex thickness measurements.
    
    cortex_thickness = zeros(length(theta) -1,1);
    


    %for each theta interval (i.e. direction range). calculate the normalized
    %distance between the inner and outer cortex.  this normalization will
    %reduce the directional bias of the normalized distance calculation.  this
    %is the way it should be done.  If one wants to the reduce the theta
    %interaval for more accuracy then one can adjust the above variable :
    %theta.


    for i = 1:(length(theta) - 1)


        %define lower bound for theta interval.

        lower_bound = theta(i);


        %define upper bound for theta interval.

        upper_bound = theta(i+1); 


        %sample attribute data from theta region.  

        sample_index = find((cortexData(:, 3) >= lower_bound) & ...
            (cortexData(:, 3) < upper_bound));


        %define cell structure with theta region. 

        cell_wall = rho_cortex_binary((theta_cortex_binary >= lower_bound) ...
            & (theta_cortex_binary < upper_bound)); 


        %define radius of inner-most cell wall pixel within delta theta slice.

        min_radius = min(cell_wall); 


        %define raduis of outer-most cell wall pixel within delta theta slice.

        max_radius = max(cell_wall); 

        
        %define the cortex thickness for each sample slice.
        
        cortex_thickness(i) = max_radius - min_radius;
        

        %define normalized radius for cells within theta slice.

        cortexData(sample_index, 4) = (cortexData(sample_index, 4) - ...
            min_radius)/(max_radius - min_radius);



    end;

    
    
    
    %calculate the overall cortex thickness for the cross-section.
    
    data_matrix{DirSpecs.iteration, 8} = median(cortex_thickness)/AllImageSpecs.calib_length; 
    
    
   
end