function non_aeren = cortex_noise_reduct(varargin)

%this function will attempt to reduce any noise prior to calculating cortex
%cell data.



    %define the cortex data matrix.

    non_aeren = varargin{1};

        
    %remove all objects with pixel area less than 
        
    non_aeren(non_aeren(:,1) <= 25, :) = [];

    
    
    %since cortex cell size varies from the inner to outer cortex we need to
    %evaluate cortex cells and noise within each radial band from 0 to 1 with
    %an interval of .1.


    band_vect = 0:.1:1;



    for i = 1:(size(band_vect,2) - 1)
        
        
        %define the lower and upper radial boundary.
        
        lower_bound   = band_vect(i);
        
        upper_bound = band_vect(i+1);


        %subset the cortex cell data.
        
        cortex_subset = non_aeren((non_aeren(:,4) >= lower_bound) & ...
            (non_aeren(:,4) <= upper_bound),:);


        
        %test the cortex data and remove all noise.  
        
        meanSize = mean(cortex_subset(:,1));
        
        stdSize = sqrt(2)*std(cortex_subset(:,1));
        
        
        
        %define the lower and upper boundaries for the statistical cutoff.
        
        neg_sigma = meanSize - stdSize;
        pos_sigma = meanSize + stdSize;
        
        
        
        %keep the low and high end size objects in the cortex data
        %subset.
        
        cortex_subset = cortex_subset((cortex_subset(:,1) < neg_sigma) | ...
            (cortex_subset(:,1) > pos_sigma), :);
        
        
        
        %use the ismember function to find membership of the cortex subset
        %data to the entire cortex data matrix.
        
        member_index = ismember(non_aeren(:,2), cortex_subset(:,2));
        
        
        %make adjustments to the non_aeren data matrix.
        
        non_aeren(member_index == 1,:) = [];



    end;
































end