function cvrt2tif

%this function will convert output images to tif format if needed.


global AllImageSpecs;



%allow user to select a directory.

directory = uigetdir;


%load data matrix

data_matrix = load([directory AllImageSpecs.fileSeparator 'DATA_MAT.mat']);
data_matrix                                     = struct2cell(data_matrix);  
data_matrix                                             = data_matrix{1,1};  



%determine if the dataset is complete by evaluating the value of the last
%3rd column, last row position.

complete_value = data_matrix{end,3};


switch (complete_value ~= -1)
    
    
    case 1 
        
        %the dataset is complete. proceed with the conversion.
        
        
        %initialize waitbar for rgb2tiff conversion status.
        
        conv_wait = waitbar(0, 'Initializing Image To Tiff Converter...');
        
        
        numIM = size(data_matrix,1);
        
        for i = 1:numIM
        
        
            current_ID = data_matrix{i,1};
            
            %read in the coded region image.  1-d.
            
            filename = [directory AllImageSpecs.fileSeparator 'Image_Output' ...
                AllImageSpecs.fileSeparator current_ID AllImageSpecs.fileSeparator ...
                'Highlight_RGB_region.' current_ID];
            
            
            %check to see if file exists.
            
            file_exists = exist(filename, 'file');
            
            
            switch file_exists
                
                case 2
            
                    coded_region = imread(filename);        


                    %go to image output directory.

                    cd([directory AllImageSpecs.fileSeparator 'Image_Output' ...
                        AllImageSpecs.fileSeparator current_ID]);

                    %check for tif files.

                    tif_dir = dir ('*.tif');


                    switch numel(tif_dir)

                        case 0


                        %read in the binary xs image.

                        binary_im = imread([directory AllImageSpecs.fileSeparator 'X_section_binary' ...
                            AllImageSpecs.fileSeparator 'XS_binary.' current_ID]); 



                        %create label matrix for binary image.

                        binary_label = bwlabel(binary_im);




                        %create dummy image to store the new pixels values into.

                        new_region = (coded_region*0) +255;
                        new_region(binary_im == 0)     = 0;


                        %evaluate each label object and assign the color mode to the
                        %object.

                        for j = 1:max(max(binary_label))


                            %define the color mode of the object.

                            colorMode = mode(double(coded_region(binary_label == j)));


                            new_region(binary_label == j) = colorMode;



                        end;



                        %recode stele cell wall now.


                        %find all cell wall pixels.

                        cw_pixels = coded_region(binary_im == 0);


                        %find the pixel threshold to separate out the cortex cell wall pixels
                        %from the stele cw wall pixels.

                        thr = graythresh(cw_pixels);


                        %remove cortex cell wall pixels from dataset.

                        cw_pixels(cw_pixels <= 255*thr) = [];


                        %define the color mode.

                        colorMode = mode(double(cw_pixels));


                        %replace all pixel values with the color mode.

                        new_region((coded_region >= min(cw_pixels)) & ...
                            (coded_region <= max(cw_pixels)) & (binary_im == 0)) = colorMode;




                        %write the data to image format tif.

                        index = find(filename == '.', 1, 'last');

                        filename = [filename(1:index) 'tif'];

                        imwrite(uint8(new_region), filename, 'tif');


                    end;
            
            
            
            end;
        
            
            percent_done = i/numIM;
            
            waitbar(percent_done, conv_wait, [num2str(floor(percent_done*100), 3) ' % Complete']);
            
            
        
        end;
        
        
        
    case 0
        
        
        
end;



end