function cw_thick_measure(varargin)

%this function will calculate the cell wall thickness in all areas of the
%cross-section and give numerial results for later use.


%list global variables now.

global  solidSegment; %solid stele image.
global      X_binary; %binary cross-section image.
global   data_matrix; %main data matrix.
global AllImageSpecs; %image specifications structure.
global      DirSpecs; %directory spefications structure.



%create my own label matrix using radial and theta slices.


my_label = ones(size(X_binary)) - 2;

my_label(X_binary == 0)         = 0;

my_label(solidSegment ~= 0)    = -1;



%define the row and column vectors that designate our label boxes

row_vector = 1:(size(X_binary,1)/50):size(X_binary,1);
col_vector = 1:(size(X_binary,2)/50):size(X_binary,2);



%--------------------------create my label matrix-------------------------%



%initialize counter variable.

counter = 1;



for i = 1:(size(row_vector,2) - 1)
    
    %define the lower boundary.
    
    lowerbound   = floor(row_vector(i));
    
    
    %define the upper boundary.
    
    upperbound = floor(row_vector(i+1));
   
    
    
    for j = 1:(size(col_vector,2) - 1)
        
        %define inner rho boundary.
        
        innerbound = floor(col_vector(j));
        
        
        %define outer rho boundary.
        
        outerbound = floor(col_vector(j+1));
        
       
        %define the max pixel value of the binary cortex image.
        
        max_cortex = max(max(my_label(lowerbound:upperbound,innerbound:outerbound)));
        
        
        %apply label only when cell wall pixels are contained within the
        %sampling window.
        
        switch max_cortex ~= -1
            
            case 1
        
            my_label(lowerbound:upperbound,innerbound:outerbound) = counter;
       
      
            counter = counter + 1;
        
        end;
        
        
    end;
    
 
    
    
end;



%remove all non cell wall pixels from label matrix.  the cell wall pixels
%are the only labeled objects now.

my_label(X_binary == 1)  = 0;

my_label(solidSegment == 1)      = 0;


%determine the length of the cell wall erosion optimization matrix.

minLabel = min(min(my_label));
maxLabel = max(max(my_label));


%define the cell wall erosion optimization matrix.  

erosion_mat = zeros((maxLabel - minLabel + 1), 52);




%place the label indices into matrix now.




for i = 1:(maxLabel - minLabel + 1)
    
    %find the index, its center of mass (row and column indices) and place
    %them into the matrix.
    
    index = find(my_label == minLabel);
    
    
    %determine if any of the label pixels are cell wall.  if any are cell
    %wall pixels then label them only.
    
    

    
    if min(min(X_binary(index))) == 0
            
            %assign the label index to the matrix.
            
            erosion_mat(i,1)             = minLabel;
            
            
            %define the row and column center of mass coordinates.
            
            [row, col] = find(my_label == minLabel);
            
            
            %mean column and mean row.
            
            erosion_mat(i,2)            = mean(col);
            erosion_mat(i,3)            = mean(row);
            
            
            %calculate the area of the object.
            
            erosion_mat(i,4)        = length(index);

            
    end;
    
 
    %update label counter.
    
    minLabel = minLabel + 1;
    
    
    
end;



%remove all non-cell wall label locations from the matrix.

erosion_mat(erosion_mat(:,1) == 0, :) = [];



%run the erosion optimization method.

%initialize the erosion radius parameter.  this value will increase by 1
%each iteration.

erosion_rad = 1;


%initialize the iteration counter.  this value will increase by 1 each
%iteration and is used to index the data columns.

iteration = 1;


done_erode = false;


%invert the binary image.

binary_IM2 = imcomplement(X_binary);


%erode the x-section until nothing is left.

while (done_erode == false)
    
    
    %erode the x-section image now.
    
    binary_erode = imerode(binary_IM2, strel('disk', erosion_rad));
    
    
    %evalulate each label object to determine how much cell wall remains
    %after the current erosion.  these numbers will be percents.
    
    for i = 1:size(erosion_mat,1)
        
        erosion_mat(i,(5 + iteration)) = ...
            length(find(binary_erode(my_label == erosion_mat(i,1))) == 1)/erosion_mat(i,4);
        
    end;
    
    
    
    %test the results to determine if erosions should continue.
    
    max_percent = max(erosion_mat(:,(5 + iteration)));
    
    
    %if all objects have less than 10% cell wall remaining or you went more
    %than 40 iterations then update the condition statement to true and
    %exit the 'while' statement.
    
    switch (max_percent < .10 | erosion_rad > 40)
        
        case 1
            
            done_erode = true;
            
            
            
    end;
    
    
   %update the counter variables. 
    
    erosion_rad = erosion_rad + 1;
    iteration     = iteration + 1;
    
 
    
    
end;




%find the cell wall thickness based on the erosion data.

for i = 1:size(erosion_mat,1)
    
    %find the index of the percent cell retainment value that becomes
    %zeros.
    
    erosion_mat(i,5) = find(erosion_mat(i,6:end) <= .0001, 1, 'first');
    
    
end;



%calculate the median cortex cell wall thickness.

med_thick = median(erosion_mat(:,5));


%calculate the standard deviation in cell wall thickness.

std_thick    = std(erosion_mat(:,5));


%calculate the cell wall thickness range.

range_thick = range(erosion_mat(:,5));



%assign cortex cell wall thickness statistics to data matrix.
        
data_matrix{DirSpecs.iteration, 47}   = med_thick/AllImageSpecs.calib_length;
data_matrix{DirSpecs.iteration, 48}   = std_thick/AllImageSpecs.calib_length;
data_matrix{DirSpecs.iteration, 49} = range_thick/AllImageSpecs.calib_length;




end