function data_output(current_mode, matrix_size, directory_name)

%this function processes all data contained in the data matrices
%for a given image directory. this function will only execute and 
%process data when all images have been analyzed.


    global AllImageSpecs DirSpecs;

            
            
	%determine if the user selected the data output option.
            
    if (current_mode == 2)
                
        DirSpecs.programMode = -2;
                
	end;

            
            
	%determine which data output mode the user is currently operating in.

	switch current_mode  
                
        case 2 %the user needs to select a completed directory to re-run the data output.
                    
                       
        %select the directory.       
                       
        directory_name = uigetdir;
                
                
        %change directory to directory chosen by user..
                
        cd(directory_name)
           

        %find the size of the data matrix stored in this directory if it exists.
        %the comparison of the cell array and matrix sizes will tell us if the
        %directory is complete.  for example, if the size of the cell array 
        %is equal to the size of the data matrix then the user is complete with
        %the directory.  on the otherhand, if the cell array size is less than
        %the data matrix size then the user is not completed with the analysis
        %in a particular directory.
                
                
                
        %find the DATA_MAT.mat file if it exists. %if it exists, 
        %num_samples should equal 1. if not, then num_samples equals 0. 
                
        data_directory = dir ('DATA_MAT.mat');   
        num_samples   = numel(data_directory); 
                

        %if the data exists, check the number of data rows filled with
        %data and compare then the number of images in the directory.
                
        if (num_samples == 1) 
                    
                    
            %load the data matrix and convert initial data structure to cell
            %array. calculate the array cell size in the first dimension.
                    
            data_cell_array         = load('DATA_MAT.mat');
            data_cell_array = struct2cell(data_cell_array);
            data_cell_array    = data_cell_array{1,1}(:,2);
                    
            cell_array_size = size(data_cell_array,1);
                    
                    
            %covert cell array to data matrix format and calculate the matrix
            %size in the first dimension.
                    
            data_matrix = cell2mat(data_cell_array);
                    
            matrix_size = size(data_matrix,1);
                    
                    
                    
            %check the cell array size and matrix size to see if the directory is completed.
                    
                    
            %if both sizes are equal then we can proceed to data output.
                                      
            if (cell_array_size == matrix_size)  
                        
                        
            	%define the directory name, append /data/ to the  current directory. 
                %the data file will be stored in this sub-directory and make the sub-directory.
                        
                directory_name =                                                                   cd;  
                outputDirectory ...
                    = [directory_name AllImageSpecs.fileSeparator 'DATA' AllImageSpecs.fileSeparator];  
                                                                               mkdir(outputDirectory);  
                        
                                          
                %this parameter determines if the program can move on to the
                %data output section of the code.  in this case, the program
                %proceeds to the data output option.                 
                                          
                output_condition = 1;   
                     
                        
                
                    
            else %the current directory is incomplete. 
                        
                        
            	%define question string for question dilaog box.
                        
                question_part1 = 'Analysis for this directory';
                question_part2 = 'incomplete. Would you like to';
                question_part3 = 'complete the current directory?';
                        
                question = [question_part1 question_part2 question_part3];
                        
                        
                %incomplete directory. ask user to complete the directory.
                        
                choice = questdlg(question , 'Status', {'Yes', 'No'});  
                        
                        
                %do not proceed to data output option.
                        
                output_condition = 0;  
                        
                        
                switch choice
                        
                            
                %user wants to complete batch analysis for current directory.
                            
                	case {'Yes'}  
                            
                    complete_batch_condition = 1;
                                
                                
                    %user does not want to complete batch analysis for
                    %current directory.
                            
                    case {'No'}  
                            
                    complete_batch_condition = 0;
                            
                end;
                        
                        
            end;
                        
                        
        %data matrix file does not exist.  ask the user if they want to start
        %analyzing the current directory. 
                
        else 
                    
                    
            %define question string for question dilaog box.
                        
            question_part1 = 'No Images were Anaylzed in this directory';
            question_part2 = 'yet. Would you like to start a batch';   
            question_part3 = 'analysis for the current directory?';
                    
            question = [question_part1 question_part2 question_part3];
                    
                    
            %ask the user if they want to start analyzing the current directory.
                    
            choice = questdlg(question  , 'Status', {'Yes', 'No'}); 
                    
                    
                    
            output_condition = 0; %do not proceed to data output option.
                    
                    
            switch choice
                                   
                case {'Yes'} %yes, they would like to start a batch analysis
                             %for the current directory. 
                                          
                complete_batch_condition = 1;  
                                
                                        
                case {'No'} %no, they would not like to start a batch analysis
                            %for the current directory.
                            
                complete_batch_condition = 0;
                                       
            end;
                    
                    
        
	end;
                 
                
                
	%this is post batch analysis data processing mode.  the
	%user just recently (a couple of seconds ago) completedd
	%the directory.
                
    case 1 
                
                    
    %define the directory name.
                
    directory_name = cd; 
                
                
	%append /DATA/ directory to the current directory if it does not exist 
    %already.  the data file will be stored in this sub-directory and make 
    %the sub-directory.
      
    
    
    outputDirectory = [directory_name AllImageSpecs.fileSeparator ...
    	'DATA' AllImageSpecs.fileSeparator]; 
    
    switch exist(outputDirectory, 'dir')
        
        case 0
    
        mkdir(outputDirectory);  
                
                     
    end;
    
    %in this case, the program proceeds to the data output option.                  
                                  
    output_condition = 1;  
                      
                
end;


            
            
%-----------PROCEED TO THE DATA OUTPUT SECTION OF CODE----------------%
%-----------PROCEED TO THE DATA OUTPUT SECTION OF CODE----------------%
%-----------PROCEED TO THE DATA OUTPUT SECTION OF CODE----------------%


    %data ready for batch analysis.

    if (output_condition == 1)  


        %accessed the actions file to determine what data is output.  the
        %action file tells us which data are to included in the data output
        %based on the user settings.


        %find the path to the root scan main programs directory.

        pathway1                                          = which('data_output.m');
        find_last_break = find(pathway1 == AllImageSpecs.fileSeparator, 1, 'last');  
        pathway1                                     = pathway1(1:find_last_break); 




        %determine where the file is to be read from.



        if (DirSpecs.programMode == -2) %we have a directory.


            %define path to INTERVAL_MAT.mat file.

            pathwayINT =               [cd AllImageSpecs.fileSeparator 'INTERVAL_MAT.mat']; 


            %load the current calibration settings.

            load_calibration_settings =            load([cd AllImageSpecs.fileSeparator 'CALIB_MAT.mat']);  


            %load the data matrix, convert data matrix structure to cell array and 
            %access first cell. this cell contains the data.

            data_matrix     = load('DATA_MAT.mat');  
            data_matrix = struct2cell(data_matrix);        
            data_matrix         = data_matrix{1,1}; 


            %load the data approximation matrix.  this data matrix has all the
            %approximated data for missing lacunae, metaxylem vessel and
            %protoxylem vessel data.

            approx_data   = load('APPROX_DAT.mat');
            approx_data = struct2cell(approx_data);        
            approx_data         = approx_data{1,1}; 



        else %we are writing data for single image. 


            %define path to INTERVAL_MAT.mat file.

            pathwayINT =               [pathway1 AllImageSpecs.fileSeparator 'INTERVAL_MAT.mat']; 


            %load the current calibration settings.

            load_calibration_settings = load([pathway1 AllImageSpecs.fileSeparator 'CALIB_MAT.mat']);  


            %load the data matrix, convert data matrix structure to cell
            %array and access first cell. this cell contains the data.

            data_matrix = load('TEMP_DATA_MAT.mat'); 
            data_matrix  = struct2cell(data_matrix);      
            data_matrix          = data_matrix{1,1};  


        end;


        %assign original data matrix to new matrix with name : data_matrix2.
        %this matrix will be use for manipulation and augmentation using the 
        %cortex interval settings and derived variable settings defined by the user.



        %adquire the precision settings for the data display and output.

        precisVal = load_calibration_settings.calibprecis(3);



        %load the cortex interval settings. this file contains the intervals and other
        %information for the cortex interval data output and access second cell contained
        %within the first cell.

        cortexintervals = struct2cell(load(pathwayINT));   
        cortexintervals     = cortexintervals{1,1}{2,1};  


        %create empty cell to store data header information.

        cortexLabelHeader = cell(2, size(cortexintervals,2)); 


        %create empty cell to store data precision values.

        cortexPrecisHeader = cell(1, size(cortexintervals,2));  



        %define cortex region headers.  

        for I = 1:size(cortexintervals,2)


            %fill in the first row of the header cell array by column

            cortexLabelHeader{1,I}                = cortexintervals{1,I};


            %assign format string to each field header in the same cell array.

            cortexLabelHeader{2,I}                             = '%s\t ';


            %place all the precision values in the data precision array.

            cortexPrecisHeader{1,I} = ['%1.' int2str(precisVal+2) 'f\t ']; 


        end;






      %-----------------------------------------------------------%  

                %print all column header information now.

      %-----------------------------------------------------------%         

        %we to define the current directory name as a string and place it in the fileid.




        if (DirSpecs.programMode == -2) %we have a directory.


            %find the last file break (i.e. forward slash) in the current directory,
            %define the name of the sub-directory and define the name of the text 
            %file for data output.   

            dirs = find(directory_name == AllImageSpecs.fileSeparator, 1, 'last');  
            file_name                          = (directory_name((dirs + 1):end));  


            fileID                 = ['RootScan_Data.' file_name '.txt'];
            fileID2 = ['RootScan_Approx_Missing_Data.' file_name '.txt'];        

        end;



        %open the file for writing purposes.

        dataOpen = fopen(fileID, 'wt');  



        %declare the column headers now.......................


        %write the data column headers to the first line in the data file.


        %define column header for the image name.

        nameHeader = {'Filename'; '%s\t '};  


        %raw data column label headers.

        dataLabelHeader = {'Calib Value/Threshold Method', ...
            'XSCWA (mm^2)', 'RXSA (mm^2)', 'RXS_DIAMETER (mm)', ...
            'CCWA (mm^2)', 'TCA (mm^2)', 'Cortex Thickness (mm)', ...
            'SCWA (mm^2)', 'TSA (mm^2)', 'Stele Diameter (mm)', ...
            '#Lac', 'Median Lac Area (mm^2)', 'Lac Area Standard Deviation (mm^2)', ...
            'Smallest Lac Area (mm^2)', 'Largest Lac Area (mm^2)', 'AA (mm^2)', ...
            'Cortex Cell Count', 'Cortex Cell Count (User Approximation)', 'Cortical Cell Area', ...
            'Cortex Cell Area (User Approximation)', 'Cell Files', 'Cell Files (User Approximation)', ...
            '# of Metaxylem Vessels', 'Median Metaxylem Area (mm^2)', ...
            'Metaxylem Vessel Area Standard Deviation (mm^2)', 'Metaxylem Vessel Area (low) (mm^2)', ...
            'Metaxylem Vessel Area (high) (mm^2)', 'Median Metaxylem Vessel Diameter (mm)', ...
            'Metaxylem Vessel Diameter Standard Deviation (mm)', 'Metaxylem Vessel Diameter (low) (mm)', ...
            'Metaxylem Vessel Diameter (high) (mm)', 'Meta-XVA (mm^2)'...
            'Water Conductance (Metaxylem vessel radii^4) (m^4)', ...
            '# of Protoxylem Vessels', 'Median Protoxylem Area (mm^2)', ...
            'Protoxylem Vessel Area Standard Deviation (mm^2)', 'Protoxylem Vessel Area (low) (mm^2)', ...
            'Protoxylem Vessel Area (high) (mm^2)', 'Median Protoxylem Vessel Diameter (mm)', ...
            'Protoxylem Vessel Diameter Standard Deviation (mm)', 'Protoxylem Vessel Diameter (low) (mm)', ...
            'Protoxylem Vessel Diameter (high) (mm)', 'Proto-XVA (mm^2)'...
            'Water Conductance (Proto-xylem vessel radii^4) (m^4)', 'LA (mm^2)', ...
            'Median Cortex Cell Wall Thickness (mm)', ...
            'Standard Variation of Cortex Cell Wall Thickness (mm)', ...
            'Cortex Cell Wall Thickness Range (mm)'; ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t '};  



        %define the notes header

        %set up cell array to contain the notes headers.

        notesLabelHeader = {'Comments'; '%s\n'};  


        %concatenate all the header information

        columnHeader = [nameHeader dataLabelHeader cortexLabelHeader notesLabelHeader];  


        %print the header information to the data output file (text format).

        fprintf(dataOpen, cell2mat(columnHeader(2,:)), columnHeader{1,:});  


        %close the data file for now.

        fclose(dataOpen);  




              %--------------------------------------------------%

                              %PRINT DATA TO FILE.

              %--------------------------------------------------%                




    %---------------------SET THE FORMAT FOR DATA OUTPUT----------------------%

        %image name precision / format.

        imageIDPrecis = {'%s\t '};  


        %define the general precision value obtained from the calibration file.

        set_precision =    ['%1.' int2str(precisVal) 'f\t '];  


        rawDataPrecis = {'%s\t ', set_precision, set_precision, set_precision, ...
            set_precision, set_precision, set_precision, set_precision, set_precision, ...
            set_precision, '%1.0f\t ', set_precision, set_precision, set_precision, ...
            set_precision, set_precision, '%1.0f\t ', set_precision, set_precision, ...
            set_precision, set_precision, set_precision, '%1.0f\t ', set_precision, ...
            set_precision, set_precision, set_precision, set_precision, set_precision, ...
            set_precision, set_precision, set_precision, '%1.6e\t ', '%1.0f\t ', ...
            set_precision,  set_precision, set_precision, set_precision, set_precision, ...
            set_precision, set_precision, set_precision, set_precision, '%1.6e\t ', ...
            set_precision, set_precision, set_precision, set_precision}; 



        %notes precision / format.

        commentsPrecis = {'%s\n'};  


        %print the headers to the text file.  total precision vector.

        dataPrecis = [imageIDPrecis rawDataPrecis cortexPrecisHeader commentsPrecis]; 



        %convert to matrix.

        format_string = cell2mat(dataPrecis);  



        %define data array (double precision) containing only integer and
        %double precision variables.  this will be used to consolidate the
        %print function line below.

        numerical_data = cell2mat(data_matrix(:,3:end-1));


        %open the data file in augmentation mode.  we will write the data under the 
        %column headers now.

        dataOpen = fopen(fileID, 'a+');  


        %loop through the data rows and write the data to file.

        for i = 1:matrix_size 


            %define image name, image specifications and user comments.

            imageID             = data_matrix{i,1}; 
            imageSpecifications = data_matrix{i,2};    
            userComments      = data_matrix{i,end};



            %print all data to file now.

            fprintf(dataOpen, format_string, imageID, imageSpecifications, ...
                numerical_data(i,:), userComments);  


        end;



        %close the data file.

        fclose(dataOpen);  


        %move the data file to the sub-directory : data

        movefile(fileID, outputDirectory);  










    %print the approximated data for the missing lacunae, metaxylem vessel and
    %protoxylem vessel data.




    %open the file for writing purposes.

        dataOpen = fopen(fileID2, 'wt');  



        %declare the column headers now.......................


        %write the data column headers to the first line in the data file.


        %define column header for the image name.

        nameHeader = {'Filename'; '%s\t '};  


        %raw data column label headers.

        dataLabelHeader = {'# Missing Lac', 'Adjusted # Lac', 'Adjusted Median Lac Area (mm^2)', ...
            'Adjusted Lac Area Standard Deviation (mm^2)', ' AdjustedSmallest Lac Area (mm^2)', ...
            'Adjusted Largest Lac Area (mm^2)', 'Adjusted AA (mm^2)', ...
            '# Missing Metaxylem Vessels', 'Adjusted # of Metaxylem Vessels', ' Adjusted Median Meta-Xylem Area (mm^2)', ...
            'Adjusted Metaxylem Vessel Area Standard Deviation (mm^2)', 'Adjusted Metaxylem Vessel Area (low) (mm^2)', ...
            'Adjusted Metaxylem Vessel Area (high) (mm^2)', ' Adjusted Median Metaxylem Vessel Diameter (mm)', ...
            'Adjusted Metaxylem Vessel Diameter Standard Deviation (mm)', 'Adjusted Metaxylem Vessel Diameter (low) (mm)', ...
            'Adjusted Metaxylem Vessel Diameter (high) (mm)', 'Adjusted Meta-XVA (mm^2)'...
            'Adjusted Water Conductance (Metaxylem vessel radii^4) (m^4)', ...
            '# Missing Protoxylem Vessels', 'Adjusted # of Protoxylem Vessels', 'Adjusted Median Protoxylem Area (mm^2)', ...
            'Adjusted Protoxylem Vessel Area Standard Deviation (mm^2)', 'Protoxylem Vessel Area (low) (mm^2)', ...
            'Adjusted Protoxylem Vessel Area (high) (mm^2)', 'Adjusted Median Protoxylem Vessel Diameter (mm)', ...
            'Adjusted Protoxylem Vessel Diameter Standard Deviation (mm)', 'Protoxylem Vessel Diameter (low) (mm)', ...
            'Adjusted Protoxylem Vessel Diameter (high) (mm)', 'Proto-XVA (mm^2)'...
            'Adjusted water conductance (Protoxylem vessel radii^4) (m^4)'; ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', ...
                '%s\n'};  




        %concatenate all the header information

        columnHeader = [nameHeader dataLabelHeader];  


        %print the header information to the data output file (text format).

        fprintf(dataOpen, cell2mat(columnHeader(2,:)), columnHeader{1,:});  


        %close the data file for now.

        fclose(dataOpen);  




              %--------------------------------------------------%

                              %PRINT DATA TO FILE.

              %--------------------------------------------------%                




    %---------------------SET THE FORMAT FOR DATA OUTPUT----------------------%

        %image name precision / format.

        imageIDPrecis = {'%s\t '};  


        %define the general precision value obtained from the calibration file.

        set_precision =    ['%1.' int2str(precisVal) 'f\t '];  


        rawDataPrecis = {'%1.0f\t', '%1.0f\t', set_precision, set_precision, ...
            set_precision, set_precision, set_precision, '%1.0f\t ', '%1.0f\t ', ...
            set_precision, set_precision, set_precision, set_precision, set_precision, ...
            set_precision, set_precision, set_precision, set_precision, set_precision, ...
            '%1.0f\t ', '%1.0f\t ', set_precision, set_precision, set_precision, ...
            set_precision, set_precision, set_precision, set_precision, set_precision, ...
            set_precision, '%1.0f\n'}; 




        %print the headers to the text file.  total precision vector.

        dataPrecis = [imageIDPrecis rawDataPrecis]; 



        %convert to matrix.

        format_string = cell2mat(dataPrecis);  



        %define data array (double precision) containing only integer and
        %double precision variables.  this will be used to consolidate the
        %print function line below.

        numerical_data = cell2mat(approx_data(:,2:end));


        %open the data file in augmentation mode.  we will write the data under the 
        %column headers now.

        dataOpen = fopen(fileID2, 'a+');  


        %loop through the data rows and write the data to file.

        for i = 1:matrix_size 


            %define image name, image specifications and user comments.

            imageID             = data_matrix{i,1}; 


            %print all data to file now.

            fprintf(dataOpen, format_string, imageID, ...
                numerical_data(i,:));  


        end;



        %close the data file.

        fclose(dataOpen);  


        %move the data file to the sub-directory : data

        movefile(fileID2, outputDirectory);  




    %do not print data file. directory incomplete.

    else 


    %START OR RESUME A BATCH ANALYSIS FOR CURRENT DIRECTORY IF THE USER CHOSES
    %TO DO SO.

        switch complete_batch_condition 

            case 1

                Rootscan_session(-2);


        end;


    end;


end