function [data_matrix, ccw_thickness, num_of_images, time_efficiency, approx_data] = declare_arrays

%this function will declare the data arrays and directory specific settings
%prior to the user starting or resuming their analysis.  this function can
%handle both batch and individual image file modes.  


global AllImageSpecs; %structure containing all image specifications.
global      DirSpecs; %structure containing all directory specifications.
     
%define path for Rootscan main programs directory.
        
pathway_main                                     = which('select_directory.m'); 
find_last_break = find(pathway_main == AllImageSpecs.fileSeparator, 1, 'last'); 
pathway_main                                 = pathway_main(1:find_last_break);               
    


switch DirSpecs.programMode
    
    
    case -1 %select single file

        
        %function that allows the user to select a single file for quick analysis.
        
        [image_name, directory_name]        = select_image;    
        
        
        %place directory name in structure.
        
        DirSpecs.directory_name           = directory_name;
        
        
        %place image name in structure.
        
        AllImageSpecs.image_name              = image_name;
        
        
        
        %define directory of the current image selected.
        
        DirSpecs.directory = dir(AllImageSpecs.image_name); 
           
        
        %we only have one image to analyze.
        
        num_of_images                                 = 1;
        
        
        %how many data fields (i.e. variables) do we have?
        
        
        %define the length of the cortex band intervals array. this value
        %will be used to determine the overall length of the data matrix. 

        DirSpecs.cortBins = length(AllImageSpecs.bands_intervals) - 1;


        %define the cortex cell wall thickness cell matrix.
        
        ccw_thickness = cell(1, (length(AllImageSpecs.bands_intervals)- 1));
        
        
        %define the main rootscan data matrix.
        
        data_matrix = zeros(1, (50+DirSpecs.cortBins));
        data_matrix            = num2cell(data_matrix);
        
        
        %define the cell array for our data approximations.
        
        approx_data = cell(1,32);

        
             
        
        %define the current threshold method.
        
        thresh_m       = load([pathway_main 'threshMethod.mat']);
        thresh_method                   = thresh_m.thresh_method;
        AllImageSpecs.thresh_method  = thresh_method.window_size; 
        
        
        %define the time efficiency matrix. this matrix will hold all the 
        %time values required for each major step.
        
        time_efficiency = cell(1,9);
        
        
    case -2 %select directory for batch analysis.
        
        %function that allows the user to select a directory for batch analysis.
        
        [directory_name, mode2] = select_directory;  
        
        DirSpecs.directory_name   = directory_name;
        
        
        %we need to scan the directory to see what type of files we have.

        DIRS_jpg   = dir ('*.jpg');  %find all images with format : .jpg.
        DIRS_jpeg = dir ('*.jpeg');  %find all images with format : .jpeg.
        DIRS_JPG   = dir ('*.JPG');  %find all images with format : .JPG.
        DIRS_JPEG = dir ('*.JPEG');  %find all images with format : .JPEG.
        DIRS_tif   = dir ('*.tif');  %find all images with format : .tif.
        DIRS_tiff = dir ('*.tiff');  %find all images with format : .tiff.
        DIRS_TIF   = dir ('*.TIF');  %find all images with format : .TIF.
        DIRS_TIFF = dir ('*.TIFF');  %find all images with format : .TIFF.
        DIRS_gif   = dir ('*.gif');  %find all images with format : .gif.
        DIRS_GIF   = dir ('*.GIF');  %find all images with format : .GIF.
        DIRS_png   = dir ('*.png'); %find all images with format : .png.
        DIRS_PNG   = dir ('*.PNG'); %find all images with format : .PNG.
        
        
        %construct a matrix containing the number of images in each format 
        %directory defined above.
        
        which_directory = [numel(DIRS_jpg) numel(DIRS_jpeg) numel(DIRS_JPG) numel(DIRS_JPEG) ...
            numel(DIRS_tif) numel(DIRS_tiff) numel(DIRS_TIF) numel(DIRS_TIFF) ...
            numel(DIRS_gif) numel(DIRS_GIF) numel(DIRS_png) numel(DIRS_PNG)];   

        
        %find the predominant image format in the current directory.
        
        which_directory = find((which_directory ~= 0) & (which_directory == max(which_directory)));  

        
        
        %only execute the gui if images exist in the directory selected by the
        %user.


        switch which_directory  %use switch statement to pick the directory
                                  %containing the predominant image format.

            case 1
                directory  = DIRS_jpg; %choose format : .jpg.
            case 2
                directory = DIRS_jpeg; %choose format : .jpeg.
            case 3
                directory  = DIRS_JPG; %choose format : .JPG.
            case 4
                directory = DIRS_JPEG; %choose format : JPEG.
            case 5
                directory  = DIRS_tif; %choose format : .tif.
            case 6
                directory = DIRS_tiff; %choose format : .tiff.
            case 7
                directory  = DIRS_TIF; %choose format : .TIF.
            case 8
                directory = DIRS_TIFF; %choose format : .TIFF.
            case 9
                directory = DIRS_gif; %choose format : .gif.
            case 10
                directory = DIRS_GIF; %choose format : .GIF.
            case 11 
                directory = DIRS_png; %choose format : .png.
            case 12
                directory = DIRS_PNG; %choose format : .PNG.

        end;


        %check all images in current directory to determine if any
        %image files from any sub-directory was accidentally copied to
        %the parent directory.

        directory = checkfiles(directory);


        %determine the number of images in the current directory.

        num_of_images  = numel(directory);  


        %place current image directory handle in structure.

        DirSpecs.directory    = directory; 
            
            
        %we need to verify main data files exists in the current image directory.  
        %if the file doesn not exist then two things must done: 1) the user must be 
        %notified and 2) erase all .mat files in directory and start over.

        %missing global data file: action --> user must start over.
        %missing cortical thickness data file: action --> user must start over.
        %missing time efficiency stats data file: action --> resume where stopped last time.
        %missing threshold specifications file: action --> pick option #2. (2X2 method on main menu)               



        fs = AllImageSpecs.fileSeparator;
                
        GlobalDataExist       = exist([cd fs 'DATA_MAT.mat'], 'file');
        CortexThickExist = exist([cd fs 'ccw_thickness.mat'], 'file');
        TimeStatsExist = exist([cd fs 'time_efficiency.mat'], 'file');
        threshExist       = exist([cd fs 'threshMethod.mat'], 'file');
       
        DataExistTest = (GlobalDataExist + CortexThickExist +  TimeStatsExist)/2;
        
       
        
        if (DataExistTest ~= 3)  && (DataExistTest > 0)
            
            %display message of dismay to the user telling them that their
            %data file(s) are missing and they must start over.  This case
            %should not happen but we are going to account for the
            %possibility.
            
            dismayMess = ['Unfortunately, your files are missing.' ...
                '  You must start over at image #1.  You will proceed to ' ...
                'image #1 shortly.'];
            
            dismaytitle = 'Image Data files missing';
            
            %display message box.
            
            mess_h = msgbox(dismayMess, dismaytitle);
            
            
            %wait for user to click the OK button on the message box.
            
            uiwait(mess_h); 
            
            mode2 = 4;
            
            
            
            
            %define list of directories for deletion.
            
            dirList = [{'Image_Output'}; {'X_section_binary'}; {'temp'}; ...
                {'X_section_segments'}];
            
            for I = 1:size(dirList,1)
            
                switch exist([cd fs dirList{I}], 'dir')
                
                    case 7 
                    
                        %it exists. delete it.
                    
                        rmdir([cd fs dirList{I}], 's');
                    
                end;
            
            end;
            
            
            
            
            
        end;
        
        
        
        
       %define the number of radial bins for median cortical cell size calculations.
                
       DirSpecs.cortBins = length(AllImageSpecs.bands_intervals)- 1;
        
        
        
        
        %determine if the directory is new or old.
        
        switch mode2  
                    
            
            case 5 %this directory is partially analyzed.
        

                %load the data matrix for the current directory.  this data
                %matrix contains all the variables (except the derived) for
                %each processed image in the current directory. convert to
                %cell format and access cell.
                
                data_matrix =     load('DATA_MAT.mat');   
                data_matrix = struct2cell(data_matrix);  
                data_matrix =         data_matrix{1,1};  
                
                
                %load the approximation data for the current directory.
                %this data matrix stores all lacunae, metaxylem vessel and
                %proto xylem vessel data for those with missing objects.
                
                approx_data   = load('APPROX_DAT.mat');
                approx_data = struct2cell(approx_data);
                approx_data         = approx_data{1,1};
                        
                

                %load the cortex cell wall thickness matrix for the current directory.  
                %this matrix contains all the cortex interval data for each
                %processed image in the current directory. convert to cell
                %format and access cell.                
                
                ccw_thickness  = load('ccw_thickness.mat');   
                ccw_thickness = struct2cell(ccw_thickness);  
                ccw_thickness         = ccw_thickness{1,1};  
                
                
                %load time efficiency matrix.
                
                if TimeStatsExist == 2
                
                    time_efficiency  = load('time_efficiency.mat');
                    time_efficiency = struct2cell(time_efficiency);  
                    time_efficiency         = time_efficiency{1,1}; 
                
                else
                    
                    time_efficiency  = zeros(num_of_images, 9);
                    time_efficiency = num2cell(time_efficiency);
                
                    save('time_efficiency', 'time_efficiency');   
                    
                    
                end;
                
                
                %if the threshold exists (i.e. threshExist == 2). then load
                %the settings.  if it does not exist then open the
                %threshold options.
                
                if threshExist == 2

                    thresh_m                     = load('threshMethod.mat');
                    thresh_method                  = thresh_m.thresh_method;
                    AllImageSpecs.thresh_method = thresh_method.window_size;          
                
                else
                    
                    %open the threshold options GUI window to allow users
                    %to select which sample windows and methods they want
                    %to use.
                    
                    threshold_options;
                    
                    
                    thresh_m      = load([pathway_main 'threshMethod.mat']);
                    thresh_method                  = thresh_m.thresh_method;
                    AllImageSpecs.thresh_method = thresh_method.window_size; 
                    
                    copyfile([pathway_main 'threshMethod.mat'], directory_name);

                end;
                

                
                
            case 4 %We have a new directory.  construct data matrices now.
                
                
                %define the data matrix. construct a cell array with the total
                %number of fields (i.e. data columns) equal to total_fields.
                
                sampleCell  = cell(num_of_images, 1); %cell array contain ID field
                
                commentCell = cell(num_of_images, 1); %cell array containing comment fields.
                
                
                dataCell  = zeros(num_of_images, 48); %double array containing data fields.
                
                dataCell        = num2cell(dataCell); %convert double array to cell.
                                
               
                
                %double array containing ortical cell area data.
                
                cortRegMatrix = zeros(num_of_images, DirSpecs.cortBins); 
                
                cortRegMatrix = num2cell(cortRegMatrix); %convert double to cell array.

                
                %construct the data matrix.  this data matrix stores all
                %Rootscan data.
                
                data_matrix = [sampleCell dataCell cortRegMatrix commentCell]; 
                
                
                %construct the approximation data matrix for the current directory.
                %this data matrix stores all lacunae, metaxylem vessel and
                %proto xylem vessel data for those with missing objects.
                
                dataCell = zeros(num_of_images, 31);
                dataCell = num2cell(dataCell);
                
                
                approx_data = [sampleCell dataCell];
                
                
                %save the current empty matrix.
                
                save('DATA_MAT', 'data_matrix');  
                save('APPROX_DAT', 'approx_data');
                
 
                %define the cortex cell wall thickness matrix.  construct 
                %a cell array for cortex interval data (the number of data 
                %columns is equal to the number of cortex intervals set by the user).
                %save the empty matrix.
                
                ccw_thickness = zeros(num_of_images, DirSpecs.cortBins);
                
                ccw_thickness                 = num2cell(ccw_thickness);
                
                save('ccw_thickness', 'ccw_thickness');
                

                %define time efficiency matrix.
                
                time_efficiency   = zeros(num_of_images, 9);
                time_efficiency = num2cell(time_efficiency);
                
                save('time_efficiency', 'time_efficiency');
                
                
                %define threshold method.
                
                thresh_m      = load([pathway_main 'threshMethod.mat']);
                thresh_method                  = thresh_m.thresh_method;
                AllImageSpecs.thresh_method = thresh_method.window_size;                 
                                
                copyfile([pathway_main 'threshMethod.mat'], directory_name);
                
                
                
        end;
        
        
          
        
        
end;       





end