function defAerenXVColors

%this function will define the highlight colors for interactive steps and
%and results from the interactive steps that are displayed in the reference image.
%NOTE: these numbers are only used for display purposes only.  they will not affect the
%data results.



    global AllImageSpecs; %structure containing image specifications.


    %define curent image directory.

    currentDir = cd;

    %retrieve the GUI display color set by user or set the default color.
    %our default color will be light blue.

    directory = which('Rootscan_session');
    directory(end-17:end)            = [];

    cd(directory);


    %define all the pixel values for highlighting x-section regions.  these
    %will remain constant throughout program. user does not need to changes
    %these values since they are only used to code certain regions.



    switch exist('REFhighColors.mat', 'file')

        case 2 %the file exists. 

            load('REFhighColors.mat');


        case 0 %the file does not exist.

        %ask the user if they would like to define them at this time.

        response = questdlg('Define Color Settings', ...
            'Would you like to define the Color setings now?', ...
            'Yes', 'No');


        switch strcmp(response, 'Yes')

            case 1 %they would like to define the colors now in a separeate GUI.

                ImageColors;


            case 0 %these are the default values set by RootScan.





    %place the colors for the reference image.

    AllImageSpecs.refColors = zeros(3, 4, 'uint8');

    AllImageSpecs.refColors(1:3,1)    = [240 40 0]; %lacunae color.

    AllImageSpecs.refColors(1:3,2)  = [255 230 38]; %meta xv color.

    AllImageSpecs.refColors(1:3,3)   = [0 181 255]; %proto xv color.

    AllImageSpecs.refColors(1:3,4)     = [0 240 0]; %perimeter color for X-section.

    AllImageSpecs.refColors(1:3,5)     = [0 0 240]; %perimeter color for lateral.

    AllImageSpecs.refColors(1:3,6)   = [0 240 230]; %perimeter color for stele.





    %define the disk radius for the highlighted perimeters. %pset all perimeter
    %dilation values to 1 now


    AllImageSpecs.PerimThick = ones(3,1);




        end;



    end;



    %set the highlight colors for main image axes.          

    %aerenchyma color = variable.
    %meta xv color = variable.
    %proto xv color = variable.
    %stele cell wall = 125;
    %cortex cell wall = 5.
    %lateral = 25.
    %stele cell areas  = 40.


    %define color weighting scale.

    colorproportions = zeros(3);
    colorproportions(:,1)   = 1;
    colorproportions(:,2)   = 2;


    %apply weight to color code for aerenchyma, meta xv and proto xv.

    interactiveColors = floor(sum(AllImageSpecs.high(1:3,:).*colorproportions,2)/3)';


    %apply these colors to the image specs structure field > highlightCode.

    AllImageSpecs.highlightCode = [interactiveColors 170 5 25 255];  


    %return to current image directory.

    cd(currentDir);





end