function define_gui_components

%this function defines all panels, user interactive controls (i.e.
%pushbuttons, radiobuttions, dropdown menus, etc....) for the main Rootscan
%analysis window.


global  f_fig_handle;
global AllImageSpecs;
global      DirSpecs;

%set up gui axes, buttons and etc...
 
%define the screensize in terms of pixel elements. this guide us in defining
%the dimensions of our gui components.
    
screen_size = get(0, 'ScreenSize');     
 


%read in the step label cdata for x-section crop.

xs_crop_cdata = imread([DirSpecs.pathway AllImageSpecs.fileSeparator 'X_section_crop_cdata.jpg']);
xs_crop_cdata                                                         = double(xs_crop_cdata)/255;



%read in the step label cdata images for lateral isolation.

lat_iso_cdata = imread([DirSpecs.pathway AllImageSpecs.fileSeparator 'Lateral_Iso_cdata.jpg']);
lat_iso_cdata                                                      = double(lat_iso_cdata)/255;



%read in the step label cdata images stele isolation.

stele_iso_cdata = imread([DirSpecs.pathway AllImageSpecs.fileSeparator 'Stele_Iso_cdata.jpg']);
stele_iso_cdata                                                  = double(stele_iso_cdata)/255;



%read in the step label cdata images stele isolation.

lac_cdata = imread([DirSpecs.pathway AllImageSpecs.fileSeparator 'lac_cdata.jpg']);
lac_cdata                                                  = double(lac_cdata)/255;



%read in the step label cdata images stele isolation.

meta_XV_cdata = imread([DirSpecs.pathway AllImageSpecs.fileSeparator 'meta_XV_cdata.jpg']);
meta_XV_cdata                                                  = double(meta_XV_cdata)/255;



%read in the step label cdata images stele isolation.

proto_XV_cdata  = imread([DirSpecs.pathway AllImageSpecs.fileSeparator 'proto_XV_cdata.jpg']);
proto_XV_cdata                                                  = double(proto_XV_cdata)/255;


%-------------------define all interactive buttons------------------------%
%-------------------define all interactive buttons------------------------%
%-------------------define all interactive buttons------------------------%




    
%define master panel for all sub-panels.
    
master_panel = uipanel('Units', 'normalized', 'Position', [.7 0, .3, 1], ...
	'BackgroundColor', [.7 .7 .7]);                                                          
    


    
%---------SubPanel #1 (top left corner of main Panel): finished radio buttons---------%    
    



%----------------begin-begin-begin-begin-begin-begin-begin----------------%

%---------------------------runtime status panel--------------------------%

%location: right panel at the top.

%this status panel highlights the current phase displays the number of
%images remaining in the analysis.


%define status panel to store these objects.
        
status_panel = uipanel('Parent', master_panel, 'units', 'normalized', 'Position', ...
	[0, .95, 1, .05]);    
                                       

                                        
%define the children of the status panel.  this panel will contain two text
%strings.  the first text string will be use to display the current
%analysis phase and the second string will be used to display the number of
%imaging remaining in the analysis.

%allocate memory for uicontrols.  place them in the structure entitled:
%f_fig_handle using in the field array : status.

f_fig_handle.status = zeros(1,5);


%define the text string displaying phase I.

f_fig_handle.status(1) = uicontrol('Parent', status_panel, ...
    'Style', 'Pushbutton', 'Units', 'normalized', 'Position', [0, .5, .333, .5],  ...
    'FontUnits', 'normalized', 'String', 'Phase I');


%define the text string displaying phase II.

f_fig_handle.status(2) = uicontrol('Parent', status_panel, ...
    'Style', 'Pushbutton', 'Units', 'normalized', 'Position', [.333, .5, .333, .5],  ...
    'FontUnits', 'normalized', 'String', 'Phase II');



%define the text string displaying phase III.

f_fig_handle.status(3) = uicontrol('Parent', status_panel, ...
    'Style', 'Pushbutton', 'Units', 'normalized', 'Position', [.666, .5, .333, .5],  ...
    'FontUnits', 'normalized', 'String', 'Phase III');



%define the text string displaying the percent complete.

f_fig_handle.status(5) = uicontrol('Parent', status_panel, ...
    'Style', 'text', 'Units', 'normalized', 'Position', [.02, 0, .29, .5],  ...
    'FontUnits', 'normalized', 'String', '');



%define the text string displaying the number of image remaining.

f_fig_handle.status(4) = uicontrol('Parent', status_panel, ...
    'Style', 'text', 'Units', 'normalized', 'Position', [.32, 0, .4, .5],  ...
    'FontUnits', 'normalized', 'String', '');



                set(f_fig_handle.status, 'FontWeight', 'bold'); %set font weight
set(f_fig_handle.status(1:3), 'HorizontalAlignment', 'center'); %HorizontalAlignment top strings.
set(f_fig_handle.status(4:5), 'HorizontalAlignment', 'center'); %HorizontalAlignment bottom strings.
                  set(f_fig_handle.status(1:3), 'FontSize', .8); %set fontSize for 3 phase labels.
                 set(f_fig_handle.status(4:5), 'FontSize', .6); %set fontSize for 3 phase labels.

                       
                       
%---------------------------runtime status panel--------------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%












%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%---------------------------reference image panel-------------------------%

%location: right beneath the status panel defined above.

%this panel will hold the reference image and its different options.


%set up cortex interval panel for displaying the image of the cortex intervals.
    
reference_image_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [0, .50  1 .45], 'BackgroundColor', [1 1 1]);


%set up the axes for the reference image.
    
f_fig_handle.im_axes(2) = axes('Parent', reference_image_panel, 'Units', 'normalized', ...
	'Position', [.025 .05 .95 .95], 'Visible', 'off');  


%define a dropdown menu for the different image results options.

f_fig_handle.reference_axes = uicontrol('Parent', reference_image_panel, ...
    'Units', 'normalized', 'Position', [0 0 1 .05], 'Style', 'popupmenu', ...
    'FontUnits', 'normalized', 'String', {'Cumulative Analysis Results'; ...
    'Cell File Image'; 'Cort Cell Size'}, 'FontSize', .54, 'FontWeight', 'bold', ...
    'TooltipString', 'Select This Popup Menu to View Additional Image Results');



%disable dropdown menu for the different image results options.

         set(f_fig_handle.reference_axes, 'enable', 'off');


%set the callback function for this dropdown menu tab.

set(f_fig_handle.reference_axes, 'Callback', @changeimage);



%---------------------------reference image panel-------------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%








%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%---------------------------xylem vessel subpanel-------------------------%

%panel location coordinates and dimensions.

ht = 2/24;
yo  = .25;
wd   = .5*(2/3);


%label location coordinates and dimensions.

l_wd = .5;


%radio button location coordinates and dimensions.

rad_wd = .5;


f_fig_handle.done_buttons = zeros(6,1);
f_fig_handle.step_label   = zeros(6,1);


xv_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
'Position', [0, yo  wd ht]);

%meta xylem label.

f_fig_handle.step_label(1) = uicontrol('Parent', xv_panel, ...
    'units', 'normalized', 'Style', 'pushbutton', 'Position', [0 .5 l_wd .5], ...
    'cdata', meta_XV_cdata);


%proto xylem label.

f_fig_handle.step_label(2) = uicontrol('Parent', xv_panel, ...
    'units', 'normalized', 'Style', 'pushbutton', 'Position', [0 0 l_wd .5], ...
    'cdata', proto_XV_cdata);


%meta xylem finished radiobutton.

f_fig_handle.done_buttons(2) =     uicontrol('Parent', xv_panel, ...
    'units', 'normalized', 'Style', 'radiobutton', 'Position', [l_wd .5 rad_wd .5], ...
    'FontUnits', 'normalized', 'TooltipString', 'Select This Button When Completed with Metaxylem Vessel Selection');


%proto xylem finished radiobutton. 

f_fig_handle.done_buttons(3) =     uicontrol('Parent', xv_panel, ...
    'units', 'normalized', 'Style', 'radiobutton', 'Position', [l_wd 0 rad_wd .5], ...
    'FontUnits', 'normalized', 'TooltipString', 'Select This Button When Completed with Protoxylem Vessel Selection');



%---------------------------xylem vessel subpanel-------------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%









%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%----------------------aerenchyma selection subpanel----------------------%

yo = yo + ht;
ht    = 1/24;


aeren_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [0, yo  wd ht]);


f_fig_handle.step_label(3) = uicontrol('Parent', aeren_panel, ...
    'units', 'normalized', 'Style', 'pushbutton', 'Position', [0 0 l_wd 1], ...
    'cdata', lac_cdata);


%lacunae selection finished radiobutton.

    
f_fig_handle.done_buttons(1) =     uicontrol('Parent', aeren_panel, ...
    'units', 'normalized', 'Style', 'radiobutton', 'Position', [l_wd 0 rad_wd 1], ...
    'FontUnits', 'normalized', 'TooltipString', 'Select This Button When Completed with Lacunae Selections');



%----------------------aerenchyma selection subpanel----------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%








%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%------------------------stele segmentation subpanel----------------------%

yo = yo + ht;

stele_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [0, yo  wd ht]);


f_fig_handle.step_label(4) = uicontrol('Parent', stele_panel, ...
    'units', 'normalized', 'Style', 'pushbutton', 'Position', [0 0 l_wd 1], ...
    'cdata', stele_iso_cdata);


%stele isolation finished radiobutton.

f_fig_handle.done_buttons(6) = uicontrol('Parent', stele_panel, ...
    'units', 'normalized', 'Style', 'radiobutton', 'Position', [l_wd 0 rad_wd 1], ...
    'FontUnits', 'normalized', 'TooltipString', 'Select This Button When Completed with Stele Isolation');



%------------------------stele segmentation subpanel----------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%








%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%-------------------------lateral isolation subpanel----------------------%

yo = yo + ht;
x1 = 0;

lat_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [0, yo  wd ht]);


f_fig_handle.step_label(5) = uicontrol('Parent', lat_panel, ...
    'units', 'normalized', 'Style', 'pushbutton', 'Position', [0 0 (l_wd+x1) 1], ...
    'Cdata', lat_iso_cdata);


%lateral isolation finished radiobutton.

f_fig_handle.done_buttons(5) = uicontrol('Parent', lat_panel, ...
    'units', 'normalized', 'Style', 'radiobutton', 'Position', [l_wd+x1 0 rad_wd-x1 1], ...
    'FontUnits', 'normalized', 'FontSize', .7, ...
    'TooltipString', 'Select This Button When Completed with Lateral Isolation');


%-------------------------lateral isolation subpanel----------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%






%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%-------------------------x-section crop subpanel-------------------------%

yo = yo + ht;

xs_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [0, yo  wd ht]);

f_fig_handle.step_label(6) = uicontrol('Parent', xs_panel, ...
    'units', 'normalized', 'Style', 'pushbutton', 'Position', [0 0 l_wd 1], ...
    'cdata', xs_crop_cdata);



%x-section segmentation step finished radiobutton.

f_fig_handle.done_buttons(4) = uicontrol('Parent', xs_panel, ...
    'units', 'normalized', 'Style', 'radiobutton', 'Position', [l_wd 0 rad_wd 1], ...
    'FontUnits', 'normalized', 'BackgroundColor', [.8 .8 .8], ...
    'TooltipString', 'Select This Button When Completed with Cross-Section Segmentation');



%set the font size and horizontal alignment and background color 
%for the radio buttons.

              set(f_fig_handle.done_buttons, 'FontSize', .3); %set font size
       set(f_fig_handle.done_buttons, 'String', ' Finished'); %set string for button
%set(f_fig_handle.done_buttons, 'BackgroundColor', [0 .8 .3]); %set background color.


%set the font size, font weight, horizontal alignment and background color
%for the step labels.


         set(f_fig_handle.step_label, 'FontWeight', 'bold'); %set font weight
               set(f_fig_handle.step_label, 'FontSize', .3); %set font size
%set(f_fig_handle.step_label, 'BackgroundColor', [.9 .9 .9]); %set background color.
set(f_fig_handle.step_label, 'Enable', 'inactive');



%set the background color for the done buttons.

set(f_fig_handle.done_buttons, 'BackgroundColor', [.8 .8 .8]); %set background color.



%-------------------------x-section crop subpanel-------------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%






%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%---------------------cell file calculation panel-------------------------%

% position_ref = get(reference_image_panel, 'Position');
% 
% position_xv_panel = get(xv_panel, 'Position');
% 
% xo = (position_xv_panel(1) + position_xv_panel(3));
% 
% yo = (position_ref(2) - (.07*(1-position_ref(2))));
% 
% wd = (1 - (position_xv_panel(1) + position_xv_panel(3)));
% 
% ht = .07*(1-position_ref(2));



skip_IM_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [0 0  1 .04]);

%place skip image image button in this subpanel.


%create push button for skip image options.  when the user pushes this
%button they will skip the current image.  there will an option at the
%end to allow users to come back and visit the image at the end of the
%directory's analysis.
    
f_fig_handle.skipImageButton = uicontrol('Parent', skip_IM_panel, 'Units', ...
    'normalized', 'Style', 'pushbutton', 'Position', [0 0 .3333 1], 'String', ...
    'Skip Image', 'FontUnits', 'normalized', 'FontSize', .6, 'BackgroundColor', ...
    [.7 .7 .7], 'FontWeight', 'bold', 'TooltipString', 'Select This Button to Skip Image');
    


%define dropdown menu for the redo options.

f_fig_handle.redobuttondropdown = uicontrol('Parent', skip_IM_panel, ...
    'units', 'normalized', 'Position', [.3334 0 .3333 1], 'Style', 'popupmenu', ...
    'FontUnits', 'normalized', 'FontWeight', 'bold', 'FontSize', .6, ...
    'BackgroundColor', [.7 .7 .7], 'TooltipString', 'Select This Popup Menu to Redo Any Step');   
    

%set the string components for the dropdown menu tab.

set(f_fig_handle.redobuttondropdown, 'String', {'Redo Step'; ...
	'Remove Lateral'; 'Crop Stele'; 'Aerenchyma'; 'Xylem Vessels'});
        


          
%initialize finished button (radio button)

f_fig_handle.image_done_button = uicontrol('Parent', skip_IM_panel, 'Style', ...
    'radiobutton', 'units', 'normalized', 'Position',  [.6667, 0, .3333, 1], ...
    'String', 'Finished', 'FontUnits', 'normalized', 'FontSize', .7, ...
    'BackgroundColor', [.7 .7 .7], 'HorizontalAlignment', 'right', ...
    'TooltipString', 'Select This Button When Completed With Image');           
          
          

%---------------------cell file calculation panel-------------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%






%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%---------------------cell file calculation panel-------------------------%

position_ref = get(reference_image_panel, 'Position');

position_xv               = get(xv_panel, 'Position');

yo                                   = position_xv(2); 

xo                  = position_xv(1) + position_xv(3);


%define the panel that will hold all the buttons and text associated with
%the cell file calculations and interactions.

cf_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [xo, yo (1-xo) (position_ref(2) - yo)]);


%display title of the cell file GUI panel.

uicontrol('Parent', cf_panel, 'Style', 'text', 'Units', 'normalized', ...
    'Position', [.025 .9 .5 .08], 'String', 'Measure Cell File Count', ...
    'FontWeight', 'bold', 'HorizontalAlignment', 'left');



%define input box (and label) for the number of samples to be taken.


%display label.

uicontrol('Parent', cf_panel, 'Style', 'text', 'Units', 'normalized', ...
    'Position', [.025 .77 .6 .08], 'String', 'Number of Sample Regions', ...
    'HorizontalAlignment', 'left', 'TooltipString', 'Select the Total Number of Sampling Regions');


%define editable box for cortex sampling input.

num_sample = uicontrol('Parent', cf_panel, 'Style', 'edit', 'Units', ...
    'normalized', 'Position', [.58 .77 .08 .08], 'String', '1', ...
    'HorizontalAlignment', 'center');





%display index label.

uicontrol('Parent', cf_panel, 'Style', 'text', 'Units', 'normalized', ...
    'Position', [.025 .6 .5 .08], 'String', 'Sample Region', ...
    'HorizontalAlignment', 'left', 'TooltipString', 'Current Sample Region to be Selected');


%display index of current cortex sample.

current_sample = uicontrol('Parent', cf_panel, 'Style', 'text', 'Units', ...
    'normalized', 'Position', [.58 .6 .08 .08], 'String', '1', ...
    'HorizontalAlignment', 'center');





%display slider for expanding or contracting the cell file sample window

%display slider title.

uicontrol('Parent', cf_panel, 'Style', 'text', 'Units', 'normalized', ...
    'Position', [.025 .47 .63 .08], 'String', 'Sample Window Width', ...
    'HorizontalAlignment', 'center');


CF_slider = uicontrol('Parent', cf_panel, 'Style', 'Slider', ...
    'Units', 'normalized', 'Position', [.05 .35 .58 .1], ...
    'TooltipString', 'Use Slider to Increase/Decrease Sampling Window Range');


%set the slider step size and current position.

set(CF_slider, 'SliderStep', [(5/360) (10/360)]);
set(CF_slider, 'Value', (1/12));



%place radio button for cf calculations.

cf_done = uicontrol('Parent', cf_panel, 'Style', 'Radiobutton', ...
    'Units', 'normalized', 'Position', [.025 .16 .6 .15], 'String', ...
    'Measure Cell Files', 'HorizontalAlignment', 'left', ...
    'TooltipString', 'Press Button When Done With Selection');


%define the initial x coordinate and offset for check box group 1.

xo         = .7;
x_off_set = .03;

yo = [.75 .63 .51 .39];


%display the current cell file count on the screen.

%display results title.

uicontrol('Parent', cf_panel, 'Style', 'text', ...
    'Units', 'normalized', 'Position', [xo .87 .3 .1], 'String', ...
    'Results', 'FontWeight', 'bold', 'HorizontalAlignment', 'left');


%display rootscan results.

uicontrol('Parent', cf_panel, 'Style', 'text', ...
    'Units', 'normalized', 'Position', [xo yo(1) .25 .1], 'String', ...
    'CF-U', 'HorizontalAlignment', 'left', 'TooltipString', ...
    'Radial Cell File Count Observed By User');


cf_count_edit = uicontrol('Parent', cf_panel, 'Style', 'edit', ...
    'String', '', 'Units', 'normalized', 'Position', [xo+.2 yo(1)+.03 .07 .08], ...
    'HorizontalAlignment', 'right');



%display edit boxes for cell file observations.

uicontrol('Parent', cf_panel, 'Style', 'text', ...
    'Units', 'normalized', 'Position', [xo yo(2) .25 .1], 'String', ...
    'CF-R ', 'HorizontalAlignment', 'left', 'TooltipString', ...
    'Radial Cell File Count Calculated in RootScan');


cf_count_static = uicontrol('Parent', cf_panel, 'Style', 'text', ...
    'String', '', 'Units', 'normalized', 'Position', [xo+.16 yo(2) .1 .08], ...
    'HorizontalAlignment', 'right');





%display the current cortical cell count on the screen.


uicontrol('Parent', cf_panel, 'Style', 'text', ...
    'Units', 'normalized', 'Position', [xo yo(3) .3 .1], 'String',...
    'CCC-R ', 'HorizontalAlignment', 'left', 'TooltipString', ...
    'Cortex Cell Count Calculated in RootScan');

ccc = uicontrol('Parent', cf_panel, 'Style', 'text', ...
    'Units', 'normalized', 'Position', [xo+.16 yo(3)+.02 .1 .08], 'String',...
    '', 'HorizontalAlignment', 'right');


% uicontrol('Parent', cf_panel, 'Style', 'text', ...
%     'Units', 'normalized', 'Position', [xo yo(4) .3 .1], 'String',...
%     'ccc-R ', 'HorizontalAlignment', 'left', 'TooltipString', ...
%     'Cortex Cell Count (RootScan Approximation)');
% 
% 
% ccc = uicontrol('Parent', cf_panel, 'Style', 'text', ...
%     'Units', 'normalized', 'Position', [xo+.16 yo(4) .1 .1], 'String',...
%     '', 'HorizontalAlignment', 'right');


%---------------------cell file calculation panel-------------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%








%----------------begin-begin-begin-begin-begin-begin-begin----------------%
%-----------------------------comments panel------------------------------%

position_skip = get(skip_IM_panel, 'Position');

yo = sum(position_skip([2 4]));

ht = position_xv(2) - yo;

comments_panel = uipanel('Parent', master_panel, 'Units', 'normalized', ...
    'Position', [0, yo  1 ht]);



%define the image information title string for the data information panel.

uicontrol('Parent', comments_panel, 'Style', 'text', 'Units', 'normalized', ...
    'Position', [.01 .9 .35 .1], 'String', 'Image Evaluation For ', 'FontUnits', 'Normalized',...
    'FontSize', .7, 'FontWeight', 'bold', 'HorizontalAlignment', 'left', ...
    'ToolTipString', 'Uncheck Any Boxes Associated With Unreliable Data');
    


%display the image name on the screen.

 image_name = uicontrol('Parent', comments_panel, 'Style', 'text', ...
     'Units', 'normalized', 'Position', [.33 .9 .6 .1], 'String', '', ...
     'HorizontalAlignment', 'left', 'FontUnits', 'normalized', 'FontWeight', ...
     'bold', 'FontSize', .7,  'ForegroundColor', [1 0 0], 'TooltipString', ...
     'Current Image Being Analyzed');




%get the position of the image ID uicontrol.

pos_ID = get(image_name, 'Position');



%define the first check box group. the first group contains the checkboxes
%for the aggregate data (i.e. RXSA, XSCWA, TSA, TCA, x-section diameter,
%stele diameter and cortex thickness).

%allocate memory for uicontrol handles.

group1 = 7;

f_fig_handle.checkGroup1 = zeros(2,group1);


%define the initial x coordinate and offset for check box group 1.

xo       = .015;
x_off_set = .03;


%define the offset for the y coordinate for check box group 1.

y_off_set = .1;


%define the y-coordinates for check box group 1.

yo            = flipdim(1:group1, 2);
yo = pos_ID(2)*yo/group1 - y_off_set;


%define the height and width of each check box in group 1.

ht = .08;
wd = .25;


%group 1-checkbox 1: total cross-section area.

f_fig_handle.checkGroup1(1,1) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo yo(1) wd ht], 'String', 'RXSA', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Root Cross-Section Area (mm^2)');


%group 1-checkbox 2: total cortex area.

f_fig_handle.checkGroup1(1,2) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo+x_off_set yo(2) wd ht], 'String',...
    'TCA', 'HorizontalAlignment', 'right', 'ToolTipString', 'Total Cortex Area (mm^2)');


%group 1-checkbox 3: cortex cell wall area.

f_fig_handle.checkGroup1(1,3) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [(xo+(2*x_off_set)) yo(3) wd ht], 'String',...
    'CCWA', 'HorizontalAlignment', 'right', 'ToolTipString', 'Cortex Cell Wall Area (mm^2)');


%group 1- checkbox 4: cortex thickness.

f_fig_handle.checkGroup1(1,4) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [(xo+(2*x_off_set)) yo(4) wd ht], 'String',...
    'Cort. Thickness', 'HorizontalAlignment', 'right', 'ToolTipString', 'Median Cortex Thickness (mm)');


%group 1- checkbox 5: total stele area.

f_fig_handle.checkGroup1(1,5) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo+x_off_set yo(5) wd ht], 'String', 'TSA', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Total Stele Area (mm^2)');


%group 1-checkbox 6: stele cell wall area.

f_fig_handle.checkGroup1(1,6) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [(xo+(2*x_off_set)) yo(6) wd ht], 'String', 'SCWA', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Stele Cell Wall Area (mm^2)');


%group 1-checkbox 7: stele diameter.

f_fig_handle.checkGroup1(1,7) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [(xo+(2*x_off_set)) yo(7) wd ht], 'String', 'Stele Diam.', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Median Stele Diameter (mm)');



%check all group 3 checkboxes.

set(f_fig_handle.checkGroup1(1,:), 'Value', 1);


%place these checkbox values into the second row of the matrix.

f_fig_handle.checkGroup1(2,:) = 1;



%set the callback for group 1 checkboxes.

set(f_fig_handle.checkGroup1(1,:), 'Callback', @checkboxFcn);











%define the second check box group. the first group contains the checkboxes
%for the lacunae and cortex cell data (i.e. lacunae, missing lacunae #, cell
%file count, cortex cell count, cortex cell area and median cell size).

%allocate memory for uicontrol handles.

group2 = 5;

f_fig_handle.checkGroup2 = zeros(2, group2);
f_fig_handle.editGroup2        = zeros(1,1);
f_fig_handle.editLabel         = zeros(1,3);


%define the initial x coordinate and offset for check box group 1.

xo        = .33;
x_off_set = .03;


%define the offset for the y coordinate for check box group 1.

y_off_set = .1;


%align the boxes with the top left box.

position_RXSA = get(f_fig_handle.checkGroup1(1), 'Position');



%define the y-coordinates for check box group 1.

yo            = flipdim(1:group2+1, 2);
yo = (pos_ID(2)*yo/group1) - y_off_set;
yo   = yo + position_RXSA(2) - max(yo);



%define the height and width of each check box in group 1.

ht  = .08;
wd  = .25;


%group 2-checkbox 1: lacunae.

f_fig_handle.checkGroup2(1,1) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo yo(1) wd ht], 'String', 'Lacunae', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Total Number of Lacunae');


%group 2-textbox 1 label: missing lacunae label.

f_fig_handle.editLabel(1) = uicontrol('Parent', comments_panel, 'Style', 'text',  'Units', 'normalized', ...
    'Position', [xo+x_off_set yo(2) wd ht], 'String', 'Missing Lacunae', ...
    'HorizontalAlignment', 'left', 'ToolTipString', 'Number of Missing Lacunae');


%group 2-textbox 1: missing lacunae.

f_fig_handle.editGroup2(1) = uicontrol('Parent', comments_panel, 'Style', 'edit', ...
    'Units', 'normalized', 'Position', [(wd + xo+x_off_set+.02) yo(2) .05 ht], 'String', '0', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Enter Number of Missing Lacunae Here');


%group 2-checkbox 3: cell file count.

f_fig_handle.checkGroup2(1,2) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo yo(3) wd ht], 'String', 'Cell File Count', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Radial Cell File Count');


%group 2- checkbox 4: cortex cell count.

f_fig_handle.checkGroup2(1,3) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo yo(4) wd ht], 'String', 'CCC', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Cortex Cell Count');


%group 2- checkbox 5: cortex cell area.

f_fig_handle.checkGroup2(1,4) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [(xo+(x_off_set)) yo(5) wd ht], 'String', 'CCA', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Cortex Cell Area (mm^2)');


%group 2-checkbox 6: stele cell wall area.

f_fig_handle.checkGroup2(1,5) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo yo(6) wd ht], 'String', 'Median Cell Size', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Median Cell Size (check reference image)');




%check all group 2 checkboxes.

set(f_fig_handle.checkGroup2(1,:), 'Value', 1);


%place these checkbox values into the second row of the matrix.

f_fig_handle.checkGroup2(2,:) = 1;


%set the callback for group 2 checkboxes.

set(f_fig_handle.checkGroup2(1,:), 'Callback', @checkboxFcn);
















%define the second check box group. the first group contains the checkboxes
%for the lacunae and cortex cell data (i.e. lacunae, missing lacunae #, cell
%file count, cortex cell count, cortex cell area and median cell size).

%allocate memory for uicontrol handles.

group3 = 2;

f_fig_handle.checkGroup3 = zeros(2, group3);
f_fig_handle.editGroup3        = zeros(1,2);

%define the initial x coordinate and offset for check box group 1.

xo        = .7;
x_off_set = .03;


%define the offset for the y coordinate for check box group 1.

y_off_set = .1;


%define the y-coordinates for check box group 1.

yo        = flipdim(1:(group3+2), 2);
yo = pos_ID(2)*yo/group1 - y_off_set;
yo = yo + position_RXSA(2) - max(yo);


%define the height and width of each check box in group 1.

ht  = .08;
wd  = .25;


%group 2-checkbox 1: meta xylem vessels.

f_fig_handle.checkGroup3(1,1) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo yo(1) wd ht], 'String', 'Meta  XV', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Metaxylem Vessel Data');


%group 3-textbox 1 label: missing meta xv label.

f_fig_handle.editLabel(2) = uicontrol('Parent', comments_panel, 'Style', 'text', 'Units', 'normalized', ...
    'Position', [xo+x_off_set yo(2) wd ht], 'String', 'Missing MXV', ...
    'HorizontalAlignment', 'left', 'ToolTipString', 'Missing Metaxylem Vessels');


%group 3-textbox 1: missing meta xv.

f_fig_handle.editGroup3(1) = uicontrol('Parent', comments_panel, 'Style', 'edit', ...
    'Units', 'normalized', 'Position', [((.75*wd) + xo+x_off_set+.02) yo(2) .05 ht], 'String',...
    '0', 'HorizontalAlignment', 'right', 'ToolTipString', 'Enter Number of Missing Metaxylem Vessels Here');


%group 3-checkbox 3: proto xylem vessels.

f_fig_handle.checkGroup3(1,2) = uicontrol('Parent', comments_panel, 'Style', 'checkbox', ...
    'Units', 'normalized', 'Position', [xo yo(3) wd ht], 'String', 'Proto XV', ...
    'HorizontalAlignment', 'right', 'ToolTipString', 'Protoxylem Vessel Data');


%group 3-textbox 1 label: missing proto xv label.

f_fig_handle.editLabel(3) = uicontrol('Parent', comments_panel, 'Style', 'text',  'Units', 'normalized', ...
    'Position', [xo+x_off_set yo(4) wd ht], 'String', 'Missing PXV', ...
    'HorizontalAlignment', 'left', 'ToolTipString', 'Missing Protoxylem Vessels');


%group 3- textbox 2: missing proto xv.

f_fig_handle.editGroup3(2) = uicontrol('Parent', comments_panel, 'Style', 'edit', ...
    'Units', 'normalized', 'Position', [((.75*wd) + xo+x_off_set+.02) yo(4) .05 ht], 'String',...
    '0', 'HorizontalAlignment', 'right', 'ToolTipString', 'Enter Number of Missing Protoxylem Vessels Here');



%define for user comments text box.

uicontrol('Parent', comments_panel, 'Style', 'text', 'units', ...
	'normalized', 'Position',  [.7, .21, .25, .1], 'String', ...
	'User Comments', 'FontUnits', 'normalized', ...
	'FontSize', .7, 'HorizontalAlignment', 'left', 'FontWeight', 'bold', ...
	'Max', 5, 'Min', 1);

%define the edible text box for user comments.

f_fig_handle.comments =    uicontrol('Parent', comments_panel, 'Style', 'edit', 'units', ...
	'normalized', 'Position',  [.7, .02, .3, .2], 'String', ...
	'', 'FontUnits', 'normalized', 'BackgroundColor', [.9 .9 .9], ...
	'FontSize', .3, 'HorizontalAlignment', 'left', 'FontWeight', 'bold', ...
	'Max', 5, 'Min', 1, 'TooltipString', 'Enter Your Comments Here');
 

%check all group 3 checkboxes.

set(f_fig_handle.checkGroup3(1,:), 'Value', 1);


%place these checkbox values into the second row of the matrix.

f_fig_handle.checkGroup3(2,:) = 1;


%set the callback for group 3 checkboxes.

set(f_fig_handle.checkGroup3(1,:), 'Callback', @checkboxFcn);








%-----------------------------comments panel------------------------------%
%----------------end-end-end-end-end-end-end-end-end-end-end--------------%



    

%-----set up your figure im_axes for the different images and plots.-----%
%-----set up your figure im_axes for the different images and plots.-----%
%-----set up your figure im_axes for the different images and plots.-----%    

    
    
    
    
    
    
%main axis 
    
f_fig_handle.im_axes(1) = axes('Units', 'normalized', 'Position', [.01 .02 .68 .96], 'Visible', 'off');  


%place all axes handles, table column x-position, font settings, main axes
%position settings and text field names in a figure handle structure.
%this will reduce the clutter in functions.

   
 f_fig_handle.main_axes_coords = [(.15*screen_size(3)) (.58*screen_size(3)) (.15*screen_size(4)) ...
(.3810*screen_size(3)) (.4669*screen_size(4))];  

 f_fig_handle.image_vars = [image_name num_sample current_sample CF_slider ...
     cf_done  cf_count_edit cf_count_static ccc];
     
 
 
end