function deleteSession

%this function will allow users to delete their entire RootScan Batch
%Session in their current directory.  to perform this action the user will
%be prompted to enter their current directory for deletion.  When they
%select their directory a series of two warning messages will be displayed.
% The warning message will explicitly state the irreversibility of their
%actions.

global AllImageSpecs;






%prompt the user for their current target directory for deletion.


directory = uigetdir;


%display warning message asking the user if they want to proceed.

warningMessage = ['Are you sure you want to delete the Current Session files ' ...
    'from your current image directory?'];

warningTitle = 'Delete Current RootScan Session';


answer = questdlg(warningMessage, warningTitle, 'Delete Session', 'Keep Session', 'Keep Session');





%take action based on the result of the question dialog box.

switch answer
    
    
    case 'Keep Session'
        
        %user changed their mind.  they want to forgo deleting their current
        %RootScan Session for the directory they selected.
        
        %take no action on the directory.

        
    case 'Delete Session'
       
        %user wants to proceed.  issue another warning to be sure they want
        %to go ahead with their RootScan Session deletion.
        
        warningMessage = ['Are you sure you want to delete the Current Session files ' ...
            'from your current image directory?'];

        warningTitle = 'Delete Current RootScan Session';


        answer = questdlg(warningMessage, warningTitle, 'Delete Session', 'Keep Session', 'Keep Session');
        
        
        
        %take action based on the result of the question dialog box.

        switch answer


            case 'Keep Session'

                %user changed their mind.  they want to forgo deleting their current
                %RootScan Session for the directory they selected.

                %take no action on the directory.


            case 'Delete Session'

                %user wants to proceed.  this is point of no return for the
                %user.  continue to delete the current RootScan session without
                %any additional warnings.



                %check for the existence of all session files.  if each
                %sub-directory or file exists then delete it.  Do not delete
                %the RAW image folder, this folder contains all the RGB images
                %for reference.  if the user manually deletes this folder it is
                %not a problem since they should have the images backed up on
                %another disk.


                %delete image output folder : Image_Output if it exists.


                %define list of directories for deletion.

                dirList = [{'Image_Output'}; {'X_section_binary'}; {'temp'}; ...
                    {'X_section_segments'}];

                for i = 1:size(dirList,1)

                    switch exist([directory AllImageSpecs.fileSeparator dirList{i}], 'dir')

                        case 7 

                            %it exists. delete it.

                            rmdir([directory AllImageSpecs.fileSeparator dirList{i}], 's');

                    end;

                end;



                %delete the current .mat files from the directory if they
                %exist.


                %define list of files for deletion.

                matfileVect = [{'AUTOMATED_SETTINGS.mat'}; {'CALIB_MAT.mat'}; ...
                    {'CCW_THICK.mat'}; {'DATA_MAT.mat'}; {'INTERVAL_MAT.mat'}; ...
                    {'threshMethod.mat'}; {'TIME_EFF.mat'}; {'APPROX_DAT.mat'}; ...
                    {'ccw_thickness.mat'}; {'time_efficiency.mat'}];

                for i = 1:size(matfileVect,1)


                    %delete matfile in focus.

                    switch exist([directory AllImageSpecs.fileSeparator ...
                            matfileVect{i}], 'file')

                        case 2 

                            %it exists. delete it.

                            delete([directory AllImageSpecs.fileSeparator ...
                                matfileVect{i}]);

                    end;


                end;
                

        end;
        
        
end;     
        


end