function cf_data = first_cf(varargin)

%this function will detect the innermost cell file ring for cortex cell
%area data.  This result will be used to calculated the approximate cell
%file count and approximate cell size for each cell file member.


%access global data

global  solidSegment; %solid stele image.
global            L4; %cortex label matrix.


%read in the cortex cell matrix containing only cortex cell data and noise.

all_data           = varargin{1};

all_data = sortrows(all_data, 3);



%scan the entire cortex data matrix to find the ring of inclusion.

theta = 0:(pi/6):2*pi;


%allocate memory for major axis length profile.

major_ax_profile = zeros(size(theta,2), 2);




for i = 1:(size(theta,2) - 1)
    
    
    
    %subset cortex matrix data by the sampling window defined by the
    %directional region between lower and upper theta.
    
    data_sample = all_data((all_data(:,3) >= theta(i)) & ...
        (all_data(:,3) < theta(i+1)),:);
    
    
    %subset sampling window data by radius.  keep only the inner cortex
    %cell areas.
    
    data_sample = data_sample(data_sample(:,4) <= .25, :);
    
       
    %define the mean angle within the sampling window.
    
    major_ax_profile(i,1) = mean([theta(i) theta(i+1)]); 
    
    
    
    switch isempty(data_sample) == 0
    
        
        case 1
            

    %define the mean major axes lenght for all objects within the sampling
    %window.
    
    major_ax_profile(i,2) = mean(data_sample(:,7));
    
    
        case 0
            
            
    
    end;
    

    
    
end


%take the result from the major axis profile data set and smooth the data
%using a locially weight loess regression.  assign these values to
%variable: major_ax_profile (second column).

major_ax_profile(:,2) = smooth(major_ax_profile(:,2), 'rlowess');




%cycle through the cortex by angle slices and keep only 1 (the largest object)
%within the minimum radius requirement for that samping window.



%dilate stele perimeter.

%calculate dilation radius.

dilate_rad = floor(median(major_ax_profile(:,2))/2);

stele_dilate = imdilate(solidSegment, strel('disk', dilate_rad));


L4_list = L4(stele_dilate ~= 0);


index = ismember(all_data(:,2), L4_list);

cf_data   = all_data(index,2);



% close all;
% 
% for j= 1:size(cf_data,1)
%     
%     current_IM(L4 == cf_data(j,1)) = 160;
%     
%     
%     
%     
% end
% 
% 
% figure(2), imshow(current_IM);
% colormap(jet);
% 
% ddddd



end