function gen_seg(imagePerim)

%this function will run a secondary segmentation step for the x-section image
%segmentation after the user interaction in the previous step.  this step
%is used as a redundancy measure to ensure all the x-section is included in
%the automated results and user results ensemble.


global solidSegment; %solid x-section image.
global      finalIM; %final grayscale x-section image.


    
            
%step 1: convert grayscale image to binary using the 'otsu's
%method' for image binarization.  This method is only going to be altered
%with respect to space.  We are going to compute otsu's method for a series
%of angle slices.


%define the angle vector for the cross-section sampling window scan.

thetaVect = 0:(pi/30):2*pi;


%define the x and y-coords of the cross-section doughnut ring.

[y,x] = find(solidSegment ~= 0);
index = find(solidSegment ~= 0);


%normalize the coordinates by the doughnut center of mass.

x = x - mean(x);
y = y - mean(y);


%convert to polar coordinates.

[theta, rho] = cart2pol(x,y);

theta(theta < 0) = theta(theta < 0) + 2*pi;



%loop through the angle slices and compute the binary image.

guiBinary = solidSegment*0 + 1;


for I = 1:(length(thetaVect)-1)
    
    %define the lower and upper bounds of each angle slice.
    
    lowerB   = thetaVect(I);
    upperB = thetaVect(I+1);
    
    
    %isolate all pixels in each angle slice.
    
    eachIndex = index((theta > lowerB) & (theta <= upperB));
    
    pixelVals                          = finalIM(eachIndex);
        
    pixelVals2 = pixelVals;
        
    pixelVals2(pixelVals < .5*mean(pixelVals))                     = [];
    
  
    threshVal                       = 255*graythresh(pixelVals2);
    
    guiBinary(eachIndex(pixelVals <= (threshVal)))  = 0;
    
    
end;







       
%step 2: take the complement of the image.  this is the image 
%negative of the binary image.
    
%guiBinary = imcomplement(guiBinary);
%guiBinary(imagePerim ~= 0)      = 1;
   

guiBinary        = edge(finalIM, 'canny');
guiBinary(solidSegment == 0) = 0;

            

%step 3: dilate the binary complement to seal up any holes or 
%gaps in the x-section perimeter binary complement.
            
guiBinaryDil = imdilate(guiBinary, strel('disk', 7));
    
            
%step 4: fill the dilated x-section so the x-section binary image
%becomes solid.
            
guiBinaryFill = imfill(guiBinaryDil, 'holes');
    
           
%step 5: erode the filled x-section binary image equal to the 
%degree of binary dilation in step 3.
            
solidSegment = imerode(guiBinaryFill, strel('disk', 6));
    

          
%construct a label matrix that labels each binary object.
            
roiLabel = bwlabel(solidSegment);
    


%remove everything but the solid x-section region from the solid x-section image.
   
solidSegment(:,:) = false;   
solidSegment(roiLabel == mode(roiLabel(roiLabel > 0))) = true;




end