function hi_prob = hi_binary_prob(IMAGE, SOLID)

%this function will highlight any pixel having a very high probability of
%being cell structure or cell area (the image background).  Those pixels
%values that are very close to white pixels are counted as background pixels.
%those pixels values that are very close to the black pixels are counted
%as cell structure pixels.  these results are applied after the local
%binarization method is applied in the parent function called : X_THRESH.m.


%allocate memory for high binary probability image.

hi_prob = zeros(size(IMAGE));




%determine if there are any pixels above 250.  pixels above 250 are most
%likely background pixels.

hi_prob(IMAGE >= 250) = 2;


%determien if there are any pixels below 5. pixels below 5 are most likely
%backgroiund pixels.

hi_prob(IMAGE <= 5)   = 1;





%calculate the local mean and local standard deviation of the image pixels.
%this measure will give an idea of which pixels are outliers (either they
%are background pixels or cell structure pixels).





%define the row and column indices for the solid cross-section.

[row, col] = find(SOLID ~= 0);



%allocate memory for the local mean pixel calculations.

mean_pixel = hi_prob*0;


%define the box radius for 1-dim.

box_rad = 3; 


%define the disk size for the sampling window.

disk_nhood = strel('disk', box_rad);
disk_nhood   = getnhood(disk_nhood);


for I = 1:length(row)
    
    
    %define the sampling range for the pixel neighborhood.  our pixel
    %neighborhood will consist of a square box with 7 pixels in each
    %dimension.
    
    row_index = (row(I) - box_rad):(row(I) + box_rad);
    
    col_index = (col(I) - box_rad):(col(I) + box_rad);
    
    
    %define the pixel sample around the target pixel.
    
    sample = IMAGE(row_index, col_index);
    
    
    %eliminate all pixels outside the symetrical sampling disk.
    
    sample_disk = sample(disk_nhood ~= 0);
    

    %calculate the local mean pixel value for the current pixel
    %neighborhood.
    
    mean_pixel(row(I), col(I)) = mean(sample_disk);
    
    
    
end;





%calculate the local standard deviation filter for the image.

std_pixel = stdfilt(IMAGE, disk_nhood);


%assign value=2 to high end pixels.  high end pixels are those that are
%above the mean (p-bar) and stdev (p-sigma).

hi_prob(IMAGE >= (mean_pixel + 1.5*std_pixel)) = 2;


%assign value=1 to low end pixels.  low end pixels are those that are
%below the mean (p-bar) and stdev (p-sigma).

hi_prob(IMAGE <= (mean_pixel - 1.5*std_pixel)) = 1;





end