function xv_data = highlight_objs(xv_data, xv_tag)

%this function will allow the user to highlight all meta or proto xv
%objects depending on which group are in focus.



    global      LABEL_STELE_AREAS; %label matrix for stele region.
    global          get_ref_cdata; %reference image cdata.
    global           ref_axes_obj; %reference image axes handle.
    global          main_axes_obj; %main image axes handle.
    global          AllImageSpecs; %image specifications.
    global           f_fig_handle; %all GUI children handles.
    global              XVimageUI; %xylem vessel interactive GUI image.
    global get_ref_cdata_standard; %standard reference cdata image for xv process.

    %define the current xylem vessels (whether meta or proto).

    xylem_vessels = xv_data(xv_data(:,end) == xv_tag,:);


    %determine which objects (i.e. meta xv or proto xv) are in focus.

    switch xv_tag

        case 2 %meta xv are in focus.

            current_ref_colors  = AllImageSpecs.refColors(2,:); %get reference colors.
            current_obj_color = AllImageSpecs.highlightCode(2); %get highlight colors.

        case 3 %proto xv are in focus.

            current_ref_colors  = AllImageSpecs.refColors(3,:); %get reference colors.
            current_obj_color = AllImageSpecs.highlightCode(3); %get highlight colors.

    end;



    %run for loop for previously defined meta-xylem vessle objects.

    if (isempty(xylem_vessels(:,1)) == 0)  


    %loop through all object indexes.

        for obj_i = 1:length(xylem_vessels(:,1))  

            %assign color code all all xylem vessle objects                

            XVimageUI(LABEL_STELE_AREAS == xylem_vessels(obj_i,1)) = current_obj_color;  


        end;


    end;



    %find the current highlighted xv objects (meta or proto, depends on which
    %objects are in focus).

    index = find(XVimageUI == current_obj_color);



    %assign highlight to red channel.

    get_ref_cdata(index)                                    = current_ref_colors(1);


    %assign perimeter highlight to green channel.

    get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index)   = current_ref_colors(2);


    %assign perimeter highlight to blue channel.

    get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index) = current_ref_colors(3);


    %display reference image.

    set(ref_axes_obj, 'Cdata', get_ref_cdata);


    %xylem vessel objects are highlighted. now we proceed to the interactive
    %portion of the xylem vessel selection process.

    %1-create a data cursor that, whn clicked on a region, will highlight the
    %object.


    %2-initialize the interactive image in the main image axes, set the
    %windowbuttondown function for the interactive GUI and initalize a waitfor
    %command used when the user selects the done radio button.


          set(main_axes_obj, 'Cdata', XVimageUI);  
                                   colormap(hot);

    get_main_cdata = get(main_axes_obj, 'Cdata');


    %define the windowbuttondown function for the case in which the user
    %selects a xylem vessel object.

    set(gcf, 'WindowButtonDownFcn', @buttondownSEL2);


    %wait until the user hits the xylem vessel finished radio button before
    %moving on.

    waitfor(f_fig_handle.done_buttons(xv_tag), 'value', 1);                


    %get the cdata for the main axes object.

    XVimageUI = get(main_axes_obj, 'Cdata');


    %set the windowbuttondown function to null.

            set(gcf, 'WindowButtonDownFcn', '');



    function buttondownSEL2(varargin)


    %allow the user to select the pixel coordinate of only one stele object.

    get_point = round(get(gca, 'CurrentPoint'));  


    %convert the col and row coordinates to image coordinates.

    column = get_point(1,1);  
    row = get_point(1,2);  


    %if user selects outside the image axes then he/she is done.

        if (((row < 1) || (row > size(XVimageUI,1)) || ...
            (column < -1) || (column > size(XVimageUI,2))))  


        else %previously unselected and selected objects.


        %define stele object

        current_object = LABEL_STELE_AREAS(row,column);


            if current_object > 1 %user selected non-background object.


                %unselected objects must be selected.


                    if (get_main_cdata(row,column) == 255) 

                        %asign color code to xylem vessel object index pixels.

                        get_main_cdata(LABEL_STELE_AREAS == current_object)    = current_obj_color;  
                        xv_data(xv_data(:,1) == current_object, end) = xv_tag;

                        index = find(LABEL_STELE_AREAS == current_object);


                        %assign highlight to red channel.

                        get_ref_cdata(index)                                    = current_ref_colors(1);


                        %assign highlight to green channel.

                        get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index)   = current_ref_colors(2);


                        %assign highlight to green channel.

                        get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index) = current_ref_colors(3);


                    %falsely selected objects must be de-selected    

                    else 


                        %remove color code from xylem vessel object index pixels.

                        get_main_cdata(LABEL_STELE_AREAS == current_object) = 255; 

                        xv_data(xv_data(:,1) == current_object,end) = 0;

                        index = find(LABEL_STELE_AREAS == current_object);


                        %assign highlight to red channel.

                        get_ref_cdata(index)   = get_ref_cdata_standard(index);


                        %assign highlight to green channel.

                        get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index) = ...
                            get_ref_cdata_standard((AllImageSpecs.tot_dim_pixels) + index);


                        %assign highlight to blue channel.

                        get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index)  = ...
                            get_ref_cdata_standard(2*(AllImageSpecs.tot_dim_pixels) + index);


                end;



            %if the user selects the image background (i.e. any pixel not associated
            %with the cross-section), it will de-select all previously defined xylem
            %vessel objects.

            elseif (current_object == 1)


                %remove color code from all xylem vessel object index pixels.

                get_main_cdata(get_main_cdata == current_obj_color) = 255; 

                xv_data(xv_data(:,end) == xv_tag,end) = 0;


                get_ref_cdata = get_ref_cdata_standard;





            end;


        end;


    %set cdata for main axes object.

    set(main_axes_obj, 'Cdata', get_main_cdata);    


    %set cdata for reference axes object.

    set(ref_axes_obj, 'Cdata', get_ref_cdata);


    end
                
                
end