function imageDIMnorm

%this function will evaluate all images in the X_section_segments
%sub-directory based on their image size.  The largest dimensions will
%determine the overall image size for all images in the directory.


global format; %current image format.
global h_wait; %waitbar handle.


%go to the sub-directory named: X_section_segments.

mainDIR                         = cd;  %define main image directory.

xsegDIR = [cd '/X_section_segments']; %define the subdirectory.

                         cd(xsegDIR); %change directory to sub-directory.



%find all images of one kind.  we will choose to find all the solid
%x-section images (the prefix for their labels start with : SOLID_XS

solidXSDIR = dir('SOLID_XS*');


%define the total number of images.

numImages = numel(solidXSDIR);



%read in each file and determine the size of the each image.  these
%dimensions will be stored in a NX2 matrix for maximization.

imageSize = zeros(numImages, 2, 'double');


for i = 1:numImages
    
    %read in the image.
    
    image = imread(solidXSDIR(i).name);
    
    
    %record the image size for each image.
    
    imageSize(i,:) = size(image);
     
    
end;
    


%define the values for largest row and column.  note: the largest values
%for rows and column are not nessecarily found in the same image.

maxRow = max(imageSize(:,1));
maxCol = max(imageSize(:,2));    


rowsum = sum(imageSize(:,1)) == maxRow*numImages;
colsum = sum(imageSize(:,2)) == maxCol*numImages;




if (rowsum*colsum) == 0



%determine if the maxRow or maxCol is even or odd.

maxI = (maxRow/2) > floor(maxRow/2);
maxJ = (maxCol/2) > floor(maxCol/2);

maxRow              = maxRow - maxI;
maxCol              = maxCol - maxJ;



%run through each image and pad the image array based on the current
%centralization of the image and previously calculated max row/col data.

%define image format.

format            = solidXSDIR(i).name;
index = find(format == '.', 1, 'last');
format(1:index)                   = [];


allImagesDIR = dir(['*' format]);

numImages = numel(allImagesDIR);



%normalize each image for both dimensions.

for i = 1:numImages
    
    
    
    %read in the image.
    
    image = imread(allImagesDIR(i).name);
    
    imSize = size(image);
    
    %determine if the image has even or odd number of rows and columns.
    
    maxI = (imSize(1)/2) > floor(imSize(1)/2);
    maxJ = (imSize(2)/2) > floor(imSize(2)/2);

    image(maxI,:) = [];
    image(:,maxJ) = [];
    
    padding = ([maxRow maxCol] - size(image))/2;
    
    %pad the image now.
    
    image = padarray(image, [padding], 'replicate');
    
    
    %write the image to current sub-directory.
    
    imwrite(image, allImagesDIR(i).name, format);
    
    
    %update the waitbar.
    
    percent_done = i/numImages;

    waitbar(percent_done, h_wait, [num2str(floor(percent_done*100), 3) ' % Complete']);   
    

end;


end;


%return to main image directory.

cd(mainDIR);

waitbar(1, h_wait, 'Image Dimension Normalization Complete');


end