function invertImage

%this function inverts image directories by taking the negative of the original image.
%This operation is performed when the original raw images are
%photo-negative of what is require by RootScan.


global AllImageSpecs;




%initalize waitbar for image negative conversion.

h_wait = waitbar(0, 'Initializing Image Negative Conversion Process...');





%ask the user to select the directory that needs inverted.

dir_name = uigetdir;


cd(dir_name);

%verify this is the case by displaying the first image and a dialog box.


%open image using an interval open file box.

image_formats = ['*.jpg; *.jpeg; *jp2; *.tif; *.tiff; *.gif; *.JPG; *.JPEG; *.TIF; *.TIFF'];
info    = 'Select File To Verify Image Inversion Is Required';


%open files with formats: .jpg, .jpeg, .tif, .tiff, .gif.

[image_name, dir_name] = uigetfile(image_formats,info); 


index = find(image_name == '.', 1, 'last');
format            = image_name(index+1:end);


%read in image.

image = imread([dir_name AllImageSpecs.fileSeparator image_name]);


%display image to verify inversion.

invert_fig = figure('Name', 'Sample Image Candidate for Inversion');
subplot(1,2,1);
imshow(image);
title('Raw Image');


subplot(1,2,2);
imshow(imcomplement(image));
title('Image Result');


%ask the user if the image nees inverted.

question = 'Would you like to convert the raw image to the result on the right?';
choice = questdlg(question, 'Yes', 'No'); 




switch choice

    case 'Yes'
        
        %close the sample image.
        
        close(invert_fig);
        
        
        %make a folder called 'Negatives'.
        
        mkdir('Negatives');
        
        
        %define the image directory containing all images with a specific image format.
        
        imDirectory = dir(['*.' format]);
        
        numImages = numel(imDirectory);
        
        for i = 1:numImages
            
            %read in image 'i'
            
            image = imread(imDirectory(i).name);
            
            
            %convert to grayscale if needed.
            
            if size(image,3) ~= 1
                
                image2 = rgb2gray(image);
                
            else 
                
                image2           = image;
                
            end;
            
            
            
            
            %invert the image
            
            image2 = imcomplement(image2);
            
            
            
            %save the image in folder titled: 'Negatives'
            
            imwrite(image2, [cd AllImageSpecs.fileSeparator 'Negatives' ...
                AllImageSpecs.fileSeparator imDirectory(i).name], format);
            
            percent_done = i/numImages;

            waitbar(percent_done, h_wait, [num2str(floor(percent_done*100), 3) ' % Complete']);         
            
        end;
        
        
        
        
    case 'No'
        
        %close the sample image.
        
        close(invert_fig);
        
        
        
end;



waitbar(1, h_wait, 'Image Negative Conversion Process Complete');








end