function [binary_im, binary_stele, coded_region, flag] = isolate_cortex(varargin)

%this function will determine the colors of the cross-section regions.


global     directory;
global AllImageSpecs;


%define the color coded image filename to be tested.

current_ID  = varargin{1};
current_ID2 = varargin{2};

%define stele radius.

stele_rad  = varargin{3};



%only isolate cortex if the color coded image exists.

coded_exists = exist([directory AllImageSpecs.fileSeparator 'Image_Output' ...
                AllImageSpecs.fileSeparator current_ID AllImageSpecs.fileSeparator ...
                'Highlight_RGB_region.' current_ID2], 'file');

            
switch coded_exists == 0
    
    case 0
        
        %it does exist, proceed with cortex isolation.
        
        flag = 1;

        coded_region = imread([directory AllImageSpecs.fileSeparator 'Image_Output' ...
                        AllImageSpecs.fileSeparator current_ID AllImageSpecs.fileSeparator ...
                        'Highlight_RGB_region.' current_ID2]);
            
            
        %read in current binary image.

        binary_im = imread([directory AllImageSpecs.fileSeparator 'X_section_binary' ...
            AllImageSpecs.fileSeparator 'XS_binary.' current_ID]);            



        %remove the stele area now.


        %take pixel line sample in the middle of cross-section.

        row_range = floor(.5*(-stele_rad:stele_rad) + .5*size(coded_region,1));

        line_sample  = coded_region(row_range, floor(.5*size(coded_region,2)));


        %remove all non-xv pixels from the line sample.

        line_sample(line_sample == 255) = [];


        %update the flag to false if there are no stele cell wall pixels in
        %the line sample.  this would indicate that our image is poor.
        
        switch isempty(line_sample)
            
            case 0
        
        
                %make binary dummy image use for stele removal.

                binary_stele                         = binary_im*0;
                binary_stele(coded_region == max(line_sample)) = 1;
                binary_stele(coded_region == min(line_sample)) = 1;




                %dilate binary dummy image used for stele removal.

                binary_stele = imdilate(binary_stele, strel('disk', 12));


                %fill this dummy image. should have solid stele image.

                binary_stele = imfill(binary_stele, 'holes');


                %erode binary dummy image used for stele removal.

                binary_stele = imerode(binary_stele, strel('disk', 12));


                %remove the stele pixels using the results from the binary_stele image.

                binary_im(binary_stele == 1) = 0;


                %remove lacunae from binary image.

                binary_im((coded_region >= 5) & (coded_region < 255)) = 0;


                %create label matrix for the removal of the background.

                label_binary = bwlabel(binary_im);


                %remove background pixels.

                binary_im(label_binary == 1) = 0;


                %code the cortex cell wall to zero.

                coded_region(coded_region <= 5) = 0;


                %remove the stele area.

                coded_region(binary_stele == 1) = 255;
                
                
            case 1
                
                flag = 0;
                
                binary_stele = binary_im; 
                
                
        end;
        

    case 1
        
        
        binary_im    = 0;
        binary_stele = 0;
        coded_region = 0;
        flag         = 0;

        
        
        
end;




end