function lateral_segmentation
 
%this function allows the user to select all lateral regions, if present
%in image, calculates lateral area and updates the reference image.


%access the global variables for the gui figure handles and data specifications.
        
global    f_fig_handle; %handle for all GUI children.
global   AllImageSpecs; %all image specs.
global     data_matrix; %data matrix.
global    ref_axes_obj; %reference axes handle.
global   get_ref_cdata; %reference axes cdata.      
global        DirSpecs; %structure containing all directory specifications.   
global      imagePerim; %perimeter image.
global  X_section_gray; %gray x-section.
global X_section_solid; %solid x-section (binary)


 
        
%define a color coded image for the tracking of user interaction steps.
        
set(gcf, 'CurrentAxes', f_fig_handle.im_axes(2));
                                          cla;
           

%find the perimeter of the x-section.  this will be used to draw a
%highlighted perimeter around the x-section.
        
imagePerim                                         = bwperim(X_section_solid);
imagePerim = imdilate(imagePerim, strel('disk', AllImageSpecs.PerimThick(2)));
        
        
%draw highlighted perimeter around x-section.
        
index                                = find(imagePerim == 1);


%assign grayscale x-sections pixels to red channel.

get_ref_cdata(:,:,1) = X_section_gray; 


%assign grayscale x-section pixels to the green channel.

get_ref_cdata(:,:,2) = X_section_gray;


%assign grayscale x-section pixels to the blue channel.

get_ref_cdata(:,:,3) = X_section_gray;
        
 


%assign perimeter highlight to red channel.

get_ref_cdata(index)                                   ...
    = AllImageSpecs.refColors(4,1);


%assign perimeter highlight to green channel.
        
get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index)   ...
    = AllImageSpecs.refColors(4,2);


%assign perimeter highlight to blue channel.
        
get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index) ...
    = AllImageSpecs.refColors(4,3);
 

%show the reference image in the reference axes.

ref_axes_obj = imshow(get_ref_cdata);


                                        
%set the current axes to the left main axes clear any existing images and show
%the x-section image with interactive polygon for user intervention. the user
%manually isolates any lateral regions.
            
set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));


%use the function 'roipoly' to allow user to draw a N-sided polygon around a 
%lateral region if present.
        
%display the initial interactive polygon to allow user to select any
%laterals regions.

lateral_segment = roipoly(X_section_gray);

         
                       
                       
%set the finished (done) radiobutton associated with the x-section
%segmentation step to on so the user can select it when finished.

set(f_fig_handle.done_buttons(5), 'enable', 'on');


%if the user made adjustments to the lateral isolation then assign the
%mask associated with the image polygon tool to the solidSegment result.

if max(max(lateral_segment)) == 0
     
    %initialized lateral binary image.
    
    lateral_segment = imagePerim*0;     
    
end;


%set lateral done button to 1 and disable.

             set(f_fig_handle.done_buttons(5), 'value', 1);  
        set(f_fig_handle.done_buttons(5), 'Enable', 'off'); 
       
        
%if the user does not take action (i.e. the user does not draw a n-sided polygon
%around the lateral region) the image a zeroes matrix of size equal size to that
%of the original image must be made. this image will be used later in the analysis.                                        
        
switch (sum(sum(lateral_segment)) == 0) %if the 'roipoly' handle: 'lateral_segment' sums to
                                    %zero then define a zeros matrix.
	case 1
                
        lateral_segment = zeros(AllImageSpecs.size); %define zeros matrix 
        
            
end; 
          
        
%write all temporary images to file at this time.  NOTE: the 2-D image array
%outputImage is defined once and indexed differently for the differeny image
%output expressions.
        
%remove lateral from cross-section image. make it white. add
%IMAGE.tif located at path=imagename.
       
outputImage    = X_section_gray;
outputImage(lateral_segment ~= 0) = 255;
                        

imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
    AllImageSpecs.fileSeparator 'current_image.' AllImageSpecs.format];  
            
         imwrite(outputImage, imagename, AllImageSpecs.format);  

                             
%add lateral region to XsectionCode.tif located at path=imagename.
            
outputImage             = zeros(AllImageSpecs.size, 'uint8');
outputImage(X_section_solid ~= 0)                      = 255;
outputImage((lateral_segment ~= 0) & ...
    (X_section_solid ~= 0)) = AllImageSpecs.highlightCode(6);
            
 
%write the current color coded image to the temp images directory.
            
imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
	AllImageSpecs.fileSeparator '/XsectionCode.tif'];
            
              imwrite(outputImage, imagename, 'tif');


  
%calculate lateral area.
      
data_matrix{DirSpecs.iteration, 46} = bwarea(lateral_segment)/AllImageSpecs.calib_area;
        

   
%find the perimeter of the x-section.  this will be used to draw a highlighted
%perimeter aroiund the x-section lateral.
        
switch bwarea(lateral_segment) > 0
        
    case 1
            
            
    	%define the lateral region in image.
            
        imagePerim                                  = lateral_segment*0;
        imagePerim((lateral_segment ~= 0) & (X_section_solid ~= 0)) = 1;
                
            
        %define the perimeter of the lateral region in image.
            
        imagePerim                                              = bwperim(imagePerim);
        imagePerim = imdilate(imagePerim, strel('disk', AllImageSpecs.PerimThick(2)));
        
        
        %highlight lateral perimeter in reference image.
            
        index                                = find(imagePerim == 1);
        
        get_ref_cdata(index)                                    ...
        	= AllImageSpecs.refColors(5,1); %red channel.
            
        get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index)   ...
        	= AllImageSpecs.refColors(5,2); %green channel.
            
        get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index) ...
        	= AllImageSpecs.refColors(5,3); %blue channel.     

        %displat the updated reference image.
        
        set(ref_axes_obj, 'Cdata', get_ref_cdata);
        
        

            
end;  
            
            
%save reference image containing lateral selection.
        
imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
	AllImageSpecs.fileSeparator 'refCdata.tif'];
        
          imwrite(get_ref_cdata, imagename, 'tif');

        
             
            
end