function local_binary_image = local_threshold_method(x_section_grayscale, x_section_solid, threshold_iteration)
       
%this function is devoted to using localized thresholding to yield 
%a grayscale image in it most accurate binary form. this will ensure the 
%boundary is labeled as such and cell areas are labeled as such.  this must
%be done since many images are of poor quality, low contrast, and most
%images, if not all, have local variations in the image contrast.



global AllImageSpecs; %structure containing all image specifications.
global   data_matrix; %data matrix.
global      DirSpecs; %structure containing all directory specifications.
global  f_fig_handle; %handle for all GUI children.
global         f_fig; %main rootscan GUi figure window handle.



%define buffer half window size.

buffer_margin = 20;          
          

%pad the current image matrices.

x_section_grayscale = padarray(x_section_grayscale, [buffer_margin buffer_margin], 'symmetric');

x_section_solid         = padarray(x_section_solid, [buffer_margin buffer_margin], 'replicate');



%find the image cross-section indices for which the binarization is
%performed.

[row, col] = find((x_section_solid ~= 0));% & (hi_prob == 0));


%define the min and max's for rows and columns.

Crow = [min(row) max(row)];
Ccol = [min(col) max(col)];


%determine if the range of row indices are even or odd.

Evenrange = ((Crow(2)-Crow(1))/2) - floor((Crow(2)-Crow(1))/2);


if (Evenrange > 0)

    Crow(2) = Crow(2)+1;

end;


%determine if the range of column indices are even or odd.

Evenrange = ((Ccol(2)-Ccol(1))/2) - floor((Ccol(2)-Ccol(1))/2);

if (Evenrange > 0)

    Ccol(2) = Ccol(2)+1;

end;


%determine the sampling vector for the row and column indices.

row = Crow(1):AllImageSpecs.thresh_method:Crow(2);
col = Ccol(1):AllImageSpecs.thresh_method:Ccol(2);
    
        

%define the sample window size.

winSize = AllImageSpecs.thresh_method;


%define starting row and column indices for sample window.

WinStart = buffer_margin + 1;


%define the ending row and column indices  for sample window.

WinEnd = buffer_margin + winSize;

  
%apply local otsu method to cross-section image pixels.

local_binary_image = binary_conv23(x_section_grayscale, row, col, WinStart, WinEnd, ...
    buffer_margin);
 




%remove the salt and pepper noise within cell areas resulting from the
%local binary conversion methods. %we will do this by taking the image
%negative and finding the mode of the label matrix.

%remove the padding on the two image matrices.

local_binary_image([(1:buffer_margin) ((end-buffer_margin)+1:end)],:) = [];
local_binary_image(:,[(1:buffer_margin) ((end-buffer_margin)+1:end)]) = [];

x_section_solid([(1:buffer_margin) ((end-buffer_margin)+1:end)],:)    = [];
x_section_solid(:,[(1:buffer_margin) ((end-buffer_margin)+1:end)])    = [];



%--------this section is removed since it removes images sometimes--------%




% %define local binary pixel map without white image background. you will see
% %a x-section binary image.
% 
% local_binary_image(x_section_solid == 0) = 0;
% 
% 
% %fill the local map. this should remove any salt and pepper noise in the
% %binary image.
% 
% local_binary_image = imfill(local_binary_image, 'holes');
% 
% 
% 





%--------this section is removed since it removes images sometimes--------%


%recode the local map now.  you should have a binary x-section and
%white background.

local_binary_image(x_section_solid == 0) = 1;

%invert the binary image.

local_binary_image = imcomplement(local_binary_image);


%create label matrix for inverted image.

label_invert = bwlabel(local_binary_image);


%find the mode of the label matrix.  this corresponds to the whole
%cross-section cell wall.

label_mode = mode(mode(double(label_invert(label_invert ~= 0))));


%remove the every object but the mode.

local_binary_image(label_invert ~= label_mode) = 0;


%invert the binary image back to its original form.

local_binary_image = imcomplement(local_binary_image);




%write binary image to file.  this image will be storedin the subdirectory
%: X_section_binary.

%define the image name without the format suffix.

image_name = data_matrix{threshold_iteration, 1};
index = find(image_name == '.', 1, 'last');
image_name = [image_name(1:index) 'tif'];


%define the file path for writing the binary image to directory.

file_name = ['X_section_binary' AllImageSpecs.fileSeparator ...
    'XS_binary.' image_name];
     
%convert the image to logical format.

local_binary_image      = logical(local_binary_image);
       

%write the image to file.

        imwrite(local_binary_image, file_name, 'tif');
     
   


%read in grayscale image.
        
grayimage = imread(['X_section_segments' AllImageSpecs.fileSeparator ...
	'XS.' data_matrix{threshold_iteration,1}]);        



switch DirSpecs.batch_mode == 1
    
    case 1
        

        %display the original grayscale image in the reference image axes.

        set(f_fig, 'CurrentAxes', f_fig_handle.im_axes(2));
                                                  cla;

        imshow(grayimage);  


        %display the result in the main image axes.

        set(f_fig, 'CurrentAxes', f_fig_handle.im_axes(1));
                                                  cla;

        imshow(local_binary_image);                                         
                                          

    case 0
        
        figure(2), imshow(local_binary_image);
        
        
end;



%enter calibration value and threshold method settings into data matrix.
                        
data_matrix{threshold_iteration, 2} = ['Image Cal Value = ' num2str(sqrt(AllImageSpecs.calib_area)) ...
	'  -  Threshold Method = ' num2str(AllImageSpecs.thresh_method)];       
    

%enter dummy value into x-section wall column.
        
data_matrix{threshold_iteration, 3}                      = -1;

    
%place calibration value and threshold method information in data matrix.
 
switch DirSpecs.batch_mode == 1
    
    case 1

        switch DirSpecs.programMode

            case -2 

            %save the current updated matrix.

            save('DATA_MAT', 'data_matrix');  


        end;
        
        
    case 0
        
        %save the current updated matrix.

        save('DATA_MAT', 'data_matrix');         
        
        
end;
        


     
      
end