function [cortexData, lacunae_matrix] = manual_lacunae_selection(cortexData)

%this function allows the user to interactively select cortical object
%(this action actually takes place in a child function.  most of the
%aerenchyma and cortical region measurements are calculated in this
%function.
    
    global     f_fig_handle; %contains all GUI handles.
    global    AllImageSpecs; %image specifications.
    global      data_matrix; %data matrix.
    global    get_ref_cdata; %reference axes cdata.
    global    ref_lat_stele; %coded image for lateral and stele.
    global        non_aeren; %cortex cell object matrix.
    global highlight_cortex; %highlighted cortex.
    global               L4; %label matrix for cortex.
    global         DirSpecs; %directory specifications. 


    %enable aerenchyma finished radio button.

    set(f_fig_handle.done_buttons(1), 'enable', 'on'); 


    %access reference image from temporary images directory.

    ref_lat_stele = imread([cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'ref_lat_stele.tif']);


    %access coded cross-section image from temporary images directory. call it
    %highlight_cortex for now. we will not write the new data to file.  we just
    %want to use it.

    highlight_cortex = imread([cd AllImageSpecs.fileSeparator 'temp' ...
         AllImageSpecs.fileSeparator 'XsectionCode.tif']);




    %open a gui to let the user select or de-select arenchyma areas.  in this
    %gui the user will select any cortex objects that are actually aerenchyma
    %that went undetected in the auto-aerenchyma detection function.  also, when
    %the auto-aerenchyma detection function falsely identified an object as
    %aerenchyma, the user can then de-select the object.  if the user clicks on
    %any image pixel not associated with the cross-section the gui will clear
    %some highlighted objects (this is sorta like a refresh button).  enjoy...


    %subset lacunae detected during the auto-detection algorithm.

    lacunae_matrix = sortrows(cortexData(cortexData(:,10) == 2, 2));  






    %----------highlight all cortex objects defined aerenchyma by algorithms.--------%



    %make cortex cell wall black (value = 0).

    highlight_cortex(highlight_cortex == 5)   = 0;


    %make everything else white (value = 255).

    highlight_cortex(highlight_cortex ~= 0) = 255;


    
    %loop through all inital lacunae objects and highlightCode each object using
    %the current color code.

    for i = 1:length(lacunae_matrix)  

        %highlightCode each object detected as aerenchyma

        highlight_cortex(L4 == lacunae_matrix(i)) = AllImageSpecs.highlightCode(1);  

    end;     





    %----------------highlight all lacunae in reference image-----------------%



    %define the index for lacunae object pixels. this result will be used to
    %highlight the lacunae in the reference image using the color set by the
    %user in the color preferences (3-channel) module found in the main Rootscan menubar.

    index_ref = find(highlight_cortex == AllImageSpecs.highlightCode(1));


    %assign lacunae color code for red channel.

    get_ref_cdata(index_ref)                                    = AllImageSpecs.refColors(1,1);


    %assign lacunae color code for green channel.

    get_ref_cdata(AllImageSpecs.tot_dim_pixels + index_ref)     = AllImageSpecs.refColors(1,2);


    %assign lacunae color code for blue channel.

    get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index_ref) = AllImageSpecs.refColors(1,3);





    %-------------------------------------------------------------------------%
    %---------------------------lacunae validation----------------------------%
    %-------------------------------------------------------------------------%

    %user selects any lacunae object not detected by Rootscan and de-selects
    %any object miss-classified as lacunae.

    cortexData = select_aerenchyma(cortexData, L4);


    %-------------------------------------------------------------------------%                       
    %proceed to the calculations derived from the aerenchyma selection process%                       
    %-------------------------------------------------------------------------%                       




    %subset all lacunae object areas for calculations.

    lacunae_matrix = cortexData(cortexData(:,10) == 2, 1);


    %if there are no lacunae (i.e. cross-section absent of aerenchyma) then
    %make the lacunae matrix equal to zero.

    switch isempty(lacunae_matrix)

        case 1

        lacunae_matrix = 0;

    end;


    %assign number of lacunae to data matrix.

    data_matrix{DirSpecs.iteration, 12}                         = length(lacunae_matrix); 


    %assign median lacunae area to data matrix.

    data_matrix{DirSpecs.iteration, 13} = median(lacunae_matrix)/AllImageSpecs.calib_area; 


    %assign lacunae area standard deviation to data matrix.

    data_matrix{DirSpecs.iteration, 14}    = std(lacunae_matrix)/AllImageSpecs.calib_area; 


    %assign smallest lacunae area value to data matrix.

    data_matrix{DirSpecs.iteration, 15}    = min(lacunae_matrix)/AllImageSpecs.calib_area; 


    %assign largest lacunae area value to data matrix.

    data_matrix{DirSpecs.iteration, 16}    = max(lacunae_matrix)/AllImageSpecs.calib_area; 


    %assign total lacunae area value to data matrix.

    data_matrix{DirSpecs.iteration, 17}    = sum(lacunae_matrix)/AllImageSpecs.calib_area; 

    
    
    
    
    
    %loop through each cortex interval and assign color code to matrix indices.

    for j = 1:DirSpecs.cortBins 


        %define the lower and upper boundary for each cortex interval. 

        lower_bound =     AllImageSpecs.bands_intervals(j);  
        upper_bound = AllImageSpecs.bands_intervals(j + 1);  


        %assign color tag to each object falling within the cortex interval.

        cortexData((cortexData(:,4) >= lower_bound) &  (cortexData(:,4) < upper_bound), 11) ...
            = AllImageSpecs.bands_colors(j); 


    end; 





    %sub-set all non-aerenchyma objects for cortex cell area calculations.

    non_aeren        = cortexData(abs(cortexData(:,10)) ~= 2, :);  


    %-----------------------noise reduction (begin)---------------------------%

    %remove some noise from the non_aerenchyma objects matrix.

    %****************noise reduction algorithm needs some work****************%
    
     non_aeren = cortex_noise_reduct(non_aeren);

    %-------------------------noise reduction (end)---------------------------%


    
    

    %-------------------------------------------------------------------------%
    %------------------------cortex cell calculations-------------------------%
    %-------------------------------------------------------------------------%

    
    %cortical cell count.  *****we need more accuracy********
    
    %assign cortex cell count and cortical cell area to data matrix.

    data_matrix{DirSpecs.iteration, 18} = size(non_aeren,1); 


    %cortical cell area.  *****we need more accuracy********

    data_matrix{DirSpecs.iteration, 20} ...
        = sum(non_aeren(:,1))/AllImageSpecs.calib_area;


    set(f_fig_handle.image_vars(8), 'String', int2str(size(non_aeren,1)));



    %----calculate the median cortex cell sizes for each radial cortex band----%



    %calculate the median for the cortex interval selections.

    
    %allocate memory for cortical cell size bin image.

    cortCellSize                                         = highlight_cortex;
    cortCellSize((highlight_cortex ~= 0) & (highlight_cortex ~= 255)) = 255;


    ObjectColors = repmat([100 190], [1 10]);

    %loop through each interval based on the color tag and calculate the
    %median cell size.

    for theta_i = 1:DirSpecs.cortBins 


        %sub matrix for each radial band.

        sample_band = non_aeren(non_aeren(:, 11) == AllImageSpecs.bands_colors(theta_i), :);


        for I = 1:size(sample_band,1)


            %color in each object

            cortCellSize(L4 == sample_band(I,2)) = ObjectColors(theta_i);

        end;




        %calculate the mean cell size for each cortex interval.

        data_matrix{DirSpecs.iteration, 49+theta_i} = median(sample_band(:,1))/AllImageSpecs.calib_area;  


    end;


    %save cortical cell size image.

    save([cd '/temp/cortCC'], 'cortCellSize');

    clear cortCellSize;



    %new cell file method. this function was initilized January 2011, modified Feb 2011.
    %future changes may be made to function as new data arise when testing for the
    %reasoning behind some cell file calculation inconsistency.


    %initialize polygon for cell file calculation.

    %[XsectionCode, TCApix]   = cf_poly(non_aeren);



    %find the first cell file ring.  this data matrix will be used to
    %initialize the search of all proceding cell file rings as one proceeds to
    %the outer cortex boundary.

    initial_cf = first_cf(non_aeren);

    TCApix = 1;
    
    cf_mode = 1;


    %calculate the cell wall thickness statistics.

    cw_thick_measure;



    %new cell file count method.  currently under construction.

    cf_Isolate(highlight_cortex, non_aeren, TCApix, initial_cf, cf_mode);


    %-------------------------------------------------------------------------%             

    %old cell file count method.  currently suspended.

    %[cort_thick_measure, CORTEX_THICKNESS] = ...
        %radial_cell_file_count(XsectionCode, non_aeren, image_name);

    %-------------------------------------------------------------------------%    



    beep




    %read in the color coded x-section image.

    imagename  = [cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'XsectionCode.tif'];

    XsectionCode                    = imread(imagename);


    %highlight the aerenchyma area pixels.

    XsectionCode(XsectionCode == AllImageSpecs.highlightCode(1)) = 255; 

    XsectionCode(highlight_cortex == AllImageSpecs.highlightCode(1)) ...
        = AllImageSpecs.highlightCode(1);


    %write the new image to file.

    imwrite(XsectionCode, imagename, 'tif'); 



    %disable the aerenchyma finished button.

    set(f_fig_handle.done_buttons(1), 'enable', 'off');             
            
            
            
           
        
end