function manual_segmentation
      
%this function allows the users to actively select the cross-section if the
%automated cross-section detection algorithm failed to do so accurately.


%read in the global variables for the gui figure handles, image specifications,
%directory name and image output specifications.

global        f_fig_handle; %structure containing all figure properties and children.
global       AllImageSpecs; %structure containing all image specifications.
global           imageSize; %image size
global x_section_reference; %image used for the interactive polygon.
global          imagePerim; %image perimeter mask.
global        solidSegment; %solid image mask.
global                img1; %current raw grayscale image.
global             finalIM; %final grayscale image without background debris.
    

    
%disable all main buttons.
    
set(f_fig_handle.image_done_button, 'enable', 'off');  

 
%define temporary solid cross-section image.  we will need to compare the
%automated results with the users selection later on in the function.

solidSegment2 = solidSegment;    
                                                                                                 
        
%define the x and y-coms for the cross-section center of mass.  these will
%be used to place the initial coordinates in the interactive polygon so the
%user does not have to draw the interactive polygon from scratch each time.
%this will save the user time.
        
[row, col] = find(solidSegment ~= 0);
        
xbar = mean(col); %row mean.
ybar = mean(row); %column mean.
        

        
%define the initial condition for while control structure.
        
manual_done = 0;  

  
%define the perimeter image for the automated solid cross-section image.

imagePerim = bwperim(solidSegment);
  

%create a vector that will be used in the interactive polygon tool.

[row, col] = find(imagePerim == 1);
        
posVect = [(row - ybar) (col - xbar)];
        


%dilate cross-section perimeter.
        
imagePerim = imdilate(imagePerim, strel('disk', AllImageSpecs.PerimThick(1)));
  

%Remove inner dilation since the user should see the image border pixels to
%make an accurate assessment of whether the automated x-section detection
%algorithm calculated the x-section border correctly.

imagePerim(solidSegment ~= 0) = 0;
        
        

%------------highlight the stele region perimeter bright green------------%
 

%define index for dilated x-section perimeter image.

index = find(imagePerim ~= 0);
        
x_section_reference(index)                                  = AllImageSpecs.refColors(4,1); %red channel.
         
x_section_reference((imageSize(1)*imageSize(2)) + index)    = AllImageSpecs.refColors(4,2); %green channel.
        
x_section_reference(2*(imageSize(1)*imageSize(2)) + index)  = AllImageSpecs.refColors(4,3); %blue channel.
       
               
                                        
%enter control structure and remain until the user performs a valid operation.
        
while (manual_done == 0)  
        
                                               
    %set the current axes to the left main axes, clear any existing  finalim and
    %show the x-section image with interactive polygon for user intervention. 
    %the user manually isolates x-section from image background.
                                                 
    set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));
                                                 cla; 
                         imshow(x_section_reference);         
                 XsStelepoly(posVect, 4, xbar, ybar); 
                                            axis off;         
                                                 
  
 
    %determine the pixel area of the initial xs and modified xs.
          
    sizeInitXS = bwarea(solidSegment2);
    sizeManXS   = bwarea(solidSegment);  
          
          
    %if the size of the cross section does not meet our lowest 
    %criteria, ask the user if they are satisfied with their actions.
            
    if ((isempty(solidSegment)) && (sizeManXS <= ...
                    (.00001*size(img1,1)*size(img1,2))))   
          
                
    	%set done to 0. clear the current image handle associated 
        %region-of-interest tool and re-introduce region of interest tool.
                
        manual_done = 0;  
                    cla;  
                
                
        %if the size of the cross section does not meet our lowest criteria
        %but meets the second a question box shows up to ask the user
        %if the current cross section is valid.   
            
    elseif ((isempty(solidSegment)) && (sizeManXS <  (.05*size(img1,1)*size(img1,2))))   
                
                
        %display question dialog box.
                
        question                   = 'Is this the entire cross section? ';
        title_name                                = 'Small Cross Section';
                        
                              
        choice = questdlg(question, title_name, {'Yes',  'No', 'Cancel'});  
                        
                
                
        switch choice
                        
        	case {'Yes'} %the cross section is valid.  
                           
                        
            	%exit while control structure.
                                
                manual_done = 1; 
                            
            case {'No'}  %the cross section is not valid  per user response.  
                            
                        
                %remain in while control structure.
                                
                manual_done = 0; 
                            
            case {'Cancel'}  %the cross section is not valid per user response. 
                            
                        
                %remain in the while control structure.
                                
                manual_done = 0; 
                            
        end;
                       
                        
	else %the object is large enough.
                
                
    	%exit the while control structure.
                
        manual_done = 1; 
                
    end;
          
            
    %clear left axes.
            
    cla; 
            

            
end;

   


%disable x-section radiobutton.
       
set(f_fig_handle.done_buttons(4), 'enable', 'off');

        
%if the x-section was partially or completely eliminated in  the manual x-section
%segmentation we must define the x-section  image (binary) and x-section image
%(grayscale).  take the result from the region of interest polygon gui and run
%an additional segmentation step to %ensure all non-x-section pixel are eliminated.
%this needs to be done since it is almost impossible to draw around a x-section
%(or other region) with a high degree of accuracy.  besides the degree of accuracy
%across users may have a high degree of variability. this step (or series of steps)
%will eliminate any %measurement error associated with the user interaction.
        
      
    
%define x-section image (grayscale) based on the binary results from the region
%of interest gui handle.  retain the area enclosed by the region of interest result.
              

switch (sizeInitXS ~= sizeManXS);
            
                
    case 0 %user did not interact with image.  use the results from the
           %automatrix xs detection method
                    
        solidSegment = solidSegment2; %redefine solid x-section.
              
            
        %define the final grayscale result based on the results from this function.
                
        %create blank image (white).
            
        finalIM                               = img1*0 + 255;
            
            
        %insert cross-section pixels only.

        finalIM(solidSegment ~= 0) = img1(solidSegment ~= 0); 
                
                    
	case 1 %user did interact with image.  use these results instead.
        
    
        %we need to verify that lighter cross-section pixels in the
        %vicinity of the border regions are counted as x-section area.
        
        %define the median filter for the image.  we will only use
        %the median filter values for the image background.  this result
        %helps us normalize the image background.
            
        %finalIMmed = medfilt2(img1, [30 30], 'symmetric');
            
  
        %calculate the median value of median filter image at the ROI 
        %border selected by the user.  we will set the background pixels
        %to this value.
            
        imagePerim = bwperim(solidSegment);
            
        
        %calculate the median background value.
        
        %medVal      = median(finalIMmed(imagePerim ~= 0));
            
        
        overlap = sum(sum(solidSegment.*solidSegment2));
            
        maxDiam1  = max(sum(solidSegment,1))/2;
        maxDiam2 = max(sum(solidSegment2,1))/2;


        diffPerimA = pi*(maxDiam1 - maxDiam2).^2;
        
        

        %if the regions of the automated x-section segmentation result
        %overlap with the results of the manual x-section segmetnation
        %result we must make additional corrections to the final x-section
        %boundary.
        
        switch overlap >= .5*diffPerimA
                        
                %set the grayscale result background pixels to median pixel value 
                %for the background. 
                
                
            case 1
        




                %remove all pixels outside initial xs segment.

                solidSegment2(solidSegment == 0) = 0;




                %retain only the border region of cross-section image.  this image 
                %should look like a doughnut.            

                %retain only the outer 5% of xs.

                %maxDiam = max(sum(solidSegment2,1));

                %diskRad = floor(.20*maxDiam/2);

                %imagePerim                       = bwperim(solidSegment2);
                %imagePerim = imdilate(imagePerim, strel('disk', diskRad));
                %imagePerim(solidSegment2 == 0)                        = 0;

                imagePerim = bwperim(solidSegment2);

                
                
                
                %retain only the outer 20% of xs.    
                
            case 0
                
                %define the maximum diameter of the x-section.
                
                maxDiam = max(sum(solidSegment,1));
                
                
                %define the dilation structural element based on the
                %maximum diameter calculated in the previous line.

                diskRad = floor(.25*maxDiam/2);   
                
                
                %use the diskRad result to dilate the x-section perimeter
                %image.

                imagePerim                        = bwperim(solidSegment);
                imagePerim = imdilate(imagePerim, strel('disk', diskRad));
                imagePerim(solidSegment == 0)                         = 0;

                
                %remove all pixels outside the current x-section.
                
                imagePerim(solidSegment == 0)                         = 0;
            
            
                
        end;

        %if changes were made to the region of interest then we need to
        %run another segmentation step to ensure we are accurate.   
                
        finalIM = img1;

        gen_seg(imagePerim);
      
             
        %define the final grayscale result based on the results from this function.
                
        %create blank image (white).
            
        finalIM(:)                                     = 255;
            
            
        %insert cross-section pixels only.
            
        finalIM(solidSegment ~= 0) = img1(solidSegment ~= 0); 
        
        

                    
end;
            
     
            
end
