function xv_data = manual_xv_selection(xv_data, skip_proto)
  
%this function allows the user to manually select/deselect stele objects to
%classify them as xylem vessels.  the user interacts with the user
%interface by clicking on those objects in question.


%access the xylem vessel value display, dataspecs and f_fig_handle object
%structure and image output specs.

global  f_fig_handle; %all GUI handleds.
global AllImageSpecs; %image specifications.
global  solidSegment; %solid image segment (intermediate steps).
global      X_binary; %binary x-section.
global     XVimageUI; %stele region (user interactive).
    
   
    
%enable meta xylem vessel finished radio button so user can hit it when done.
    
          set(f_fig_handle.done_buttons(2), 'enable', 'on');      

    
    
%opem temporary image from temp image directory located in current 
%images directory.
    
imagename    = [cd AllImageSpecs.fileSeparator 'temp' ...
	AllImageSpecs.fileSeparator 'XsectionCode.tif'];
    
XsectionCode                        = imread(imagename);
    
    
    
    
    
%-------------------------------------------------------------------------%               
%---visual analysis: display highlighted (meta or proto) xylem vessels.---%
%-------------------------------------------------------------------------%




%run the function that selects/de-selects all meta-xylem
%vessel objects.


%define the xylem vessel image for which the user will interact with.  
                
XVimageUI   = XsectionCode*0 + 255; %set all pixels to white.
XVimageUI(X_binary == 0)       = 0; %set all cell structure pixels to black.
XVimageUI(solidSegment == 0) = 255; %set all cortical pixels to white.


%based on the previous lines, we should only have a black and white stele
%region. everything else is gone.


set(f_fig_handle.step_label(1), 'ForegroundColor', [0 .7 0]); %set the foreground color of the meta xv step label to green. 


xylemTag = 2;


xv_data = highlight_objs(xv_data, xylemTag); 
    
 set(f_fig_handle.step_label(1), 'ForegroundColor', [0 0 0]); %set the foreground color of the meta xv step label to black. 


   
%run the auto-proto-xylem detection function now.  we need to remove all
%meta-xylem vessel objects prior to auto-detection.

switch skip_proto
    
    case 0

    xv_data = automatic_protoXV_detection(xv_data);

end;



%run the function that selects/de-selects all proto-xylem vessel objects.

xylemTag = 3;


set(f_fig_handle.done_buttons(2), 'enable', 'off'); %disable meta xylem finished button.
 set(f_fig_handle.done_buttons(3), 'enable', 'on'); %enable proto xylem finished button.

 
 
set(f_fig_handle.step_label(2), 'ForegroundColor', [0 .7 0]); %set the foreground color of the proto xv step label to green. 
 
 

%allow user to select any proto xylem objects.

xv_data = highlight_objs(xv_data, xylemTag); 
          

set(f_fig_handle.step_label(2), 'ForegroundColor', [0 .7 0]); %set the foreground color of the proto xv step label to black. 


          set(f_fig_handle.done_buttons(3), 'enable', 'off'); %disable proto xylem finished button.

                
      
%calculate the variables for the meta xylem vessels.
                
xv_calc_data(XVimageUI, 1); 
                
                              
%calculate variables for proto-xylem vessels.
                
xv_calc_data(XVimageUI, 2); 
                
                
                

%code in the meta and proto-xylem vessels into the xsectioncode and save the
%changes.     

XsectionCode(XsectionCode == AllImageSpecs.highlightCode(2))                         = 255;
XsectionCode(XVimageUI == AllImageSpecs.highlightCode(2)) = AllImageSpecs.highlightCode(2);
              

XsectionCode(XsectionCode == AllImageSpecs.highlightCode(3))                         = 255;
XsectionCode(XVimageUI == AllImageSpecs.highlightCode(3)) = AllImageSpecs.highlightCode(3);
 


%save the temp image 'XVimageUI'.              
              
imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
    AllImageSpecs.fileSeparator 'XsectionCode.tif'];  

               imwrite(XsectionCode, imagename, 'tif');  
                
              
%set the xylem vessel push button background color to white. and disable
%the finished radio button associated with the meta and proto xylem vessels.
            
set(f_fig_handle.done_buttons(2:3), 'enable', 'off');               
              
              
                
                
end
