function result = modotsu(pxvalslice, pxmin, pxmax, step)

%this function is basically modified version of otsu's interclass variance
%minimization problem.  In the modified version the interations are run over
%a specified interval instead of running it over the range of values.
%Also, the interation step is modified to speed up the optimization
%process.



%define the pixel range for the modified otsu method.

pxrange = (pxmin + 5):step:(pxmax - 5);


%define the length of the pixel vector input into function.

totsize = length(pxvalslice);


%allocate memory for the interclass variance results.

bwtclassvar = zeros(length(pxrange), 2);
bwtclassvar(:,1)             = pxrange';



%loop through each threshold value and calculate the interclass variance.

for j = 1:length(pxrange)

    
    %variance weight for low class.
    
    lowclass             = var(pxvalslice(pxvalslice <= pxrange(j)));
    
    
    %variance for low class.
    
    lowweight                             = length(lowclass)/totsize;
    
    
    %variance weight for high class.
    
    highclass             = var(pxvalslice(pxvalslice > pxrange(j)));
    
    
    %variance for high class.
    
    highweight                           = length(highclass)/totsize;
    
    
    %interclass weighted variance calculation.
    
    bwtclassvar(j,2) = (lowclass*lowweight) + (highclass*highweight);
    



end;


%sort the variance matrix from lowest to highest variance.

bwtclassvar    = sortrows(bwtclassvar, 2);


%define the threshold now.

switch isempty(bwtclassvar)
    
    case 0
        
        %the result reflects the modified otus algorithm.
        
        result = bwtclassvar(1,1);
        
        
    case 1
        
        %the result reflects the median of the pixel range.
        
        result  = median(pxrange);
        
        
end;




end