function runtimeSTATS()

%this function will evaluate any runtime statistics for a completed
%directory upon user request.




figure('Name', 'Runtime Statistics', 'Units', 'normalized', ...
    'Position', [0 0 1 1], 'MenuBar', 'none', 'NumberTitle', 'off');


%task 1: ask the user to select a completed directory at this time.

directory = uigetdir;


%change current directory to the one chosen by the user.

cd(directory);


%task 2: determine if the main data file and runtime statistics files exist

DATAexist    = exist('DATA_MAT.mat', 'file');

RUNTIMEexist = exist('TIME_EFF.mat', 'file');



switch DATAexist*RUNTIMEexist
    
    
    %one or both data files do not exist.  
    
    case 0
        
        
        %if the the rootscan data file does not exist then warn the user.
        
        switch DATAexist
            
            case 0
                
        
      warndlg('You have no aggregate rootscan data.', 'Data Files Missing');
      
        end;
        
        
        %if the the runtime data file does not exist then warn the user.
        
        switch RUNTIMEexist
            
            case 0
                
        
      warndlg('You have no runtime data.', 'Data Files Missing');
      
        end;
        
     
   
    %Both datasets exist procede with the analysis
      
    case 4
        
        
        %read in the data files now.
        
        DATA    = load('DATA_MAT.mat');
        RTstats = load('TIME_EFF.mat');
       
        DATA    = DATA.DATA_MATRIX;
        
        RTstats = RTstats.TIME_EFF;
        
        
        
       %convert these data matrices from cell format to double precision.
       
       
       %load the calibration values.
       
       calib = load('CALIB_MAT');
       calib = mean(calib.calibprecis(1:2));
       
       
       %define the number of columns in the cell matrix.
       
       numcol = size(DATA,2);
       
       DATAstats = cell2mat(DATA(:,3:(numcol-1)))*calib^2;
       
       RTstats                = cell2mat(RTstats);
       
       

        
       %define the image axis layout for the different statistical plots
       %used in the runtime analysis section of rootscan.
        
       pieAXES       = axes('Position', [0 .1 1 .8]);
        
       phaseDistAXES  = axes('Position', [.05 .64 .65 .3]);
        
       mainAXES   = axes('Position', [.05 .1 .65  .4]);
        
        
       %---major panel---% 
       
       %define the major panel for the different variable and visualization options.
        
       majorPanel = uipanel('Position', [.72 .05 .25 .9]);
        
       
       %define dropdown menus for major panel.
       
       majorButtons = uicontrol('Parent', majorPanel, 'Style', 'popupmenu', ...
           'Units', 'normalized', 'Position', [0 .485 1 .1], 'CallBack', @majorcompare);
       
       majorStrings = {'RXSA vs. Phase I'; 'RXSA vs. Phase II'; 'RXSA vs. Phase III'};
       
       set(majorButtons, 'String', majorStrings);
       
       

       
       
       %plot the default plot now.
       
       set(gcf, 'CurrentAxes', mainAXES);
       
       t                  = RTstats(:,1);
       x                = DATAstats(:,4);
           
       
                        plot(x, t, '.r');
                 xlabel('RXSA (pixels)');
           ylabel('Phase I Runtime (s)');
       title('Phase I Runtime vs. RXSA');
       
       
       
       %calculate the correlation coeficient.
       
       R = corrcoef(x, t);
       R         = R(2,1);
       
       
 
       
       
       
       %define text boxes for R-val.
       
       RValtext = uicontrol('Parent', majorPanel, 'Style', 'text', ...
           'Units', 'normalized', 'Position', [.015 .45 .8 .075], ...
           'String', strcat('R-Value: ', num2str(R)), 'HorizontalAlignment', ...
           'left');
       
         
       
       %define text boxes showing possible projections for a typical
       %directory.
       
       uicontrol('Parent', majorPanel, 'Style', 'text', ...
        'Units', 'normalized', 'Position', [.015 .3 .95 .075], ...
        'String', 'Runtime Projections for a Typical Image' , ...
        'HorizontalAlignment', 'left', 'FontWeight', 'bold');
       
       uicontrol('Parent', majorPanel, 'Style', 'text', ...
        'Units', 'normalized', 'Position', [.015 .25 .9 .075], ...
        'String', '                   Best Case               Worst Case' , ...
        'HorizontalAlignment', 'left', 'FontWeight', 'bold');
       
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
           'Position', [.015 .2 .3 .075], 'String', 'Phase I', 'HorizontalAlignment', ...
            'left', 'FontWeight', 'bold');
       
       
        %phase 1 projects.
        
        phase1med = median(RTstats(:,1));
        phase1std    = std(RTstats(:,1));        
        
        %best case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.25 .2 .2 .075], 'String', ...
            strcat(num2str(ceil(phase1med - phase1std)), ' (s)'));
        

        %worst case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.7 .2 .2 .075], 'String', strcat(num2str(ceil(phase1med + phase1std)), ' (s)'));       
       
        
        %phase 2 projects.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
           'Position', [.015 .15 .3 .075], 'String', 'Phase II', 'FontWeight', 'bold', ...
           'HorizontalAlignment', 'left');
        
        
        phase2med = median(RTstats(:,2));
        phase2std    = std(RTstats(:,2));
        
        %best case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.25 .15 .2 .075], 'String', ...
            strcat(num2str(ceil(phase2med - phase2std)), ' (s)'));
        

        %worst case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.7 .15 .2 .075], 'String', ...
            strcat(num2str(ceil(phase2med + phase2std)), ' (s)'));          
        
        
        
       %phase 3 projects.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
           'Position', [.015 .1 .3 .075], 'String', 'Phase III', 'FontWeight', 'bold', ...
           'HorizontalAlignment', 'left');
        
        
        phase3med = median(sum(RTstats(:,3:end), 2));
        phase3std    = std(sum(RTstats(:,3:end), 2));
        
        %best case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.25 .1 .2 .075], 'String', ...
            strcat(num2str(ceil(phase3med - phase3std)), ' (s)'));
        

        %worst case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.7 .1 .2 .075], 'String', ...
            strcat(num2str(ceil(phase3med + phase3std)), ' (s)'));  
        
        
        %total runtime required per image for typical directory.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
           'Position', [.015 .035 .3 .075], 'String', 'Total', 'FontWeight', 'bold', ...
           'HorizontalAlignment', 'left');
        
        bestcase  = (phase1med + phase2med + phase3med) - (phase1std + phase2std + phase3std);
        worstcase = (phase1med + phase2med + phase3med) + (phase1std + phase2std + phase3std);

        
        %best case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.25 .035 .2 .075], 'String', ...
            strcat(num2str(ceil(bestcase)), ' (s)'));
        

        %worst case.
        
       uicontrol('Parent', majorPanel, 'Style', 'text', 'Units', 'normalized', ...
            'Position', [.7 .035 .2 .075], 'String', ...
            strcat(num2str(ceil(worstcase)), ' (s)'));        
        
        
       %---breakdown panel---%
       
       RTbreakdownPanel = uipanel('Parent', majorPanel, 'Position', [0 .585 1 .415]');
       set(pieAXES, 'Parent', RTbreakdownPanel);
       
       
       %RTbreakdownPanel = uipanel('Position', [.45 .63 .25 .35]');
       %set(pieAXES, 'Parent', RTbreakdownPanel);
       
        
       %define buttons and other interactive objects for breakdown panel.
        
       piechartButton = uicontrol('Parent', RTbreakdownPanel, 'Style', 'popupmenu', ...
           'Units', 'normalized', 'Position', [0 0 1 .1], 'String', {'Runtime Breakdown: Interactive Steps'; ...
           'RunTime Break Down: Phase'}, 'CallBack', @changePie);
        
        
        
        
       %pie chart data calculations here.
        
        
        
       %calculate the median time spent on the each step (phases I and III) for all images.
        
       medianRT         = median(RTstats, 1);
        
       medianRTAct = medianRT([1 3 5 8 9]);
        
       RTlabel = {'X-section: '; 'LA: '; ...
           'Stele: '; 'Lacunae: '; 'Xylem Vessels: '};
        
       
       RTphaseLabel = {'Phase I: '; 'Phase II: '; 'Phase III: '};
        
       %calculate the median time spent on each phase
        
       phase12RT           = median(RTstats(:,[1 2]));
       phase3RT = median(sum(RTstats(:,[3 5 8 9]),2));
        
        
       
       %show pie chart in the top-left corner of the figure window.
       
       
                  set(gcf, 'CurrentAxes', pieAXES);
       piechart                 = pie(medianRTAct);
                                      colormap hot;
        
        
       textobj = findobj(piechart, 'Type', 'text');
       textstring       = get(textobj, {'String'});
                  
       newstring     = strcat(RTlabel, textstring);
                  
       oldpos = get(textobj, {'Position'});
       oldpos = cat(1, oldpos{:});
       [theta, rho] = cart2pol(oldpos(:,1), oldpos(:,2));
       
       rho = rho + .15;
       [oldpos(:,1), oldpos(:,2)] = pol2cart(theta, rho);
       
       set(textobj, {'Position'}, num2cell(oldpos, [3, 2]));
       
               set(textobj, {'String'}, newstring);
        
        
               
       %caculate the distribution of runtime statistics by phase in the
       %top-middle axes.
       
       %calculate the mean and std deviations of the runtime statistics by
       %phase.
       
       phaseImean                  = mean(RTstats(:,1));
       phaseIstd                    = std(RTstats(:,1));
       
       phaseIImean                 = mean(RTstats(:,2));
       phaseIIstd                   = std(RTstats(:,2));
       
       phaseIIImean = sum(mean(RTstats(:,[3 5 8 9]),1));
       phaseIIIstd    = sum(std(RTstats(:,[3 5 8 9]),1));
        
       
       timevect = 0:1:1.5*max([phaseImean phaseIImean phaseIIImean]);
       
       
       phaseInorm         = (1/(phaseIstd*sqrt(2*pi)))*exp(-(timevect - phaseImean).^2/(2*phaseIstd^2));
       phaseIInorm     = (1/(phaseIIstd*sqrt(2*pi)))*exp(-(timevect - phaseIImean).^2/(2*phaseIIstd^2));
       phaseIIInorm = (1/(phaseIIIstd*sqrt(2*pi)))*exp(-(timevect - phaseIIImean).^2/(2*phaseIIIstd^2));
       
       
       set(gcf, 'CurrentAxes', phaseDistAXES);
       plot(timevect, phaseInorm, 'r', 'LineWidth', 3), hold on;
       plot(timevect, phaseIInorm, 'g', 'LineWidth', 3);
       plot(timevect, phaseIIInorm, 'b', 'LineWidth', 3), hold off;
       xlabel('Time (s)');
       ylabel('Frequency');
       title('Distribution of Runtimes by Phase');
       
       legend('Phase I', 'Phase II', 'Phase III');
       
       
       
       
        
end;



        
        
        
        
        
    function changePie(varargin)
        
        %set current axes to pieAXES.
        
        set(gcf, 'CurrentAxes', pieAXES);
        
        %change the variables listed in the pie chart axes.        
        
        pieVal = get(piechartButton, 'Value');
        
        switch pieVal
            
            case 1
                
                             set(gcf, 'CurrentAxes', pieAXES);
                                  piechart = pie(medianRTAct);
                                                 colormap hot; 
                       
                textobj   = findobj(piechart, 'Type', 'text');
                textstring         = get(textobj, {'String'});
            	newstring       = strcat(RTlabel, textstring);
                          set(textobj, {'String'}, newstring);
                                      
                  
       oldpos = get(textobj, {'Position'});
       oldpos = cat(1, oldpos{:});
       [theta, rho] = cart2pol(oldpos(:,1), oldpos(:,2));
       
       rho = rho + .15;
       [oldpos(:,1), oldpos(:,2)] = pol2cart(theta, rho);
       
       set(textobj, {'Position'}, num2cell(oldpos, [3, 2]));
       
                          
                          
                          
                          
               
                
            case 2
                
                
                                         set(gcf, 'CurrentAxes', pieAXES);
                piechart                      = pie([phase12RT phase3RT]);
                                                             colormap hot;                    
                
                                           
                textobj               = findobj(piechart, 'Type', 'text');
                textstring                     = get(textobj, {'String'});
                newstring              = strcat(RTphaseLabel, textstring);
                                      set(textobj, {'String'}, newstring);
                
                
        end;
        
        
        
        
        
        
    end
        
        
        
    function majorcompare(varargin)
        
        
       %set current axes to main axes.
       
       set(gcf, 'CurrentAxes', mainAXES);
        
       %get current value from dropdown menu.
       
       val = get(majorButtons, 'Value');
       
       switch val
           
                
           
           case 1 %Phase I vs. RXSA
               
                t   = RTstats(:,1);
                x = DATAstats(:,4);
           
                  plot(x, t, '.r');
           xlabel('RXSA (pixels)');
     ylabel('Phase I Runtime (s)');
 title('Phase I Runtime vs. RXSA');
               
               
                
               
           case 2 %Phase II vs. RXSA
               
                t   = RTstats(:,2);
                x = DATAstats(:,4);
           
                  plot(x, t, '.g');
           xlabel('RXSA (pixels)');
     ylabel('Phase II Runtime (s)');
 title('Phase II Runtime vs. RXSA');
               
                
               
           case 3 %Phase III vs. RXSA
               
             
                t  = sum(RTstats(:,3:end),2);
                x           = DATAstats(:,4);
           
                            plot(x, t, '.b');
                     xlabel('RXSA (pixels)');
               ylabel('Phase III Runtime (s)');
           title('Phase III Runtime vs. RXSA');
               
               
               
       end;
      
       
       
       %calculate the correlation coeficient.
       
       R = corrcoef(x, t);
       R = R(2,1);
       
       set(RValtext, 'String', strcat('R_value: ', num2str(R)));
 
       
  
    
        
        
        
        
        
        
        
        
        
        
        
        
        
    end




end