function segment_xs(starting_iteration, num_of_images, program_mode)

%this function drives the batch analysis process for the x-section
%segmentation phase in the rootscan analysis.  during this phase the root
%scan will perform the automatic x-section detection and the user will
%interact with the cross-section during the manual x-section seletect
%process.  these steps will be performed for all images in a particular
%image directory.

global         data_matrix; %data matrix.
global        f_fig_handle; %GUI handles.
global       AllImageSpecs; %image specifications.
global            DirSpecs; %current directory.
global     time_efficiency; %time efficiency matrix.
global           iteration; %current iteration.
global                img1; %raw image.
global           imageSize; %image size.
global          imagePerim; %perimeter images.
global        solidSegment; %x-section result (binary).
global x_section_reference; %raw image containing highlighted xs perimeter.
global             finalIM; %x-section result (grayscale).





%define dummy global image for raw image.

img1 = imread(data_matrix{1,1}); 


%define global image size
    
imageSize = size(img1);


%define dummy global image for perimeter image, highlighted x-section perimeter image,
%and x-section result (grayscale).

imagePerim                             = logical(img1);

x_section_reference = ones([imageSize 3], 'uint8')*255;    

finalIM                 = ones(imageSize, 'uint8')*255;



%solidSegment image (this variable name is used even though we are going to
%use a solid x-section).  reason: this phase 1 and phase 3 (stele
%segmentation) steps use the same function using this variable as global to
%reduce memory usage.
    
solidSegment = imagePerim;       




%highlight the current phase.

set(f_fig_handle.status(1), 'BackgroundColor', [0 1 .3]);





%run the batch process if the number of images is equal to 1 or the current
%batch iteration is less than the number of images in a directory.

if ((starting_iteration <= num_of_images) || (num_of_images == 1))  
  
    
%make the current main image axes visible now.

set(f_fig_handle.im_axes(1), 'Visible', 'on');
    
    
%run the batch processing for xs segmentation step for all images in a 
%particular directory.    

for iteration = starting_iteration:num_of_images
    
    %start the clock 
    
    tic;



    %read in the image.
    
    img1 = imread(data_matrix{iteration,1}); 
     
    
    %compare the standard image size with the size of the current image to
    %determine if our standard size needs to change.  this case should not
    %happen that often since the image dimensions should not be dynamic for
    %a particular directory.
    
    sizecomp = size(img1) - size(x_section_reference(:,:,1));
    
    
    switch max(abs(sizecomp)) == 0
    
        
        case 0 %change the standard images and their sizes.
            
            x_section_reference = ones([size(img1) 3], 'uint8');
            imagePerim           = logical(x_section_reference);
            imageSize                        = size(imagePerim);  
            
    end;
    
    
    %define image containing grayscale and highlighted xs perimeter.
    
    %assign pixels to red channel.
    
    x_section_reference(:,:,1) = img1; 
    
    
    %assign pixels to green channel.
    
    x_section_reference(:,:,2) = img1; 
    
    
    %assign pixels to blue channel.
    
    x_section_reference(:,:,3) = img1; 
    
    
    %define name of image and set name in GUI display panel.
    
    image_name =   data_matrix{iteration,1};
    
    
    %display image name.

    set(f_fig_handle.image_vars(1), 'String', image_name); 
    
    
    %determine the image format.
    
    
    %total name including format.
    
    AllImageSpecs.format = DirSpecs.directory(iteration).name; 
    
    
    %find indice of last period in name.
    
    findi          = find(AllImageSpecs.format == '.', 1, 'last'); 
    
    
    %truncate image name (only the format should be left in the name).
    
    AllImageSpecs.format(1:findi)                            = []; 
   

   

    %step 1: auto-segmentation: x-section segmentation. output test
    %results.  these results will be used to determine if the user has to
    %interact with the xs as result of poor automatic segmentation.  NOte:
    %the test results need some refining so do not worry about the results
    %nor the code at this time.
    
    testResult = auto_x_section;    
    

    
    switch ((AllImageSpecs.automated_settings(1)*AllImageSpecs.automated_settings(end) == 0) | ...
            (testResult == 1)) 
        
        
        %execute manual x-section segmentation step if the automated settings are turned off.
    
        case 1
        
        %step 2: manual-segmentation: x-section segmentation.
        
        manual_segmentation; 
    

    end;
    
        
    
    
    
    %write the data results and images to data files.
    
    writeData(image_name, iteration);
    
    
    
    %calculate the number of images remaining.
        
    num_remain = num_of_images - iteration;
    
    
    %display this result in the GUI.
    
    set(f_fig_handle.status(4), 'String', [num2str(num_remain) ' Images Remaining' ]);
    
    
    %display the percent completed.
    
    set(f_fig_handle.status(5), 'String', [num2str((100*iteration/num_of_images), '%3.0f\t') ' % Complete']);
    
 
    
        %save all data matrices if we are directory mode.
        
        switch program_mode
            
            case -2 %we are in directory mode.
            
                
            %save the current updated data matrix.
                    
            save('DATA_MAT', 'data_matrix');  
            
            
            %save time efficiency parameters to matrix. stop the clock and 
            %record time.
            
            time_efficiency{iteration, 1} = toc; 
            
            save('time_efficiency', 'time_efficiency');
            
            
        
        end;
    
%clear command line of any output.

clc; 

        
end;  
    


end;    



end