function cortexData = select_aerenchyma(cortexData, L4)

%this function allows the user to actively select or deselect any cortical
%objects on the basis of them being qualified as aerenchyma or not.


global     ref_axes_obj; %reference axes handle.
global    get_ref_cdata; %reference axes cdata.
global    ref_lat_stele; %reference image for stele + lateral.
global    main_axes_obj; %main axes handle.
global     f_fig_handle; %structure containg all figure children and properties.
global    AllImageSpecs; %structure containing all image specifications.
global highlight_cortex; %label matrix for cortical objects.



%set the right axis to the current axes and display the original cross-section
%image for references purposes only.
           
set(ref_axes_obj, 'Cdata', get_ref_cdata);  


%get the current cdata from the reference image.  this image should contain
%the highlighted perimeters for the x-section, lateral (if present) and
%stele.

get_ref_cdata    = get(ref_axes_obj, 'Cdata');
           

%clear highlighted image from axes.
               
set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1)); 
cla;  
               
               
%initialize the image figure used for the interactive aerenchyma selection.
               
main_axes_obj = imshow(highlight_cortex); colormap(hot);  
 

%get the cdata from main axes.  this will be the initial highlighted
%aerenchyma image.

get_main_cdata = get(main_axes_obj, 'Cdata');
   

%set the current windowbuttondown function for the interactive aerenchyma
%selection process.  when the user clicks inside the image axes on the
%current highlighted aerenchyma image.  they can select cortical objects.

set(gcf, 'WindowButtonDownFcn', @buttondownSEL);
   

%continue to select and de-select cortex objects until user
%decides they are satisfied.
                  
waitfor(f_fig_handle.done_buttons(1), 'value', 1);
               
               

%------------------------end of this gui operation.-----------------------%

   


%buttondown function callback function.  this function executes when users
%click over a cortex object.


function buttondownSEL(varargin)
        
        
    get_point = round(get(gca, 'CurrentPoint'));  
                
               
    %CONVERT THE ObjCol AND ObjRow COORDINATES TO IMAGE COORDINATES.
               
	ObjCol = get_point(1,1);  
	ObjRow = get_point(1,2);  
                
                

	%the proceeding if/else statements decide whether to select and
    %de-select objects based on where the user clicks.
                 
                                                                   
    %the user selected background pixels.  action: deselect only 12 
    %objects per click.
    
    CortexObj = L4(ObjRow,ObjCol);
    
    switch CortexObj > 0
    
        case 0
             
            switch CortexObj == -1
                
                case 1
            
                %find data for all cortex object pixels currently labeled aerenchyma.
                   
                find_lacunae_objs = cortexData(cortexData(:,10) == 2, :);
                     
                   
                %if there more than 15 but less than 50 objects currently  selected. de-select
                %only 5 per click.    

                if (size(find_lacunae_objs,1) >= 5)   
                                                                                                     
                                
                    for OI = 1:5 %deselect the 5 smallest cortex objects.
                                    
                        %change object pixel values to 255 in the highlighted
                        %cortical image shown in the main image axes.
                               
                        get_main_cdata(L4 == find_lacunae_objs(OI,2))   = 255;
                            
                        highlight_cortex(L4 == find_lacunae_objs(OI,2)) = 255;
                    
                
                        %remove the highlight from the reference image.
                
                        index_ref = find(L4 == find_lacunae_objs(OI,2));
               
                
                        %red channel.     
                
                        get_ref_cdata(index_ref)   = ...
                            ref_lat_stele(index_ref); 
                
                
                        %green channel. 
                
                        get_ref_cdata(AllImageSpecs.tot_dim_pixels + index_ref) = ...
                            ref_lat_stele(AllImageSpecs.tot_dim_pixels + index_ref); 
                
                
                        %blue channel.
                
                        get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index_ref)  = ...
                            ref_lat_stele(2*(AllImageSpecs.tot_dim_pixels) + index_ref);                            
                            
                            
                        %assign tag to the object properties matrix.        
                                    
                        cortexData(cortexData(:,2) == find_lacunae_objs(OI,2),10) = 0; 
                
                    end;                                
                                
       
                    %there are less than 5 objects currently highlighted. 
                    %de-select one per click.
                    
                else 
              
            
                %de-select (un-highlightaeren) all currently highlighted cortex objects.  
                        
                get_main_cdata(highlight_cortex == AllImageSpecs.highlightCode(1))   = 255;
                            
                highlight_cortex(highlight_cortex == AllImageSpecs.highlightCode(1)) = 255;
               
             
                %reset the reference image to reference image containing only
                %the highlighted perimeters.
             
                get_ref_cdata                             = ref_lat_stele;
                            

                %assign tag to the object properties matrix.
                        
                cortexData(:,10)                                      = 0;  
                            
                                
                end;
                            
            end;   
                   
                    
        case 1  
              
                       
                   

        switch (get_main_cdata(ObjRow,ObjCol) == 255)
      
            case 1
        
                %select object previously mis-classified as a cortex cell.

                get_main_cdata(L4 == CortexObj)   = AllImageSpecs.highlightCode(1);

                highlight_cortex(L4 == CortexObj) = AllImageSpecs.highlightCode(1);


                %highlight current cortical object.

                index_ref = find(L4 == CortexObj);


                %red channel.

                get_ref_cdata(index_ref)                                    ...
                    = AllImageSpecs.refColors(1,1);


                %green channel.

                get_ref_cdata(AllImageSpecs.tot_dim_pixels + index_ref)     ...
                    = AllImageSpecs.refColors(1,2);


                %blue channel.

                get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index_ref) ...
                    = AllImageSpecs.refColors(1,3);                     


                %assign tag to the object properties matrix.

                cortexData(cortexData(:,2) == CortexObj, 10) = 2;  
                       
                    
                    
            %falsely selected objects must be de-selected.  
                 
            case 0
            
            
                %de-select object mis-classified as aerenchyma.

                get_main_cdata(L4 == CortexObj)   = 255;  

                highlight_cortex(L4 == CortexObj) = 255;  


                %remove highlight from the reference image.

                index_ref = find(L4 == CortexObj);


                %red channel.

                get_ref_cdata(index_ref)                                    ...
                    = ref_lat_stele(index_ref);


                %green channel.

                get_ref_cdata(AllImageSpecs.tot_dim_pixels + index_ref)     ...
                    = ref_lat_stele(AllImageSpecs.tot_dim_pixels + index_ref);


                %blue channel.

                get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index_ref) ...
                    = ref_lat_stele(2*(AllImageSpecs.tot_dim_pixels) + index_ref);   


                %assign tag to the object properties matrix.

                cortexData(cortexData(:,2) == CortexObj, 10) = 0;  
                                
                                                     
        end;
               
    end;

    
    
    %apply display changes to GUI image.
               
	set(main_axes_obj, 'Cdata', get_main_cdata);
  
            
	%apply display changes to the reference image.
            
	set(ref_axes_obj, 'Cdata', get_ref_cdata);    

    
    
end


end