function [dir_name, mode_2] = select_directory
        
  
global AllImageSpecs;

%this function selects a directory for batch analysis, evaluates the status 
%of the directory returns data specifications to the data_and_display function
%prior to accessing and analyzing images.
     
%this parameter tells the while loop when to terminate. set to zero initially.

display_condition = 0; 



%continue to display interactive directory selection window until the batch
%parameter equals 1.             

while (display_condition == 0) 
         
                   
    %select the batch analysis directory from interactive window.
    
	dir_name = uigetdir;   
             
                                         
	%check the current directory to verify that user is not in any sub-directory.

    result = checkDir(dir_name);   
        
    if result == 1
            
    	dir_name = uigetdir;
            
    end;
     
   
   
   
    
    %check to see if the image negatives exist.
    
    NegativesExist        = exist([dir_name AllImageSpecs.fileSeparator ...
        'Negatives'], 'dir');
    
    
    
    switch NegativesExist
        
        case 7
            
            dir_name = [dir_name AllImageSpecs.fileSeparator 'Negatives'];  

    end;
        
    
    cd(dir_name);

    

    %if the user cancels ask them if they are sure they want to quit batch 
    %analysis on the current directory.
                    
	if (sum(dir_name) == 0) 
                    
                                                   
        %open question dialog box and ask the question.                            
                         
        question = 'Are you sure you want to exit batch analysis mode?';
        choice = questdlg(question, 'Yes', 'No');  
        
        
        %switch statement is used to make decision to continue or cancel the
        %current batch directory selection.     
                           
        switch choice  
                        
        	case {'Yes'} %they want to exit batch analysis directory selection mode.
            
            %halt directory selection process.
                                                          
            display_condition = 1; 
                            
            case {'No'}  %they want to select another directory.
            
                
            %continue selecting a directory.  batch remains zero.  
            
            display_condition = 0;  
                            
        end;
                   
                    
                    
	else  %a directory was selected.  terminate 'while' control statement
          %and proceed to accessing data settings.
                     
    	display_condition = 1;                                        
                    
	end;
                    
end;
               
 
    
   
    
    
    
    
%if the user selects a directory then proceed to the aquisistion of data specifications.   
    
    

if (sum(dir_name) ~= 0) %continue only if there is a directory selected.
                
                
    %determine if data specification files exist in the current image directory.
           

    %go to the selected batch analysis directory

    cd(dir_name); 
                
                    
    %determine if the data settings file: INTERVAL_MAT.mat is contained
    %in the current batch directory. 
                    
    file_check = dir('DATA_MAT.mat');  
   
    
    
    %find main programs directory define the main programs directory path. 
    
    pathway_main                                     = which('select_directory.m'); 
    find_last_break = find(pathway_main == AllImageSpecs.fileSeparator, 1, 'last'); 
    pathway_main                                 = pathway_main(1:find_last_break); 
    

    
    switch numel(file_check)
                    
    	case 1 %this is an old directory. just access the data specs
               %file in the current image directory.
                        
                            
            %grab the data specs files and place them in their
            %appropriate structures.

            %-----------------------------------------------------------------%
            %---------adquire the calibration and precision settings----------%
            %-----------------------------------------------------------------%    

            calib_vals                                                   = load('CALIB_MAT.mat'); 

            AllImageSpecs.calib_area      = calib_vals.calibprecis(1).*calib_vals.calibprecis(2);

            AllImageSpecs.calib_length = (calib_vals.calibprecis(1)+calib_vals.calibprecis(2))/2;

            AllImageSpecs.precision                                  = calib_vals.calibprecis(3); 


            %-----------------------------------------------------------------%  
            %------------adquire cortex region interval settings--------------%
            %-----------------------------------------------------------------%

            %load the cortex region intervals saved in the current image directory.

            regionvals            = struct2cell(load('INTERVAL_MAT.mat'));


            %define interval and tags place them in a structure.

            AllImageSpecs.bands_intervals = [0 regionvals{1,1}{1,:}{1,:}];

            AllImageSpecs.bands_colors    = [0 regionvals{1,1}{1,:}{2,:}];  


            %data matrices exist, they must be accessed in the main program at the start. 

            mode_2 = 5; 
                         

            %load in the automated settings. these will determine what steps the user
            %wants to automate.

            %check to see if automated settings file exists

            switch exist('AUTOMATED_SETTINGS.mat', 'file') %yes, it does. use previous settings.


                case 2 %the file exists. use the settings.

                    automated_settings                = struct2cell(load('AUTOMATED_SETTINGS.mat'));
                    AllImageSpecs.automated_settings                      = automated_settings{1,1};


                case 0 %allow user to define these settings and then load them.

                                                                              automated_options;
                    automated_settings = struct2cell(load([pathway_main 'AUTOMATED_SETTINGS.mat']));
                    AllImageSpecs.automated_settings                      = automated_settings{1,1};


            end;
        
        
        
        
        %this is a new directory.  take action.  grab the data specs files, 
        %copy them to the current image directory.
               
        case 0 
                
                  
            %-----------------------------------------------------------------%
            %----------adquire the calibration and precision settings---------%
            %-----------------------------------------------------------------%

            %load the calibration file.
                                               
           calib_vals                                    = load([pathway_main 'CALIB_MAT.mat']);

           AllImageSpecs.calib_area      = calib_vals.calibprecis(1).*calib_vals.calibprecis(2);

           AllImageSpecs.calib_length = (calib_vals.calibprecis(1)+calib_vals.calibprecis(2))/2; 

           AllImageSpecs.precision                                  = calib_vals.calibprecis(3); 


           %--------------------------------------------------------------%  
           %-----------adquire cortex region interval settings------------%
           %--------------------------------------------------------------%

           
           %load the cortex region intervals saved in the current image directory.

           regionvals = load([pathway_main 'INTERVAL_MAT.mat']); %--S1--
           regionvals                 = struct2cell(regionvals); %--S1-- 
                                
                                
           %define interval and tags place them in a structure.

           AllImageSpecs.bands_intervals = [0 regionvals{1,1}{1,:}{1,:}]; 

           AllImageSpecs.bands_colors    = [0 regionvals{1,1}{1,:}{2,:}];




           %load in the automated settings. these will determine what steps the user
           %wants to automate.

           %check to see if automated settings file exists

           switch exist([pathway_main 'AUTOMATED_SETTINGS.mat'], 'file')


               case 2 %the file exist. use the settings.

                   automated_settings = struct2cell(load([pathway_main 'AUTOMATED_SETTINGS.mat']));
                   AllImageSpecs.automated_settings                      = automated_settings{1,1};


               case 0 %allow user to define these settings and then load them.

                                                                                 automated_options;
                   automated_settings = struct2cell(load([pathway_main 'AUTOMATED_SETTINGS.mat']));
                   AllImageSpecs.automated_settings                      = automated_settings{1,1};


           end;


           %place the data specs files in the current batch analysis directory.

                 copyfile([pathway_main 'INTERVAL_MAT.mat'], dir_name);  
                    copyfile([pathway_main 'CALIB_MAT.mat'], dir_name);  
                 copyfile([pathway_main 'threshMethod.mat'], dir_name);
           copyfile([pathway_main 'AUTOMATED_SETTINGS.mat'], dir_name);   

           
           %make subdirectories now.  the temp subdirectory will hold all
           %temporary image files. the X_section_segments subdirectory will
           %contain all images results from the X-section segmentation step
           %that will be used later in the program.  the X_section_binary
           %subdirectory will contain all images producd in the image 
           %binarization algorithm that will be used later in the program.
           %the Image_Output subdirectory will contain all output images
           %from the analysis.


            %make temp image directory if it does not exist in the current image directory.          

            switch exist('temp', 'dir')

                case 0

                    mkdir(dir_name, 'temp');  

            end;


            %make X_section_segments directory if it does not exist in the current
            %image directory.

            switch exist('X_section_segments', 'dir')

                case 0

                    mkdir(dir_name, 'X_section_segments');

            end;


            %make X_section_binary directory if it does not exist in the current
            %image directory.

            switch exist('X_section_binary', 'dir')

                case 0

                    mkdir(dir_name, 'X_section_binary');

            end;


            %make Image_Output directory if it does not exist in the current image
            %directory.

            switch exist('Image_Output', 'dir')

                case 0

                    mkdir(dir_name, 'Image_Output');

            end;
            
               
               
           %no data matrices defined yet they must be defined in the main
           %program at the start.

           mode_2 = 4;  
                   
                                    
    end;
  
    
%no directory selected. return no variables.    
                        
else 
       
    %set the directory name and mode to dummy values.
    dir_name   = 0;
    mode_2   = -111;

                
                
end;
                
                
                
                
                
end  