function [image_name, dir_name] = select_image

%this function selects a single image for a quick analysis and loads the
%specification that  rootscan uses during the analysis of the that
%individual image.


global AllImageSpecs; %image specifications.



%find main programs directory.

pathway_main = which('select_image.m'); 



%define the main programs directory path.

find_last_break = find(pathway_main == AllImageSpecs.fileSeparator, 1, 'last'); 
pathway_main                                 = pathway_main(1:find_last_break); 
                               

                                
%-------------------------------------------------------------------------%
%-------------adquire the calibration and precision settings--------------%
%-------------------------------------------------------------------------%
             

%load the calibration file.  this file contains the image calibration and 
%data precision settings.
                                
calib_vals =   load([pathway_main 'CALIB_MAT.mat']); %--S1-- 
                                
                          
%place the calibration value and precision value in the image specifications structure.

AllImageSpecs.calib_area      = calib_vals.calibprecis(1).*calib_vals.calibprecis(2);
                        
AllImageSpecs.calib_length = (calib_vals.calibprecis(1)+calib_vals.calibprecis(2))/2;

AllImageSpecs.precision                                  = calib_vals.calibprecis(3); 

                         

%-------------------------------------------------------------------------% 
%----------------ADQUIRE CORTEX REGION INTERVAL SETTINGS------------------%
%-------------------------------------------------------------------------%
                        
%load the cortex region settings.  these settings contain the bin sizes,
%labels and other information needed during and after the analysis.
                                
regionvals = load([pathway_main 'INTERVAL_MAT.mat']); 
regionvals                 = struct2cell(regionvals); 
                                
                                
%place these settings in data structures.
    
AllImageSpecs.bands_intervals = [0 regionvals{1,1}{1,:}{1,:}];  
                                
AllImageSpecs.bands_colors    = [0 regionvals{1,1}{1,:}{2,:}];  
                        


%load in the automated settings. these will determine what steps the user
%wants to automate.

%check to see if automated settings file exists

switch exist([pathway_main 'AUTOMATED_SETTINGS.mat'], 'file')

    
    case 2 %file exists. use the settings.
        
    automated_settings = struct2cell(load([pathway_main 'AUTOMATED_SETTINGS.mat']));
    AllImageSpecs.automated_settings                      = automated_settings{1,1};

    
    case 0 %allow user to define these settings and then load them.
    
                                                         AUTOMATED_OPTIONS;
    automated_settings = struct2cell(load([pathway_main 'AUTOMATED_SETTINGS.mat']));
    AllImageSpecs.automated_settings                      = automated_settings{1,1};
    
    
end;




%open image using an interval open file box.

image_formats = ['*.jpg; *.jpeg; *jp2; *.tif; *.tiff; *.gif'];
info = 'Select File for Quick Analysis';


%open files with formats: .jpg, .jpeg, .tif, .tiff, .gif.

[image_name, dir_name] = uigetfile(image_formats,info);  



%go to the parent directory of the selected file.

cd(dir_name);  



%check the current directory to verify that user is not in any
%sub-directory.

result = checkDir(dir_name);

while result == 1
    
    %open files with formats: .jpg, .jpeg, .tif, .tiff, .gif.

    [image_name, dir_name] = uigetfile(image_formats,info);  
    
end;






%make subdirectories now if they do not exist.  the TEMP subdirectory will hold all temporary
%image files. the X_section_segments subdirectory will contain all images
%results from the X-section segmentation step that will be used later in
%the program.  the X_section_binary subdirectory will contain all images
%producd in the image binarization algorithm that will be used later in the
%program.  the Image_Output subdirectory will contain all output images
%from the analysis.



    %make TEMP image directory if it does not exist in the current image directory.          
               
    switch exist('temp', 'dir')
    
        case 0

        mkdir(dir_name, 'temp');  
    
    
    end;

    
    %make X_section_segments directory if it does not exist in the current
    %image directory.

    switch exist('X_section_segments', 'dir')
    
        case 0
        
        mkdir(dir_name, 'X_section_segments');
    
    end;


    %make X_section_binary directory if it does not exist in the current
    %image directory.
    
    switch exist('X_section_binary', 'dir')
    
        case 0

        mkdir(dir_name, 'X_section_binary');
    
    end;


    %make Image_Output directory if it does not exist in the current image
    %directory.

    switch exist('Image_Output', 'dir')
    
        case 0

        mkdir(dir_name, 'Image_Output');

    end;
            

    

end