function set_calibration

%this function accomplishes two objectives.

%first objective:  define camera calibration settings.  how many image
%pixels placed in a line constitute a linear millimeter.

    
%second objective: define the data precision.  



global AllImageSpecs; %structure containing all image specifications.

global         hline; %interactive polyline.

hline = 0;



%define the current directory.

CD = cd;  


%load the current calibration settings....

%find the location of the calibration file.  this location is the main
%programs directory.

pathway =                 which('set_calibration.m'); 


%find the last forward or backslash.

find_last_break = find(pathway ==  AllImageSpecs.fileSeparator, 1, 'last'); 


%truncate the string after the last forward slash.

pathway =             pathway(1:find_last_break);  


%define the full path of the file.
   
pathway_file =         [pathway 'CALIB_MAT.mat'];  



%if the calibration file exists then define the calibration settings.

switch exist(pathway_file, 'file')  

    
    %if the calibration file exists. load in the current settings.
    
    case 2
        
    %load the file.
    
    calib_vals    = load(pathway_file); 
    
    
    %access structure field.
    
    calib_vals  = calib_vals.calibprecis;  

    
    %access calibration value (width).
    
    calib_1d  = calib_vals(1);  
    
    
    %access calibration value (height).
    
    calib_2d  = calib_vals(2);  
    
    
    
    %access the precision value.

    precis = calib_vals(3);  

          
    %if the calibration file does not exist in the root-scan program directory 
    %then define default calibration setings.
    
    case 0
       
     
   %default image pixel calibration setting:  1 linear mm = 295 linearly arranged pixels.  
     
   calib_1d  = '771'; 
     
   calib_2d = '771';
   
   %default data precision.
   
   precis   = '4'; 
   
   
end;
    

%interactive part of function..............


%initiate interactive GUI to receieve inputs from user.

calib_figure = figure('Name', 'Pixel Calibration and Data Precision Settings', ...
    'units', 'normalized', 'Position', [.05, .05, .9, .85], 'Color', [.8 .8 .5], ...
    'Menubar', 'none', 'Numbertitle', 'off');


%calibration menubar. user selects this menubar when they want to eithe
%select a calibration image file or redraw the interactive polyline.

calibsetMenu = uimenu('Parent', calib_figure, 'Label', 'Calibration Setting');


%define calibration menubar child so the user can select the appropriate
%calibration file.

uimenu('Parent', calibsetMenu, 'Label', 'Select Calibration File', ...
    'CallBack', @CallCalib);


%define calibration menubar child so the uesr can redraw any interactive
%polyline if they delete the initial one.

uimenu('Parent', calibsetMenu, 'Label', 'Measure Value', ...
    'CallBack', @CallDrawLine);




%build the GUI components now.





%build a uipanel to hold the calibration settings.

calibPanel = uipanel('Parent', calib_figure, 'Units', 'normalized', 'Position', ...
    [.76 .2 .22 .7], 'BackgroundColor', [.8 .8 .8]);



%build a uipanel to hold the precision settings.

precisPanel = uipanel('Parent', calib_figure, 'Units', 'normalized', 'Position', ...
    [.76 .1 .22 .1], 'BackgroundColor', [.8 .8 .8]);


%static text boxes to hold the field labels.


%define field label for the calibration value (pixel width) editable text box.

uicontrol('Parent', calibPanel, 'Style', 'text', 'units', 'normalized', ...
    'Position', [.1, .9, .88, .05], 'String',  ...
    'Calibration Value (pixel width)', 'Backgroundcolor', [.8 .8 .8], ...
    'HorizontalAlignment', 'right', 'FontUnits', 'normalized', 'FontSize', .6);


%define field label for the calibration value (pixel height) editable text box.

uicontrol('Parent', calibPanel, 'Style', 'text', 'units', 'normalized', ...
    'Position', [.1, .76, .88, .05], 'String',  ...
    'Calibration Value (pixel height)', 'Backgroundcolor', [.8 .8 .8], ...
    'HorizontalAlignment', 'right', 'FontUnits', 'normalized', 'FontSize', .6);



%define field label for the data precision value editable text box.

uicontrol('Parent', precisPanel, 'Style', 'text', 'units', 'normalized', ...
    'Position', [.48, .6, .5, .3], 'String',  ...
    'Data Precision', 'Backgroundcolor', [.8 .8 .8], ...
    'HorizontalAlignment', 'right', 'FontUnits', 'normalized', 'FontSize', .8);



%define editable text boxes for user input.


%define editable text box for the current calibration setting.

calibUI = uicontrol('Parent', calibPanel, 'Style', 'edit', 'units', 'normalized', ...
    'Position', [.8, .85, .18, .05], 'String',  calib_1d, 'Backgroundcolor', [1 1 1], ...
    'HorizontalAlignment', 'right');


%define editable text box for the current calibration setting.

calibUI2 = uicontrol('Parent', calibPanel, 'Style', 'edit', 'units', 'normalized', ...
    'Position', [.8, .71, .18, .05], 'String',  calib_2d, 'Backgroundcolor', [1 1 1], ...
    'HorizontalAlignment', 'right');


%define editable text box for the current precision settings.

precisUI = uicontrol('Parent', precisPanel, 'Style', 'edit', 'units', 'normalized', ...
    'Position', [.8, .1, .18, .4], 'String',  precis, 'Backgroundcolor', [1 1 1], ...
    'HorizontalAlignment', 'right');



%define image axes in GUI window.

calib_axes = axes('Parent', calib_figure, 'units', 'normalized', ...
    'Position', [.01 .03 .74, .94], 'Visible', 'off');



%define zoom in and zoom out pushbuttons.  


%define zoom in button for the image axes. when the user select this button
%rootscan will allow them to zoom in on the calibration image.

uicontrol('Parent', calibPanel, 'Style', 'PushButton', 'Units', 'normalized', ...
    'Position', [.02, .6, .5, .06], 'FontUnits', 'normalized', 'String', ...
    'Zoom In', 'FontUnits', 'normalized', 'FontSize', .6, 'CallBack', @zoomIn);


%define zoom out button for the image axes. when the user selects this
%button rootscan will allow them to zoom out on the calibration image.

uicontrol('Parent', calibPanel, 'Style', 'PushButton', 'Units', 'normalized', ...
    'Position', [.02, .5, .5, .06], 'FontUnits', 'normalized', 'String', ...
    'Zoom Out', 'FontUnits', 'normalized', 'FontSize', .6, 'CallBack', @zoomOut);


%define pan image button for the image axes. when the user selects this
%button rootscan will allow them to pan the image left/right/up/down as
%they see fit.

uicontrol('Parent', calibPanel, 'Style', 'PushButton', 'Units', 'normalized', ...
    'Position', [.02, .4, .5, .06], 'FontUnits', 'normalized', 'String', ...
    'Pan Image', 'FontUnits', 'normalized', 'FontSize', .6, 'CallBack', @panImage);


%%define measure value button.  when the user selects this button they can
%%resume dragging the interactie polyline initial drawn on the image by the
%%user.

uicontrol('Parent', calibPanel, 'Style', 'PushButton', 'Units', 'normalized', ...
    'Position', [.02, .3, .5, .06], 'FontUnits', 'normalized', 'String', ...
    'Measure Value', 'FontUnits', 'normalized', 'FontSize', .6, 'CallBack', @measureVal);



%define measure pixel height radio button. when user selects this button the
%other radiobutton will turn off and any dragging of the vertices will be
%applied to the radionbutton in focus.

calibRadio(1) = uicontrol('Parent', calibPanel, 'Style', 'Radiobutton', 'Units', 'normalized', ...
    'Position', [.03, .2, .42, .05], 'FontUnits', 'normalized', 'String', ...
    'Pixel Width', 'FontUnits', 'normalized', 'FontSize', .6, 'BackgroundColor', ...
    [.8 .8 .8]);


calibRadio(2) = uicontrol('Parent', calibPanel, 'Style', 'Radiobutton', 'Units', 'normalized', ...
    'Position', [.48, .2, .42, .05], 'FontUnits', 'normalized', 'String', ...
    'Pixel Height', 'FontUnits', 'normalized', 'FontSize', .6, 'BackgroundColor', ...
    [.8 .8 .8]);


set(calibRadio, 'Callback', @pixelRadioCallback);
set(calibRadio(1), 'Value', 1);

initialPixRadioVal = [1 0];


%define finished button. when the user selects this button they will save
%the current settings and terminate the window.

finishedAll = uicontrol('Parent', calib_figure, 'Style', 'RadioButton', 'Units', 'normalized', ...
    'Position', [.85, .025, .15, .05], 'FontUnits', 'normalized', 'String', ...
    'Finished', 'BackgroundColor', [.8 .8 .5], 'FontUnits', 'normalized', ...
    'Fontsize', .8);
  


%initiate a waitfor call that will not allow the program to proceed to the
%settings verification and file saving until the user presses the finished
%radiobutton.

waitfor(finishedAll, 'Value', 1);



%check the entries to see if they are of the correct data class.
      
CALIBans   = str2double(get(calibUI, 'String'));
      
CALIBans2   = str2double(get(calibUI2, 'String'));

PRECISans = str2double(get(precisUI, 'String'));
      
      
checkCalib   = ischar(CALIBans);

checkCalib2 = ischar(CALIBans2);

checkPrecis = ischar(PRECISans);
      
      
      
switch (checkCalib + checkPrecis + checkCalib2)
          
	case 0 %both data entries check out. 
             
        %save the data to file. 
            
        PRECISans = floor(PRECISans);
            
        calibprecis = [CALIBans CALIBans2 PRECISans];
            
        
        %go to the main programs directory.
        
        cd(pathway);
          
        
        %save the settings.
        
        save('CALIB_MAT', 'calibprecis');
                
         
        %return to the current directory.
        
        cd(CD);
            
            
            
            
end;
  

%delete the current figure. this will terminate the window and the user can
%resume verifying more settings or start using the main rootscan analysis
%tools.

delete(calib_figure);



%place callback for pixel width and height radiobuttons here.

    function pixelRadioCallback(varargin)
        
        %get current radiobutton values.
        
        currentRadioVals = cell2mat(get(calibRadio, 'Value'))';
        
        
        %define the difference of those values.
        
        diffval = currentRadioVals - initialPixRadioVal;
        
        
        %reset radiobuttons values.
        
        set(calibRadio(diffval ~= 1), 'Value', 0);
        
        
        %reset initial pixel radio button value vector.
        
        initialPixRadioVal = [1 1];
        initialPixRadioVal(diffval ~= 1) = 0;
        
        
    end







    %push button callback for when user pushes button.  this function will
    %allow the user to select the calibration image and measure the calibration setting 
    %directly.

    function CallCalib(varargin)
        
        
        %clear the current axes.
        
        set(gcf, 'CurrentAxes', calib_axes);

        cla;
        
        
        %ask the user to select the image for direct calibration
        %measuremnt.
        
        [filename, path] = uigetfile('*');
        
        
        %read in the file.
        
        switch sum(filename) == 0
            
            case 0
        
                image = imread([path filename]);
        
        
                %display the image in the axes.
        
                imshow(image);
                
                
                %allow user to draw line.
                
                hline = imline(calib_axes);
        
                
                %set the window button down function to startMeasure.  when
                %the user drags the interactive line the calibration value
                %shown in the editable text containing the calibratin value
                %changes accordingly.
                
                set(calib_figure, 'WindowButtonDownFcn', @startMeasure);
                
                
                
                
        end;
        
        
        
        
    end


%define windowbuttonmotion function.  when the user drags the line vertices
%the length of the line will change. this change is shown in the editable
%text box containing the calibration value.

function activemousePos(varargin)
      
    %find the current position of the interative line.
    
	pos = getPosition(hline);
    
    
    %calculate the length of the line. This is your calibration value.
    
    measureCalibVal = sqrt(diff(pos(:,1)).^2 + diff(pos(:,2)).^2);
        
    
    %display the new calibration value in editable text boxes as
    %applicable.
    
    
    %check to see what radio button is in focus.
    
    checkrad = get(calibRadio(1), 'Value');
    
    switch checkrad
        
        case 1 %measure calibration value by pixel width.
    
            set(calibUI, 'String', num2str(measureCalibVal, 4.1));
        
        
        case 0 %measure calibration value by pixel height.
            
            set(calibUI2, 'String', num2str(measureCalibVal, 4.1));
            
            
            
    end;
    
         
         
end



%define window button down function.  this function activates the
%windowbuttonmotion function.

     function startMeasure(varargin)
     
         set(calib_figure, 'WindowButtonMotionFcn', @activemousePos);
         
         
         
     end


%define zoom in callback.
 
    function zoomIn(varargin)
        
        %turn the interactive zooming on.
        
        pan off;
        zoom on;
        
        
        
    end


%define zoom out callback

    function zoomOut(varargin)
        
        %zoom out and turn interactive zooming off.
        
        zoom out;
        zoom off;
        
        
        
        
    end
 
 
 %define pan image callback.
 
    function panImage(varargin)
        
        zoom off;
        pan on;
        
    end
 
 
%define measure calib value callback.

    function measureVal(varargin)
        
        zoom off;
        pan off;
        
 
        
        
    end
 
 
 
 

end