function set_cortex_bands

%this function will allow the user to determine which intervals the mean cortex
%cell sizes are calculated within.

%the user will select these measurements by selecting/de-selecting a GUI checkbox.

%for each setting a diagram will appear on the right side of the showing
%the location of the intervals.

%these diagrams are stored in image files located within the main program
%directory.


%define the current directory.

current_directory = cd;

%find the path to the root scan main programs directory, find the last file
%break in the directory path and truncate directory path beyond the last 
%file break.   

pathway =            which('set_cortex_bands.m');  
find_last_break = find(pathway == 47, 1, 'last');  
pathway =             pathway(1:find_last_break);  



%load the current cortex region settings.  these settings are found in the
%file: interval_mat.mat.  define path to file: INTERVAL_MAT.mat.  load the 
%file and convert it from a structure to cell format.  this will save the current 
%setting for the cancel button option and access the data.

pathway_s      = [pathway 'INTERVAL_MAT.mat'];  
regionvals     = struct2cell(load(pathway_s));  



%define the current number of cortex intervals. this determines which diagram
%will be displayed at the startup of the interactive window.

regionvalSIZE =     size((regionvals{1,1}{2,1}), 2);  
regionvalMODE = sum(cell2mat(regionvals{1,1}{3,1}));  





%read 1/3_cortex.jpg image. %this image diagram shows 3 equally spaced
%partitions.

three_band_im = imread([pathway 'three_diag.jpg']);   



%read 1/5_cortex.jpg image. this image diagram shows 5 equally spaced
%partitions.

five_band_im   = imread([pathway 'five_diag.jpg']);  


%read 1/7_cortex.jpg image. this image diagram shows 7 equally spaced
%partitions.

seven_band_im = imread([pathway 'seven_diag.jpg']);  





%initialize figure for the selection process.


%initialize the figure window.

cc_fig = figure('Name', 'Cortex Region Interval Selection', 'Units', 'normalized', ...
    'Position', [.1 .1 .8 .8], 'Menubar', 'none', 'Tag', 'MB', ...
    'NumberTitle', 'off', 'Color', [.5 .7 .9], 'Resize', 'off');  


%set up the axes for the entire figure. this axes will cover the entire figure.

axes('Units', 'normalized', 'Position', [0, 0 , 1, 1], 'Visible', 'off');  




%set up some uipanels.

%set up panel for the description paragraph.

panel_top_left = uipanel('Parent', cc_fig, 'Units', 'normalized', 'Position', ...
    [0, 0, .4 1], 'BackgroundColor', [.9 .9 .9]);  


%set up panels for the check boxes.

panel_bottom_left = uipanel('Parent', panel_top_left, 'Units', 'normalized', ...
    'Position', [0, 0, 1, .5], 'BackgroundColor', [.8 .8 .8]);  


%set up a panel for the right side of the figure.

panel_right = uipanel('Parent', cc_fig, 'Units', 'normalized', 'Position', ...
    [.4, 0, .6 1], 'BackgroundColor', [.5 .7 .9]);  


%set up the title for the right side panel.  this will be used to parent an axes.

uicontrol('Style', 'text', 'Units', 'normalized', 'Position', ...
    [.02, .80, .93, .15], 'String', 'Diagram of Cortex Region Intervals', ...
    'Parent', panel_right, 'FontUnits', 'normalized', 'FontSize', .41, ...
    'HorizontalAlignment', 'center', 'FontWeight', 'bold', ...
    'BackgroundColor', [.5 .7 .9]);  


%set up axes to hold the cortex interval diagrams.

AR = axes('Parent', panel_right, 'Units', 'normalized', 'Position', ...
    [0, 0 , 1, .75], 'Visible', 'off');   


%set up title for check box section. this will be positioned in the top left panel.

uicontrol('Style', 'text', 'Units', 'normalized', 'Position', ...
    [.02, .87, .9, .1], 'String', 'Select Cortex Region Interval', 'Parent', ...
    panel_top_left,  'FontUnits', 'normalized', 'FontSize', .35, ...
    'HorizontalAlignment', 'center', 'FontWeight', 'bold', ...
    'BackgroundColor', [.9 .9 .9]);  


%set up the description for the cortex inteval user interface.

text_discript = uicontrol('Style', 'text', 'Units', 'normalized', 'Position', ...
    [.04, .5, .9, .4],'Parent', panel_top_left,  'FontUnits', 'normalized', ...
    'FontSize', .07,'HorizontalAlignment', 'left', 'FontWeight', 'normal', ...
    'BackgroundColor', [.9 .9 .9]);  


%set the string for the cortex interval user interface.

set(text_discript, 'String', ['      Often times local sampling methods are',...
    'used to reveal additional information for a particular sample.  This is', ...
    'especially true for root cortex samples possibly having uiform and ', ...
    'non-uniform cortex cell size distribution within cortex regions. This', ...
    'window prompts the user to select radial distance interval bands for ', ...
    'the local sampling method.']);


%set up check box for 3 equadistant cortex interval selection.

check_box_1_3 = uicontrol('Parent', panel_bottom_left, 'Units', 'normalized', ...
    'Style', 'checkbox', 'String', '3 Equal-radial Regions', 'Position', ...
    [.05, .8, .8, .1],  'FontUnits', 'normalized', 'FontSize', .7, ...
    'HorizontalAlignment', 'left', 'FontWeight', 'bold', 'BackgroundColor', [.8 .8 .8]);  


%set up check box for 5 equadistant cortex interval selection.

check_box_1_5 = uicontrol('Parent', panel_bottom_left, 'Units', 'normalized', ...
    'Style', 'checkbox', 'String', '5 Equal-radial Regions', 'Position', ...
    [.05, .65, .8, .1],  'FontUnits', 'normalized', 'FontSize', .7, ...
    'HorizontalAlignment', 'left', 'FontWeight', 'bold', 'BackgroundColor', [.8 .8 .8]);  


%set up check box for 7 equadistant cortex interval selection.

check_box_1_7 = uicontrol('Parent', panel_bottom_left, 'Units', 'normalized', ...
    'Style', 'checkbox', 'String', '7 Equal-radial Regions', 'Position', ...
    [.05, .5, .8, .1],  'FontUnits', 'normalized', 'FontSize', .7, ...
    'HorizontalAlignment', 'left', 'FontWeight', 'bold', 'BackgroundColor', [.8 .8 .8]);  


%set up check box for custom interval selection.

check_box_custom = uicontrol('Parent', panel_bottom_left, 'Units', 'normalized', ...
    'Style', 'checkbox', 'String', 'Select Custom Regions', 'Position', ...
    [.05, .35, .8, .1],  'FontUnits', 'normalized', 'FontSize', .7, ...
    'HorizontalAlignment', 'left', 'FontWeight', 'bold', 'BackgroundColor', [.8 .8 .8]);  



%set callbacks for all check boxes.  when the check box is selection the
%callback function takes action on the display and records the data.



%set callback for check box (3 equadistant cortex interval selection).

                set(check_box_1_3, 'Callback', @callback_1_3); 


%set callback for check box (5 equadistant cortex interval selection).

                set(check_box_1_5, 'Callback', @callback_1_5); 
                
                
%set callback for check box (7 equadistant cortex interval selection).                
                
                set(check_box_1_7, 'Callback', @callback_1_7);
                
                
%set callback for check box (custom cortex interval selection).                
                
set(check_box_custom, 'Callback', @callback_check_box_custom);  


%set up done and cancel push buttons.



%set up done button.

done_button = uicontrol('Parent', panel_bottom_left, 'Units', 'normalized', ...
    'Style', 'pushbutton', 'String', 'DONE', 'Position', [.08, .03, .3, .15], ...
    'FontUnits', 'normalized', 'FontSize', .5, 'HorizontalAlignment', ...
    'left', 'FontWeight', 'bold'); 


%set up cancel button.

cancel_button = uicontrol('Parent', panel_bottom_left, 'Units', 'normalized', ...
    'Style', 'pushbutton', 'String', 'CANCEL', 'Position', [.4, .03, .3, .15],  ...
    'FontUnits', 'normalized', 'FontSize', .5, 'HorizontalAlignment', 'left', ...
    'FontWeight', 'bold');  



%set up callbacks for done and cancel buttons.  



%callback for done button.  when user selects this button the new cortex 
%interval settings are saved and the program terminates.

    set(done_button, 'Callback', @callback_done); 
    
    
%callback for cancel button.  when user selects this button the previous 
%settings remain and the program terminates.    
    
set(cancel_button, 'Callback', @callback_cancel);  




%set the current axes to 'ar'.  this will tell the program which axes to place
%the cortex interval diagram corresponding to the current cortex interval 
%settings in the appropriate location.

set(gcf, 'CurrentAxes', AR);   



%place the cortex interval diagram corresponding to the current cortex interval
%settings in the axes 'ar'.


%if the curernt setting is not equal to the custom interval setting then load
%1 of the 3 pre-defined cortex interval diagrams.

if (regionvalMODE == 0)  


    %determine the current number of cortex intervals.
    
    switch regionvalSIZE  
    
        case {3}  %we have 3 equadistant intervals as the current setting.
    
            
            %display the diagram in the axes
            
            current_diagram = imshow(three_band_im);  
            
            
            %check the 3 equadistant cortex interval check box.
            
            set(check_box_1_3, 'Value', 1);  
            
          
        case {5}  %we have 5 equadistant intervals as the current setting.
    
            
            %display the diagram in the axes
            
            current_diagram = imshow(five_band_im); 
            
            
            %check the 5 equadistant cortex interval check box.
            
            set(check_box_1_5, 'Value', 1);  
            
            
         case {7}  %we have 7 equadistant intervals as the current setting.
    
            
            %display the diagram in the axes
            
            current_diagram = imshow(seven_band_im); 
            
            
            %check the 5 equadistant cortex interval check box.
            
            set(check_box_1_7, 'Value', 1);  
            
            
            
            
            
    end;

else
    
    
    %display a blank figure.  there is no diagram to describe the custom 
    %cortex interval settings.
    
    current_diagram = imshow((five_band_im*0)+255);  
    
    
    %check the custom cortex interval check box.
    
    set(check_box_custom, 'Value', 1);  
    
end;


%go to the directory defined by 'pathway'.

cd(pathway);  





%Place all callback functions here.






%define callback for user hitting the 3-equidistant cortex interval
%checkbox.

    function callback_1_3(varargin)

        %de-select check box corresponding to 5 equadistant cortex interval
        %selection.
        
        set(check_box_1_5, 'Value', 0);  
        
        
        %unselect all check boxes but the check box corresponding to the 7
        %equadistant cortex interval selection.
        
        set(check_box_1_7, 'Value', 0);
        
        
        %unselect check box corresponding to custom cortex interval selection.
        
        set(check_box_custom, 'Value', 0);  

        
        %delete current image diagram from axes 'ar' contained in the right
        %panel
        
        if (isempty(current_diagram) == 0)
            
            delete(current_diagram);
            
        end;
        
        
        %place diagram associated with the 3 equadistant interval selection
        %in axes.
        
        current_diagram = imshow(three_band_im);  
             
            
        %define the cortex intervals, color specification and column
        %headers associated with 3 equadistant cortex interval selection.
        
        
        %define the cortex intervals.
        
        intervals = [1/3 2/3 1];  
        
        
        %define the pixel color specification.
        
        color_specifications = floor([.4 .6 .8]*255);
        
        
        %define data column headers.
        
        data_column_header = {'Median Cell Size (0 >= R < .33*C)', ...
            'Median Cell Size (.33*C >= R < .66*C)', ...
            'Median Cell Size (.66*C >= R < C)'};  
        
        
        %place these settings in a cell array.

        all_interval_data = {{intervals; color_specifications}; data_column_header; ...
            {intervals*0}};  
        
        
        %save the intervals in a matfile in the main programs directory.
        
        save('INTERVAL_MAT', 'all_interval_data');  
        
            
    end



%define callback for user hitting the 4-equidistant cortex interval
%checkbox.

    function callback_1_7(varargin)

        %unselect all check boxes but the check box corresponding to the 4
        %equadistant cortex interval selection.
        
        set(check_box_1_3, 'Value', 0);
        
        
        %unselect check box corresponding to 5 equadistant cortex interval 
        %selection.
        
        set(check_box_1_5, 'Value', 0);  
        
        
        %unselect check box corresponding to custom cortex interval selection.
        
        set(check_box_custom, 'Value', 0);  
        
        
        %delete current image diagram from axes contained in the right
        %panel.
        
        if (isempty(current_diagram) == 0)
            
            delete(current_diagram);
            
        end;
        
        
        %place diagram associated with the 4 equadistant interval selection in axes 'ar'.
        
        current_diagram = imshow(seven_band_im);  

            
        %define the cortex intervals, color specification and column
        %headers associated with 4 equadistant cortex interval selection.
            
        
        %define the cortex intervals. 
        
        intervals = [1/7 2/7 3/7 4/7 5/7 6/7 1];   
        
        
        %define the pixel color specification.
        
        color_specifications = floor([.3 .35 .40 .45 .50 .55 .60]*255); 
        
        
        %define the pixel color specification.
        
        data_column_header = {'Median Cell Size (0 >= R < .14*C)', ...
            'Median Cell Size (.14*C >= R < .29*C)', ...
            'Median Cell Size (.29*C >= R < .43*C)', ...
            'Median Cell Size (.43*C >= R < .57*C)', ...
            'Median Cell Size (.57*C >= R < .71*C)', ...
            'Median Cell Size (.71*C >= R < .85*C)', ...
            'Median Cell Size (.86*C >= R < C)'};  
          
        
        %place these settings in a cell array.

        all_interval_data = {{intervals; color_specifications}; data_column_header; ...
            {intervals*0}};  
        
        
        %save the intervals in a matfile in the main programs directory.
        
        save('INTERVAL_MAT', 'all_interval_data');  
        
        
    end


%define callback for user hitting the 5-equidistant cortex interval
%checkbox.

    function callback_1_5(varargin)

        %unselect check box corresponding to 3 equadistant cortex interval
        %selection.
        
        set(check_box_1_3, 'Value', 0);  
             
        
        %unselect all check boxes but the check box corresponding to the 4
        %equadistant cortex interval selection.
       
        set(check_box_1_7, 'Value', 0); 
        
        
        %unselect check box corresponding to custom cortex interval selection.
        
        set(check_box_custom, 'Value', 0);  
        
        
        %delete current image diagram from axes 'ar' contained in the right
        %panel.
        
        if (isempty(current_diagram) == 0)
            
            delete(current_diagram);
            
        end;
        
            
        
        %place diagram associated with the 5 equadistant interval selection
        %in axes.
        
        current_diagram = imshow(five_band_im);  

            
        %define the cortex intervals, color specification and column
        %headers associated with 3 equadistant cortex interval selection.
            
        
        %define the cortex intervals.
        
        intervals = [1/5 2/5 3/5 4/5 1];   
        
        
        %define the pixel color specification.
        
        color_specifications = floor([.4 .5 .6 .7 .8]*255); 
        
        
        %define the pixel color specification.
        
        data_column_header = {'Mean Cell Size (0 >= R < .20*C)', ...
            'Median Cell Size (.20*C >= R < .40*C)', ...
            'Median Cell Size (.40*C >= R < .60*C)', ...
            'Median Cell Size (.60*C >= R < .80*C)', ...
            'Median Cell Size (.80*C >= R < C)'};  
          
        
        %place these settings in a cell array.
        
        all_interval_data = {{intervals; color_specifications}; data_column_header; ...
            {intervals*0}};  
        
        
        %save the intervals in a matfile in the main programs directory.
        
        save('INTERVAL_MAT', 'all_interval_data');  
        
        
        
    end



%define callback for user hitting custom cortex intervations checkbox.

    function callback_check_box_custom(varargin)
        
        
        %unselect check box corresponding to 5 equadistant cortex interval
        %selection.
        
        set(check_box_1_3, 'Value', 0);  
        
        
        %unselect check box corresponding to 5 equadistant cortex interval
        %selection.
        
        set(check_box_1_5, 'Value', 0); 
        
        
        %unselect check box corresponding to 7 equadistant cortex interval 
        %selection.
        
        set(check_box_1_7, 'Value', 0);  
        
        
        %define the cortex intervals, color specification and column
        %headers associated with 3 equadistant cortex interval selection.
        
        if (isempty(current_diagram) == 0)
            
            delete(current_diagram);
            
        end;
         
             
        %place diagram associated with the custom interval selection in axes
        
        
        current_diagram = imshow((five_band_im*0)+255);  
             
      

    end






%place callback for user hitting the done button.

    function callback_done(varargin)

        current_mode = get(check_box_custom, 'Value');
        
        
        
        if (current_mode ~= 0) 

 
            %open the custom cortex interval selection graphical user interface.
            
            set_custom_cortex_bands; 

        end;
        
        cd(current_directory);  %go to current directory.
        delete(cc_fig);  %delete current figure window.

    end




%place callback associated with user hitting cancel button.

    function callback_cancel(varargin)
        
        %keep the previous settings.
        

        %define main programs directory to interval_mat.mat.  the previous
        %setting will be saved to the file in this location.
        
            delete(cc_fig);  %delete current figure window.
        
            cd(current_directory);  %go to current directory.
        
        
        
    end









end