function set_custom_cortex_bands

%this function allows the user to manually selection the banding
%intervals for the cortex interval selection.  they can only select up
%to 10 intervals since there is rarely ever a cortex that has more than 10
%cell file regions.


%initilize the answer varible. this will be eventually used to terminate
%the while control statement.

answer2 = 0;  


%continue to ask the user to enter the number of desired cortex intervals 
%until they enter a valid response.

while (answer2 == 0)  

    
%prompt the user to enter the number of cortex intervals for the custom 
%selection.    
    
answer = inputdlg(['How many cortex regions do you want? ', ...
    '(Suggestion: Since the number of cell files is usually less than 10, ', ...
    'the user should select an interval no greater than 10 intervals.'], ...
    'Select The Number of Cortex Regions', 2);  


%convert the answer to numerical double precision.

answer = str2double(cell2mat(answer));  


    %if valid response is false then re-issue prompt window.

    if ((sum(ismember((1:10), answer)) == 0) && (isnan(answer) == 0))
    
        answer2 = 0;
        
    
        %if user cancels the window then terminate 'while' loop and quit
        %program.
    
    elseif ((sum(ismember((1:10), answer)) == 0) && (isnan(answer) == 1))    
        
        answer2 = 1;
        
        
        %if valid repsonse is true then terminate 'while' loop and quit
        %program. and continue to next part of program.
    
    else  
   
        answer2 = 1;
    
    end;



end;




%if the user entered a valid response then initialize a gui figure for
%entering the user-specific variables.

if (isnan(answer) == 0)

    
    %initialize another figure for the selection process.

    cc_fig = figure('Name', 'Custom Cortex Interval Selection', 'Units', 'normalized', ...
        'Position', [.4 .2 .3 .5], ...
        'Menubar', 'none', 'Tag', 'MB', 'NumberTitle', 'off', ...
        'Color', [.9 .9 .9], 'Resize', 'off');  



    %set up some panels to place the editable text boxes.  these panels are
    %used for organizational purposes.

    
    
    %set up left panel.  this panel will hold the lower bound editable text 
    %boxes of each interval.
    
    left_panel = uipanel('Parent', cc_fig, 'Units', 'normalized', ...
        'Position', [0 .1 .5 .9], 'BackgroundColor', [.9 .9 .9]);  
    
    
    %set up right panel.  this panel will hold the upper bound editable text
    %boxes of each interval.
    
    right_panel = uipanel('Parent', cc_fig, 'Units', 'normalized', ...
        'Position', [.5 .1 .5 .9], 'BackgroundColor', [.9 .9 .9]);  


    %set up the titles for the lower bound and upper bound editable text box
    %columns.

    %title: 'Lower Bound'.
    
    uicontrol('Parent', left_panel, 'Style', 'text', 'Units', 'normalized', ...
        'Position', [.17 .93 .75 .05], 'BackgroundColor', [.9 .9 .9], ...
        'String', 'Lower Bound', 'FontUnits', 'normalized', ...
        'FontSize' , .6, 'FontWeight', 'bold');  
    
    
    %title: 'Upper Bound'.
    
    uicontrol('Parent', right_panel, 'Style', 'text', 'Units', 'normalized', ...
        'Position', [.05 .93 .75 .05], 'BackgroundColor', [.9 .9 .9], ...
        'String', 'Upper Bound', 'FontUnits', 'normalized', ...
        'FontSize' , .6, 'FontWeight', 'bold');  


    
    
    %define done and cancel buttom.

    
    %done button.
    
    DONE = uicontrol('Parent', cc_fig, 'Units', 'normalized', ...
        'Position', [.58 .015 .2 .07], 'String', 'DONE',  'FontUnits', ...
        'normalized', 'FontSize' , .5, 'FontWeight', 'bold'); 
    
    
    %cancel button.
    
    CANCEL = uicontrol('Parent', cc_fig, 'Units', 'normalized', ...
        'Position', [.79 .015 .2 .07], 'String', 'CANCEL',  'FontUnits', ...
        'normalized', 'FontSize' , .5, 'FontWeight', 'bold');  

    
    %set callbacks for done and cancel buttons

    set(DONE, 'Callback', @callback_done);    
    set(CANCEL, 'Callback', @callback_cancel);  


    
    %place the editable text boxes in the figure now.
    
    
    %set the initial vertical step to place the editable text boxes.

    STEP = -.07;  

    for I = 1:answer
    
        
        %update the step.
        
        STEP = STEP - .07;  
    
        
        %define interval number/name.  each interval will have a lower and
        %upper bound.
        
        INT_NAME(I) = uicontrol('Parent', left_panel, 'Style', 'text', ...
            'Units', 'normalized', 'Position', [.05 (1 + STEP - .01) .1 .05], ...
            'BackgroundColor', [.9 .9 .9], 'String', int2str(I), 'FontUnits', ...
            'normalized', 'FontSize', .6, 'FontWeight', 'bold');
        
        
        %place lower bound text box for each interval.
        
        LOW(I) = uicontrol('Parent', left_panel, 'Style', 'edit', 'Units', ...
            'normalized', 'Position', [.2 (1 + STEP) .75 .05], ...
            'BackgroundColor', 'w', 'FontUnits', 'normalized', ...
            'FontSize' , .6, 'FontWeight', 'bold');  
        
        
        %place upper bound text box for each interval.
        
        HIGH(I) = uicontrol('Parent', right_panel, 'Style', 'edit', ...
            'Units', 'normalized', 'Position', [.06 (1 + STEP) .75 .05], ...
            'BackgroundColor', 'w', 'FontUnits', 'normalized', ...
            'FontSize' , .6, 'FontWeight', 'bold');  
    
    
        
        
        %if the current interval is the first interval. then take the following
        %actions.
    
        if (I == 1) 
        
            
            %set the first lower bound to 0.
            
            set(LOW(I), 'String', '0');  

             
            %if the current interval is not the first interval. then take the
            %following actions.    
            
        else  
        
            
            %disable current upper bound.
            
            set(HIGH(I), 'enable', 'off');  
        
        end;
    
    
        %if the current interval is the last interval. then take the following
        %actions.
    
        if (I == answer)  
        
            
            %set the last upper bound to 1 and disable last upper bound 
            %editable text box.
            
            set(HIGH(I), 'String', '1');  
            set(HIGH(I), 'enable', 'off');  
        
            
            %if the current interval is not the last interval. then take the 
            %following actions.    
            
        else  
        
            
            %set the callback for editable text box when the user enters an
            %interval.
            
            set(HIGH(I), 'Callback', @call_name_high);  
   
        end;
    
    
     
    end;


    %disable all lower bound intervals. 
    
    set(LOW, 'enable', 'off'); 


%if the user cancels the window then revert back to the checkbox window
%showing the cortex interval options.

else 
    
    
    CORTEX_REGION_VAR;
    
    
end;



%the editable text boexs are ready for input.


%list all callbacks for editable text boxes, finished and cancel buttons.


    function call_name_high(varargin)
        
        
        
        %get the string (interval entry) from all editable text box.
        
        get_all_strings = get(HIGH, 'String');  
        
        
        %get the current graphics object (in this case: the current editable 
        %text box in focus).
        
        current_obj =                     gco;  
        
        
        %get all upper bound editable text box handles.
        
        all_objs =                       HIGH;
        
        
        
        
        %define a matrix containing all alpha characters.  
        
        char_vect = char([(uint8('A'):uint8('Z')) (uint8('a'):uint8('z'))]);  
        
    

        %convert the strings to their numerical equavalents.
    
        ALL_STRING_NUMS =   str2double(get_all_strings); 
        
        
        
    
        %test the interval to determine if the interval is out of order 
        %(i.e. the intervals are not ordered corrrectly.
    
        
        %TAKE THE DERIVATIVE OF THE NUMERICAL DATA TAKEN FROM THE UPPER INTERVAL
        %EDITABLE TEXT BOXES.
        
        DIFF_ALL_STRING_NUMS =    diff(ALL_STRING_NUMS);  
    
        
        %find any values less than or equal to zero.  do we have any duplicate
        %upper bound entries or any overlapping upper bound entries?
        
        find_zero_neg = find(DIFF_ALL_STRING_NUMS <= 0);  
    
    
        %define the current editable text box in focus.
    
        MEMBER =            ismember(all_objs, current_obj);  

        
        %choose the current editable text box in focus.
        
        find_current =                    find(MEMBER == 1);  
    
        
        %get the current entry from current editable text box in focus.
        
        high_string_get = get(HIGH(find_current), 'String');  



    
        %we need to test the value of the string to see whether we have letters
        %or numbers. did the user enter an invalid string.

    
        
        %define the size of the string.  we are going to test each element 
        %of the string.
        
        stringMAT = size(high_string_get,2);  
    
        
        %set up a matrix of zeros for storing binary information (true/false)
        %for the following tests:
        
        CHAR_MEMBERS =    zeros(stringMAT, 1); %did user enter a letter? 
        POINT_MEMBERS =   zeros(stringMAT, 1); %did user entered a decimal point.
        F_SLASH_MEMBERS = zeros(stringMAT, 1); %did user entered a forward slash.
        B_SLASH_MEMBERS = zeros(stringMAT, 1); %did user entered a back slash.
        NUM_MEMBERS =     zeros(stringMAT, 1); %did user entered a number.
        SYM_MEMBERS =     zeros(stringMAT, 1); %did user entered a symbol.
    
        
        
        
    %test each string element.
    
    for I = 1:stringMAT  
    
        
        %define each element.
        
        first_string = high_string_get(I);  
        
        
        %determine if current element is a character.
        
        CHAR_MEMBERS(I) = sum(ismember(char_vect, first_string)); 
        
        
        %determine if current element is a decimal point.
        
        POINT_MEMBERS(I) = sum(ismember('.', first_string));  
        
        
        %determine if current element is a forward slash.
        
        F_SLASH_MEMBERS(I) = sum(ismember('/', first_string));  
        
        
        %determine if current element is a back slash.
        
        B_SLASH_MEMBERS(I) = sum(ismember('\', first_string));  
        
        
        %determine if current element is a number.
        
        NUM_MEMBERS(I) = sum(ismember(['1' '2' '3' '4' '5' '6' '7' '8' '9'...
            '0'], first_string)); 
        
        
        %determine if current element is a symbol.
        
        SYM_MEMBERS(I) = sum(ismember([',' '?' '[' ']' '{' '}' '|' '<' '>'...
            '"' '-' '+' '=' '!' '@' '#' '$' '%' '^' '&' '(' ')' '~' '`' ';'...
            ':'], first_string));  
        
        
    end;
    


    %define the number of decimal points entered.  will be used to determine
    %if user enter two decimal points beside each other in the string element.
    
    CUM_SUM_DECI = cumsum(POINT_MEMBERS);  
    
    
    %how many adjacent decimal point entries are there.
    
    MEM_CUM_SUM_DECI = sum(ismember((2:10), CUM_SUM_DECI));  
    
    
    %test to see if the user entered a 1.  user must enter a real number less
    %than 1.
    
    DOUBLE_ONE = str2num(high_string_get);  
    
    

    %run all character tests on the input.  lets determine if the user
    %entered a valid or invalid entry.
    
    
    
    %the user entered a letter rather than a number.
    
    if (sum(CHAR_MEMBERS) > 0) 
    
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r'); 
        
        
        %place warning dialog box here.
        
        warndlg(['Your interval boundary contains a non-numeric value, ', ...
            'please correct this mistake.']);  
    
        
    %the user entered a symbol.
    
    elseif (sum(SYM_MEMBERS) > 0) 
        
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r');  
        
        
        %place warning dialog box here.
        
        warndlg(['You entered a symbol, which are not allowed, please correct', ...
            'this mistake.']);  
        
    
    %the user enter a 1. this is the max interval bound.
    
    elseif (DOUBLE_ONE >= 1) 
        
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r');  
        
        
        %place warning dialog box here.
        
        warndlg(['You entered a ' int2str(DOUBLE_ONE) ...
            ', which exceeds the maximum uppper boundary, please correct '...
            'this mistake.']);  
        
    
    %there are more than one slash symbols entered. it will not be evaluated
    %correctly.
        
    elseif (sum(F_SLASH_MEMBERS) > 1) 
        
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r');  
        
        
        %place warning dialog box here.
        
        warndlg(['You entered multiple forward slash symbols, please correct' ...
            'this mistake.']);  
        
        
    %the user entered a backslash. this will contribute to calculation errors.    
        
    elseif (sum(B_SLASH_MEMBERS) > 0) 
        
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r'); 
        
        
        %place warning dialog box here.
        
        warndlg(['You entered a backward slash symbol, which will lead to ' ...
            'calculation errors, please correct this mistake.']);  
        
    
    %the user entered multiple adjacent decimial points.    
        
    elseif (sum(MEM_CUM_SUM_DECI) >= 1)
        
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r');  
        
        
        %place warning dialog box here.
        
        warndlg(['You entered multiple adjacent decimal points, which will'...
            'lead to calculation errors, please correct this mistake.']);  
        
   
    %the user did not proceed the decimal point wiht a number.    
        
    elseif ((sum(POINT_MEMBERS) == 1) && (sum(NUM_MEMBERS) == 0))
        
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r'); 
        
        
        %place warning dialog box here.
        
        warndlg(['No number proceeds your decimal points, please correct ' ...
            'this mistake.']);  
        
     
    %the user did not enter a number.       
        
    elseif ((sum(F_SLASH_MEMBERS) == 1) && (sum(NUM_MEMBERS) < 2))
        
        
        %set the current editable text box background color to red.  users 
        %attention should be drawn to current editable text box.
        
        set(current_obj, 'BackgroundColor', 'r');  
        
        
        %place warning dialog box here.
        
        warndlg('You are missing a number, please correct this mistake.');  
    
    
    %the user ented a valid number less than 1.  determine if their intervals
    %overlap now. we cannot hvae overlapping intervals.
       
    else
        
        
        %user's intervals overlap.
        
        if (isempty(find_zero_neg) == 0) 
        
            
            %set the current editable text box background color to red.  users
            %attention should be drawn to current editable text box.
            
            set(current_obj, 'BackgroundColor', 'r');  
            
            
            %place warning dialog box here.
            
            warndlg(['You have overlapping intervals, please correct this '...
                'mistake.']);  
                
            
            %the user entered a valid number.    
            
        else  
            

            %determine if the next uppper bound is the absolute upper bound
            %(i.e. is the next upper bound interval equal to 1).  it is equal
            %to 1.
            
            if ((find_current + 1) == length(MEMBER))  
        
                
                %the next upper bound interval is equal to 1.  disable editable
                %text box.
                
                set(HIGH(find_current + 1), 'Enable', 'off');  
        
                
                %it is not equal to 1.    
                
            else
                
                
                %enable next upper bound interval editiable text box.
                
                set(HIGH(find_current + 1), 'Enable', 'on');  
    
            end;  
        
            
                %the next lower bound interval to the current upper bound 
                %editable text box entry.
            
                set(LOW(find_current + 1), 'String', high_string_get);  
                
                
                %set the current editable text box background color to white.
                
                set(current_obj, 'BackgroundColor', 'w');  
            
        end;
        
    end
        

    
    
    
        
    end






%set callbacks for done and cancel buttons.




    function callback_done(varargin)
        
        
            %retrieve all strings from the upper bound editable text boxes.
        
            get_all_strings =               get(HIGH, 'String');  
            
            
            %convert string to double.
            
            get_all_double =       str2double(get_all_strings');  
            
            
            %get all non-nan values.
            
            INTERVALS =      get_all_double(get_all_double > 0);  
            
            
            %define the length of the intervals vector.
            
            SIZE_INTERVALS =                  length(INTERVALS);  
            
            
            %define the pixel color specifications.
            
            COLOR_SPEC = floor((.4:(.4/SIZE_INTERVALS):.8)*255);
            
            
            %remove the last color specification. this is the last upper interval.
            
            COLOR_SPEC =                    COLOR_SPEC(1:end-1);  
            
            
            %define the inteval bounds.
            
            interval_bounds =                     [0 INTERVALS];  
            
            
            
            
            %define the data column header for each interval
            
            for I = 1:SIZE_INTERVALS  
                
                
                %define column header.
                
                INTERVAL_NAME{1,I} = ['Median Cell Size (' ...
                    num2str(interval_bounds(I)) ' >= R < ' ...
                    num2str(interval_bounds(I+1)) '*C)'];  
                
            end;
        
            
            
            %store interval data in a cell array.
        
            INTERVAL_MAT_OUT = {{INTERVALS; COLOR_SPEC}; ...
                INTERVAL_NAME; {(INTERVALS*0) + 1}};  
            
            
            %find the path to the root scan main programs directory, find
            %the last file break in the directory path and truncate directory
            %path beyond the last file break. 
            
            pathway                 = which('Rootscan_session.m');  
            find_last_break = find(pathway == 47, 1, 'last');  
            pathway             = pathway(1:find_last_break);  

            
            cd(pathway);
            
            
            %save current interval settings to 'interval_mat.mat' in the main
            %programs directory.
            
            save('INTERVAL_MAT', 'INTERVAL_MAT_OUT');  
            
        
            %terminate figure.
        
            delete(cc_fig);  
        
        
    end




    function callback_cancel(varargin)
        
        
        %take no action on data. terminate figure.
        
        delete(cc_fig);  
        
    end



end