function stpersmooth(varargin)

%this function will smooth the perimeter of the stele - extra stelular
%boundary.  this will remove any rough edges prior to the initialization of
%the interactive stele boundary selection.

    global         Coms; %x-section center of mass coordinates.
    global   imagePerim; %perimeter image mask.
    global solidSegment; %solid stele image.



    %define current stele periemter image

    imagePerim    = bwperim(solidSegment); 


    %define the row and column coordinates of the perimeter image.

    [y, x] = find(imagePerim ~= 0);


    %convert to polar coordinates.

    [theta, rho] = cart2pol(x - Coms(1), y - Coms(2));

    theta(theta < 0) = theta(theta < 0) + 2*pi;


    %concatenate the two vectors.

    catThRho = [theta rho];


    %sort the matrix according to increasing theta.

    catThRho = sortrows(catThRho, 1);


    %create buffer for vectors.

    upperBuff = catThRho(1:50,:);
    upperBuff(:,1) = upperBuff(:,1) + 2*pi;

    lowerBuff = catThRho((end-50):end,:);
    lowerBuff(:,1) = lowerBuff(:,1) - 2*pi;


    catThRho2 = [lowerBuff; catThRho; upperBuff];


    %define the window radius for the smoothing method.

    winRad = 2*pi/180;



    for i = 1:size(catThRho,1)

        %lower theta bound for window.

        lowB  = catThRho(i,1) - winRad;


        %upper theta bound for window.

        highB = catThRho(i,1) + winRad;


        %define sample.

        catSample = catThRho2((catThRho2(:,1) >= lowB) & (catThRho2(:,1) < highB),:);


        %calculate the median radius.

        catThRho(i,2) = median(catSample(:,2));



    end;



    %covert the smoothed polar coordinates to cartesian coordinates.

    [x, y] = pol2cart(catThRho(:,1), catThRho(:,2));

    x = floor(x + Coms(1)) - 1;
    y     = floor(y + Coms(2));


    index = x*size(solidSegment,1) + y;


    %define the smoothed stele image.

    smoothStele = solidSegment;


    %assign all pixels to zero.

    smoothStele(:)     = false;


    %assign only the smooth stele perimeter pixels to one.

    smoothStele(index)  = true;


    %dilate the smooth stele. fill it and erode it.  these dilation, filing and
    %eroding steps need to take place since there will be gaps in the perimeter
    %image resulting from the smoothing procedure.  the follow procedure will
    %fill the gaps.

    se                     = strel('disk', 25);  %define disk structural element.

    smoothStele    = imdilate(smoothStele, se);  %dilate the stele region.

    smoothStele = imfill(smoothStele, 'holes');  %fill the dilated stele region with
                                                      %white pixels.

    solidSegment    = imerode(smoothStele, se);  %erode the solid stele solidSegment.
     

end