function threshold_options

%this function will open up another GUI window to allow users to select
%what image thresholding settings users want for your binary conversions.

global AllImageSpecs;



%cd to the main  Rootscan programs directory.

rootscan_dir                            = which('threshold_options');
index = find(rootscan_dir == AllImageSpecs.fileSeparator, 1, 'last');
rootscan_dir((index+1):end)                                     = [];



%load in the current threshold options.

thresh_m     = load([rootscan_dir 'threshMethod.mat']);
thresh_method                 = thresh_m.thresh_method;


%determine which window size checkbox is selected based on the current Rootscan
%settings.

winSizecheck = thresh_method.window_size - 1;


%determine which threshold methods checkbox is selected based on the
%current Rootscan settings.

threshM               = thresh_method.method;




%list all method information strings here.  they will be accessed later.


Str2x2 = ['The current sampling window size is a 2x2 pixel block.' ...
    '  For every iteration 4 grayscale pixels are converted ' ...
    'to binary format.'];


Str3x3 = ['The current sampling window size is a 3x3 pixel block.' ...
    '  For every iteration 9 grayscale pixels are converted ' ...
    'to binary format.  Choosing this sampling window size decreases ' ...
    'sampling time by 225%.'];


Str4x4 = ['The current sampling window size is a 4x4 pixel block.' ...
    '  For every iteration 16 grayscale pixels are converted ' ...
    'to binary format.  Choosing this sampling window size decreases ' ...
    'sampling time by 400%.'];


Str5x5 = ['The current sampling window size is a 5x5 pixel block.' ...
    '  For every iteration 25 grayscale pixels are converted ' ...
    'to binary format.  Choosing this sampling window size decreases ' ...
    'sampling time by 625%.'];


                
        
        
StrOtsu = ['The Localized Otsu Method uses Otsus global thresholding ' ...
    'method on a localized scale.' 'The Otsu method assumes the image ' ...
    'histogram data statistically fit a bi-modal distribution.' ...
    'If your image is fuzzy or has low contrast then the Localized ' ...
    'Otsu Method might not be suitable for your images.'];


StrMethod2 = 'Method 2';


StrMethod3 = 'Method 3';
                
        



%create separate GUI window positioned in the center of the screen.

thresh_fig = figure('Name', 'Image Threshold Settings', 'units', 'normalized', ...
    'position', [.3 .3 .4 .4], 'menubar', 'none');


%get the current color of the figure window.

fig_color = get(thresh_fig, 'Color');


%-----------------place buttoms and controls in window now.---------------%


%define buttons and labels associated with changes made in the sampling window.


%define label for uicontrol checkboxes.

uicontrol('Parent', thresh_fig, 'Style', 'text', 'units', 'normalized', ...
    'position', [.025, .88, .475, .08], 'FontUnits', 'normalized', ...
    'String', 'Sampling Window Width', 'HorizontalAlignment', 'left', ...
    'FontWeight', 'bold', 'BackgroundColor', fig_color);



%determine which check boxes are selected at start up based on the current
%Rootscan settings defined above.



%set initial window size check box to on.

init_check       = [0; 0; 0; 0];
init_check(winSizecheck)    = 1;


%set the current information string asociated with the settings.

switch winSizecheck
    
    case 1
        
        %set the initial information string to the one associated with the
        %2x2 sampling window.
        
        init_string = Str2x2;
        
        
    case 2
        
        %set the initial information string to the one associated with the
        %3x3 sampling window.
        
        init_string = Str3x3;
        
        
    case 3
        
        %set the initial information string to the one associated with the
        %4x4 sampling window.
        
        init_string = Str4x4;
        
        
    case 4
        
        %set the initial information string to the one associated with the
        %5x5 sampling window.
        
        init_string = Str5x5;
        
end;




%set the initial method checkbox to on and display the current method
%information to the right.

init_method = [0; 0; 0];


switch threshM
    
    case 'Local_Otsu'
        
        %the local Otsu method is selected. check the box and display the
        %current method information.
        
        init_method(1) = 1;
        
        initMethod_Str = StrOtsu;
        
        
    case 'Method2'
        
        %threshold method 2 is selected. check the box and display the
        %current method information.
        
        init_method(2) = 1;
        
        initMethod_Str = StrMethod2;
        
        
    case 'Method3'
        
        %threshold method 3 is selected. check the box and display the
        %current method information.
        
        init_method(3) = 1;
        
        initMethod_Str = StrMethod3;
        
        
end;




%define x and y coordinates for checkbox controls.

yo = [.8 .7 .6 .5];
yshift       = .01;
ht = .88 - (yo(3));

%allocate memory for checkbox uicontrol handles.

check_window = zeros(4,1);


%2x2 check box.

check_window(1) = uicontrol('Parent', thresh_fig, 'Style', 'checkbox', 'units', 'normalized', ...
    'position', [.05, yo(1) + yshift, .3, .08], 'FontUnits', 'normalized', ...
    'String', '2X2 Pixel Window', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color);


%3x3 check box.

check_window(2) = uicontrol('Parent', thresh_fig, 'Style', 'checkbox', 'units', 'normalized', ...
    'position', [.05, yo(2) + yshift, .3, .08], 'FontUnits', 'normalized', ...
    'String', '3X3 Pixel Window', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color);



%4x4 check box.

check_window(3) = uicontrol('Parent', thresh_fig, 'Style', 'checkbox', 'units', 'normalized', ...
    'position', [.05, yo(3) + yshift, .3, .08], 'FontUnits', 'normalized', ...
    'String', '4X4 Pixel Window', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color);



%5x5 check box.

check_window(4) = uicontrol('Parent', thresh_fig, 'Style', 'checkbox', 'units', 'normalized', ...
    'position', [.05, yo(4) + yshift, .3, .08], 'FontUnits', 'normalized', ...
    'String', '5X5 Pixel Window', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color);




%define label for threshold sampling window description.

uicontrol('Parent', thresh_fig, 'Style', 'text', 'units', 'normalized', ...
    'position', [.45, .88, .45, .08], 'FontUnits', 'normalized', ...
    'String', 'Sampling Window Information', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color, 'FontWeight', 'bold');


%define static textbox for the sampling window information.

window_description = uicontrol('Parent', thresh_fig, 'Style', 'text', 'units', 'normalized', ...
    'position', [.47, yo(3) + yshift, .50, ht], 'FontUnits', 'normalized', ...
    'FontSize', .1, 'String', init_string, 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color*1.1);


%check the inital checkboxs.

set(check_window(init_check == 1), 'Value', 1);


%set callback function window size checkboxes.

set(check_window, 'Callback', @Window_settings);




%-----------------------threshold statistics options----------------------%


%define label for threshold statistics options.

uicontrol('Parent', thresh_fig, 'Style', 'text', 'units', 'normalized', ...
    'position', [.025, .38, .475, .08], 'FontUnits', 'normalized', ...
    'String', 'Threshold Statistics Options', 'HorizontalAlignment', 'left', ...
    'FontWeight', 'bold', 'BackgroundColor', fig_color);


%define position coordinates for threshold method checkboxes.

yo = [.3 .2 .1];



%allocate memory for methods checkbox uicontrol handles.

check_method = [0 0 0];



%Otsu thresholding method check box.

check_method(1) = uicontrol('Parent', thresh_fig, 'Style', 'checkbox', 'units', 'normalized', ...
    'position', [.05, yo(1) + yshift, .3, .08], 'FontUnits', 'normalized', ...
    'String', 'Otsu Method', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color);


%method 2 check box.

check_method(2) = uicontrol('Parent', thresh_fig, 'Style', 'checkbox', 'units', 'normalized', ...
    'position', [.05, yo(2) + yshift, .3, .08], 'FontUnits', 'normalized', ...
    'String', 'Method 2', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color);



%method 3 check box.

check_method(3) = uicontrol('Parent', thresh_fig, 'Style', 'checkbox', 'units', 'normalized', ...
    'position', [.05, yo(3) + yshift, .3, .08], 'FontUnits', 'normalized', ...
    'String', 'Method 3', 'HorizontalAlignment', 'left', ...
    'BackgroundColor', fig_color);



%set the callback function for threshold methods checkbox selection action.

set(check_method, 'Callback', @Method_settings);


%set the initial threshold methods check box settings.

set(check_method(init_method == 1), 'Value', 1);


%define label for threshold statistics options information.

uicontrol('Parent', thresh_fig, 'Style', 'text', 'units', 'normalized', ...
    'position', [.45, .48, .475, .08], 'FontUnits', 'normalized', ...
    'String', 'Statistics Information', 'HorizontalAlignment', 'left', ...
    'FontWeight', 'bold', 'BackgroundColor', fig_color);



method_description = uicontrol('Parent', thresh_fig, 'Style', 'text', 'units', 'normalized', ...
    'position', [.47, yo(3) + .11, .50, ht], 'FontUnits', 'normalized', ...
    'FontSize', .1,  'HorizontalAlignment', 'left', 'String', initMethod_Str, ...
    'BackgroundColor', fig_color*1.1);



%place finished button at the bottom right hand side of the GUI window.

finished_method = uicontrol('Parent', thresh_fig, 'Style', 'radiobutton', 'units', 'normalized', ...
    'position', [.8 .05, .17, .1], 'FontUnits', 'normalized', ...
    'HorizontalAlignment', 'left', 'String', 'Finished', 'FontWeight', 'bold', ...
    'BackgroundColor', fig_color);


%set the callback for the finished button.

set(finished_method, 'Callback', @finished_callback);




    %this function will display the current sampling size window
    %information with description.

    function Window_settings(varargin)
        
        
        %determine which check box was checked.
        
        checkVal = cell2mat(get(check_window, 'Value'));
        
        
        %subtract initial checkbox values from current checkbox values.
        
        subVal = checkVal - init_check;
        
        
        %find the current check box value.
        
        check_index = find(subVal == 1);
        

        %uncheck all checkboxes but the one selected by user.
        
        set(check_window, 'Value', 0);
        set(check_window(check_index), 'Value', 1);
        
        
        %update initial checkbox value.
        
        init_check(:)           = 0;
        init_check(check_index) = 1;
        
        
        
        
        %update the description box.
        
        switch check_index
            
            case 1
                
                set(window_description, 'String', Str2x2);
               
                
            case 2
                
                set(window_description, 'String', Str3x3);
        
        
            case 3
                
                set(window_description, 'String', Str4x4); 
                
                
            case 4
                
                set(window_description, 'String', Str5x5);
        

        end;
        
 
    end





    %define the callback function used when users selected any of the
    %thresholding methods checkboxes.

    function Method_settings(varargin)
        
        
        %determine which check box was checked.
        
        checkVal = cell2mat(get(check_method, 'Value'));
        
        
        %subtract initial checkbox values from current checkbox values.
        
        subVal = checkVal - init_method;
        
        
        %find the current check box value.
        
        check_index = find(subVal == 1);
        

        %uncheck all checkboxes but the one selected by user.
        
        set(check_method, 'Value', 0);
        set(check_method(check_index), 'Value', 1);
        
        
        %update initial checkbox value.
        
        init_method(:)           = 0;
        init_method(check_index) = 1;
        
        
        
        
        %update the description box.
        
        switch check_index
            
            case 1
                    
                set(method_description, 'String', StrOtsu);
                

            case 2
                
                set(method_description, 'String', StrMethod2);
        
        
            case 3
                        
                set(method_description, 'String', StrMethod3);        
        
        
        end;        
        
        
        
        
        
    end



    %define the callback function associated with the user selecting the
    %finished radio button to close interactive window.

    function finished_callback(varargin)
        
        
        %get the current values for each checkbox.
        
        window_Val = cell2mat(get(check_window, 'Value'));        
        
        
        %get the current values for each checkbox.
        
        method_Val = cell2mat(get(check_method, 'Value'));         
        
        
        
        
        
        %determine the window size based on the checkbox values.
        
        thresh_method.window_size = find(window_Val == 1) + 1;
        
%         switch current_window
%             
%             case 1
%                 
%                 thresh_method.window_size = 2;
%                 
%                 
%             case 2
%                 
%                 thresh_method.window_size = 3;
%                 
%                 
%             case 3
%                 
%                 thresh_method.window_size = 4;
%                 
%         end;
        
        
        
        %determine the threshold method based on the checkbox values.
        
        current_method = find(method_Val == 1);
        
        switch current_method
            
            case 1
                
                thresh_method.method = 'Local_Otsu';
                
                
            case 2
                
                thresh_method.method    = 'Method2';
                
                
            case 3
                
                thresh_method.method    = 'Method3';
                
        end;        
        
        
        
        
        %save the current settings.
        
        save([rootscan_dir AllImageSpecs.fileSeparator 'threshMethod'], 'thresh_method');
        
        
        
        %close the current figure.
        
        delete(thresh_fig);
        
  
    end




end