function viewQuickResults

%this function will display another interactive GUI window after the user
%is completed with analyzing an individual image file for whatever purpose.
%The main purpose should be, however, to determine if their current image
%analysis parameters (i.e. cortex cell size interval settings and threshold
%settings) are adequate for their analysis.




    %define the current dataset and parameters used in the analysis.

    global   data_matrix; %current data matrix.
    global AllImageSpecs; %structure containing all image specifications.
    global  f_fig_handle; %structure containing all figure specifications.


    %define the current images from the individual image analysis mode.


    %load the cell size distribution image.

    load([cd '/temp/cortCC.mat']);



    %set the main axes to the current axes and display the cortex cells as they
    %appear in their radial distance bands.

    set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));
    imshow(cortCellSize);
    colormap('hot');



    %define radial coordinates for median x-section cell size measurements.

    radcoords = AllImageSpecs.bands_intervals(2:end) - ...
        (1/(2*length(AllImageSpecs.bands_intervals(2:end))));


    %define median cortex cell size vector.

    medCortSize = cell2mat(data_matrix(1,50:(50 + ...
        (size(radcoords,2) - 1))));




    %plot the median cell size distribution with radius in separate plot and
    %dislpay on top of main rootScan GUI figure.


    %plot the figure.

    a = figure;
    plot(radcoords, medCortSize, 'b');


    %display title, x and y axis labels on plot.

    title('Median Cortical Cell Size with Distance from Inner Cortex');
    xlabel('Normalized distance from inner cortex');
    ylabel('Median Cortical Cell Size (mm^2)');




    %wait until user deletes figure. then clear axes.

    waitfor(a);


    %set left axes to the current axes.clear the axis objects.

    set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));  
                                                 cla;  


    %set right axes to the current axes and clear ases objects

    set(gcf, 'CurrentAxes', f_fig_handle.im_axes(2));  
                                                 cla; 






end