function writeData(image_name, iteration)

%this function writes the x-section data to file and writes all images
%(made during this step) to the sub-directory called X_section_segments.


global   data_matrix; %data matrix.
global  f_fig_handle; %structure containing all figure children and properties.
global AllImageSpecs; %structure containing all image specifications.
global  solidSegment; %solid x-section image mask.
global          img1; %current raw image.
   


%compute the entire area of x-section. this includes cell structure (dark
%areas) and cell areas (light areas) contained within the cell structure in
%the final segmented image.


    
%calculate root x-section area and place it in data matrix.
            
data_matrix{iteration, 4} = bwarea(solidSegment)/AllImageSpecs.calib_area;  

            
%calculate mean root x-section diameter           
       

%define the major and minor axis lengths for the x-section.

x_section_regions = regionprops(solidSegment, 'MajorAxisLength', 'MinorAxisLength');
   

%major axis length.

major_AL = cat(1, x_section_regions.MajorAxisLength);


%minor axis length.

minor_AL = cat(1, x_section_regions.MinorAxisLength);


%concatenate vectors.

axis_lengths = [major_AL minor_AL];
    

%sort the matrix according to decrease major axes length.

axis_lengths = sortrows(axis_lengths, -1);
            
            
            
%record root cross-section diameter in data cell array
%and save the values after each iteration.
    
data_matrix{iteration, 5} = ((axis_lengths(1,1) + axis_lengths(1,2))/2)/AllImageSpecs.calib_length; 
            
            


%reduce the size of image array to reduce file size and memory
%allocation in phases 2  and 3 of rootscan analysis.
            
            
%calculate the sum of the x-section binary by rows and columns.
            
SUM_ROW = sum(solidSegment, 1);
SUM_COL = sum(solidSegment, 2);
            
            
%find the value for the min and max column parameter of x-section.
            
min_col = find(SUM_ROW ~= 0, 1, 'first');
max_col = find(SUM_ROW ~= 0, 1, 'last');
            
            
%find the value for the min and max row parameter of x-section.
            
min_row = find(SUM_COL ~= 0, 1, 'first');
max_row = find(SUM_COL ~= 0, 1, 'last');
            
            
%create a 10 pixel buffer region betwee the x-section and the image border.
%use the padarray function to accomplish this task.
            
TRUNC_SOLID = solidSegment(min_row:max_row, min_col:max_col);
            
            
%define array pad size.
            
pad = 25;


%define row and column indices for the new images.

rowRange = (min_row - pad):(max_row + pad);
colRange = (min_col - pad):(max_col + pad);
            
            
%this is a new section that accounts for images close to the border.
     
minRow = rowRange(1);
maxRow = rowRange(end);

minCol = colRange(1);
maxCol = colRange(end);


if ((maxRow >= size(img1,1)) || (maxCol >= size(img1,2)) || (minRow <= 1) || (minCol <=1))
      
    %if the maximum number of rows in the row vector exceeds the row
    %dimensions of image then pad the image starting at the last row index
    
    
    truncated_gray_im           = img1;
    solid_buffer = solidSegment;
    
    if maxRow >= size(img1,1)
        
        %pad the grayscale x-section image.
        
        truncated_gray_im = padarray(truncated_gray_im, [pad 0], 'symmetric', 'post');
            
        
        %pad the solid x-section image.
        
        solid_buffer           = padarray(solid_buffer, [pad 0], 'symmetric', 'post');
        
        
        %set border padding values to zero.
        
        solid_buffer(((end-(pad-1)):end),:)                                   = false;
        
        
        
    end;
    
    
    %if the minimum number rows in the row vector is less than the row
    %dimensions of the image then pad the image before the first row index.
    
    if minRow <= 1
    
        %pad the grayscale x-section image.
        
        truncated_gray_im     = padarray(truncated_gray_im, [pad 0], 'symmetric', 'pre');
                
        
        %pad the solid x-section image.
        
        solid_buffer = padarray(solid_buffer, [pad 0], 'symmetric', 'pre');
  
        
        %set border padding values to zero.
        
        solid_buffer(1:pad,:)                                      = false;
    
        
        %calculate the new min and max rows for the padded image.
        
        minRow = minRow + pad;
        maxRow = maxRow + pad;
        
        
    end;

    
    
        %if the maximum number of rows in the row vector exceeds the row
    %dimensions of image then pad the image starting at the last row index
    
    if maxCol >= size(img1,2)
        
        
        %pad the grayscale x-section image.
        
        truncated_gray_im     = padarray(truncated_gray_im, [0 pad], 'symmetric', 'post');
               
        
        %pad the solid x-section image.
        
        solid_buffer = padarray(solid_buffer, [0 pad], 'symmetric', 'post');
        
        
        %set border padding values to zero.
        
        solid_buffer(:,((end-(pad-1)):end))                         = false;                

        
    end;
    
    
    %if the minimum number cols in the col vector is less than the col
    %dimensions of the image then pad the image before the first col index.
    
    if minCol <= 1
    
        %pad the grayscale x-section image.
        
        truncated_gray_im     = padarray(truncated_gray_im, [0 pad], 'symmetric', 'pre');
                
        
        %pad the solid x-section image.
        
        solid_buffer = padarray(solid_buffer, [0 pad], 'symmetric', 'pre');
  
        
        %set the border padding values to zero.
        
        solid_buffer(:,(1:pad))                                    = false;                

        
        %calculate the new min and max rows for the padded image.
        
        minCol = minCol + pad;
        maxCol = maxCol + pad;
        
    
    end;
    
    
    %now that we paded the correct indices of the images we can truncate
    %the image now according to the row and column vectors defined above
    
    truncated_gray_im     = truncated_gray_im(minRow:maxRow, minCol:maxCol);
    solid_buffer               = solid_buffer(minRow:maxRow, minCol:maxCol);
                
         
    %define the grayscale image.
    
    grayscale_x_section      = truncated_gray_im;
    
    
    %set all pixels outside the buffer region to the background pixel
    %value.
    
    grayscale_x_section(solid_buffer == 0) = 255;
      
    
    
                
else
     
    
    %define truncated grayscale image.
    
    truncated_gray_im                        = img1(rowRange, colRange);
        
    
    %crop x-section image (binary) - without xs buffer. pad array now.
                        
    solid_buffer = padarray(TRUNC_SOLID, [pad pad], 'symmetric');
          
    
    %erase erronemous pixels from pad border (xs image).
            
    solid_buffer([(1:pad) ((end-(pad-1)):end)],:)        = false;
    solid_buffer(:,[(1:pad) ((end-(pad-1)):end)])        = false;
                  
                
    %crop x-section image (grayscale with white background).
            
    grayscale_x_section                 = ones(size(solid_buffer), 'uint8')*255;
    grayscale_x_section(solid_buffer ~= 0)            = img1(solidSegment ~= 0);
                
end;
            


%show result from segmentation action in the reference image axes.
             
set(gcf, 'CurrentAxes', f_fig_handle.im_axes(2));
                                             cla; 
                     imshow(grayscale_x_section); 
               
              
                                              
%crop x-section image (grayscale) - without xs buffer.  pad array now and
%write the image to file.
            
filename      = [cd AllImageSpecs.fileSeparator 'X_section_segments' ...
    AllImageSpecs.fileSeparator 'XS.' image_name];
            
                  imwrite(grayscale_x_section, filename, AllImageSpecs.format);
            
            
%crop x-section image (solid binary).  pad array now and
%write the image to file.            
           
filename = [cd AllImageSpecs.fileSeparator 'X_section_segments' ...
    AllImageSpecs.fileSeparator 'SOLID_XS.' image_name];
            
       imwrite(logical(solid_buffer), filename, AllImageSpecs.format);
   
                  
%crop x-section image (grayscale) - with xs buffer.  pad array now and
%write the image to file.                       

filename = [cd AllImageSpecs.fileSeparator 'X_section_segments' ...
    AllImageSpecs.fileSeparator 'XS_BUFFER.' image_name];
            
                   imwrite(truncated_gray_im, filename, AllImageSpecs.format);
      
                   
                   
                      
%make directory for output images.

mkdir('Image_Output', image_name);          






end


