function xv_calc_data(highlightXV, XVmode)

%this function calculates the data values for the meta and xylem vessels
%and assigns them to the data matrix.


    global   data_matrix; %data matrix.
    global      DirSpecs; %structure containing the current directory specifications.
    global  solidSegment; %solid stele image.
    global AllImageSpecs; %structure containing all image specifications.


    %determine if the user is calculating the meta or proto xylem vessel data.

    switch XVmode

        case 1 %the user is calculating meta xylem data.

            highlight = AllImageSpecs.highlightCode(2);


        case 2 %the user is calculating proto xylem data.

            highlight = AllImageSpecs.highlightCode(3);

    end;


    %calculate the total xylem vessel area.

    xv_area = length(find(highlightXV == highlight))/AllImageSpecs.calib_area;  


    %count the xylem vessels using a binary image containing only xylem 
    %vessel areas.


    %create blank binary image.

    countXVareas                      = solidSegment; 


    %place xylem vessels in binary image.

    countXVareas(highlightXV ~= highlight)   = false; 



    %CALCULATE THE 'r^4' TERM IN THE TOTAL WATER FLUX CALCULATION USING Poiseuille's EQUATION.

    xv_regionprops = regionprops(countXVareas, 'MajorAxisLength', ...
        'MinorAxisLength', 'Area');


    %vectors of major an minor axis length.

    MajAxLen = cat(1, xv_regionprops.MajorAxisLength);
    MinAxLen = cat(1, xv_regionprops.MinorAxisLength);


    %calculate the mean diameter of each xylem vessel object.

    mean_major_minor_AL = mean([MajAxLen, MinAxLen], 2);


    %calculate the mean, std, low and high xylem vessel diameters.

    med_xv_diam = median(mean_major_minor_AL)/(AllImageSpecs.calib_length);
    std_xv_diam    = std(mean_major_minor_AL)/(AllImageSpecs.calib_length);
    low_xv_diam    = min(mean_major_minor_AL)/(AllImageSpecs.calib_length);
    high_xv_diam   = max(mean_major_minor_AL)/(AllImageSpecs.calib_length);


    %vector of all object areas.

    Area = cat(1, xv_regionprops.Area);


    %calculate the mean, std, low and high xylem vessel areas values.

    med_xv = median(Area)/AllImageSpecs.calib_area;
    std_xv    = std(Area)/AllImageSpecs.calib_area;
    low_xv    = min(Area)/AllImageSpecs.calib_area;
    high_xv   = max(Area)/AllImageSpecs.calib_area;



    %--------------------------------------------------------------------------                
    %CALCULATE THE 'r^4' TERM IN THE TOTAL WATER FLUX CALCULATION USING Poiseuille's EQUATION.
    %--------------------------------------------------------------------------

    %calculate radius of each xylem vessel object (i.e. the mean of the major and
    %minor axis lengths).

    xylem_vessel_radii = (1/1000)*(mean_major_minor_AL/2)/AllImageSpecs.calib_length;


    %sum these r^4 terms up.

    total_xv_r4power = sum(xylem_vessel_radii.^4);



    %place data values in global data matrix according their kind.

    switch XVmode

        case 1

        %place the meta xv data in global data matrix.


        data_matrix{DirSpecs.iteration, 24}     = length(Area); %# of meta-xv.
        data_matrix{DirSpecs.iteration, 25}           = med_xv; %median meta-xv area.
        data_matrix{DirSpecs.iteration, 26}           = std_xv; %std meta-xv area.
        data_matrix{DirSpecs.iteration, 27}           = low_xv; %low meta-xv area.
        data_matrix{DirSpecs.iteration, 28}          = high_xv; %high meta-xv area.
        data_matrix{DirSpecs.iteration, 29}      = med_xv_diam; %median meta-xv diameter.
        data_matrix{DirSpecs.iteration, 30}      = std_xv_diam; %std meta-xv diameter.
        data_matrix{DirSpecs.iteration, 31}      = low_xv_diam; %low meta-xv diameter.
        data_matrix{DirSpecs.iteration, 32}     = high_xv_diam; %high meta-xv diameter.
        data_matrix{DirSpecs.iteration, 33}          = xv_area; %meta-xv area.

        data_matrix{DirSpecs.iteration, 34} = total_xv_r4power; %r^4 h2o conductance.



        case 2

        %place the proto xv data in global data matrix.    

        data_matrix{DirSpecs.iteration, 35}     = length(Area); %# of proto-xv.
        data_matrix{DirSpecs.iteration, 36}           = med_xv; %median proto-xv area.
        data_matrix{DirSpecs.iteration, 37}           = std_xv; %std proto-xv area.
        data_matrix{DirSpecs.iteration, 38}           = low_xv; %low proto-xv area.
        data_matrix{DirSpecs.iteration, 39}          = high_xv; %high proto-xv area.
        data_matrix{DirSpecs.iteration, 40}      = med_xv_diam; %median proto-xv diameter.
        data_matrix{DirSpecs.iteration, 41}      = std_xv_diam; %std proto-xv diameter.
        data_matrix{DirSpecs.iteration, 42}      = low_xv_diam; %low proto-xv diameter.
        data_matrix{DirSpecs.iteration, 43}     = high_xv_diam; %high proto-xv diameter.
        data_matrix{DirSpecs.iteration, 44}          = xv_area; %proto-xv area.

        data_matrix{DirSpecs.iteration, 45} = total_xv_r4power; %r^4 h2o conductance.  



    end;



end